@@ -34,9 +34,9 @@ Module responsible for handling the command line arguments for Gramps.
 # Standard python modules
 #
 #-------------------------------------------------------------------------
-from __future__ import print_function
 import os
 import sys
+import re
 
 #-------------------------------------------------------------------------
 #
@@ -45,15 +45,14 @@ import sys
 #-------------------------------------------------------------------------
 from gramps.gen.recentfiles import recent_files
 from gramps.gen.utils.file import rm_tempdir, get_empty_tempdir
-from gramps.gen.db import DbBsddb
 from .clidbman import CLIDbManager, NAME_FILE, find_locker_name
-
+from gramps.gen.db.utils import make_database
 from gramps.gen.plug import BasePluginManager
 from gramps.gen.plug.report import CATEGORY_BOOK, CATEGORY_CODE, BookList
 from .plug import cl_report, cl_book
 from gramps.gen.const import GRAMPS_LOCALE as glocale
 _ = glocale.translation.gettext
-from gramps.gen.constfunc import conv_to_unicode
+from gramps.gen.config import config
 
 #-------------------------------------------------------------------------
 #
@@ -63,7 +62,7 @@ from gramps.gen.constfunc import conv_to_unicode
 def _split_options(options_str):
     """
     Split the options for the action.
-    
+
     Rules:
 
     * Entries in the list of options are separated by commas without
@@ -75,7 +74,7 @@ def _split_options(options_str):
     * Text containing double quotes must be contained in single quotes
     * Text containing single quotes must be contained in double quotes
     * Text cannot include both single and double quotes
-    
+
     Examples:
 
     Multiple options specified::
@@ -98,9 +97,9 @@ def _split_options(options_str):
     in_list = False
     quote_type = ""
     options_str_dict = {}
-    
+
     for char in options_str:
-        if not parsing_value: 
+        if not parsing_value:
             # Parsing the name of the option
             if char == "=":
                 #print char, "This value ends the name"
@@ -118,7 +117,7 @@ def _split_options(options_str):
                 #print char, "This character ends the list"
                 in_list = False
                 value += char
-            elif not in_quotes and ( char == '"' or char == "'"):
+            elif not in_quotes and (char == '"' or char == "'"):
                 #print char, "This character starts a quoted string"
                 in_quotes = True
                 quote_type = char
@@ -148,17 +147,17 @@ def _split_options(options_str):
 #-------------------------------------------------------------------------
 # ArgHandler
 #-------------------------------------------------------------------------
-class ArgHandler(object):
+class ArgHandler:
     """
     This class is responsible for the non GUI handling of commands.
-    The handler is passed a parser object, sanitizes it, and can execute the 
+    The handler is passed a parser object, sanitizes it, and can execute the
     actions requested working on a :class:`.DbState`.
     """
 
-    def __init__(self, dbstate, parser, sessionmanager, 
-                        errorfunc=None, gui=False):
+    def __init__(self, dbstate, parser, sessionmanager,
+                 errorfunc=None, gui=False):
         self.dbstate = dbstate
-        self.sm = sessionmanager
+        self.smgr = sessionmanager
         self.errorfunc = errorfunc
         self.gui = gui
         self.user = sessionmanager.user
@@ -172,17 +171,21 @@ class ArgHandler(object):
             self.list = parser.list
             self.list_more = parser.list_more
             self.list_table = parser.list_table
+            self.database_names = parser.database_names
         self.open_gui = parser.open_gui
         self.imp_db_path = None
         self.dbman = CLIDbManager(self.dbstate)
         self.force_unlock = parser.force_unlock
-        self.cl = 0
+        self.cl_bool = False
         self.imports = []
         self.exports = []
+        self.removes = parser.removes
+        self.username = parser.username
+        self.password = parser.password
 
         self.open = self.__handle_open_option(parser.open, parser.create)
         self.sanitize_args(parser.imports, parser.exports)
-    
+
     def __error(self, msg1, msg2=None):
         """
         Output an error. Uses errorfunc if given, otherwise a simple print.
@@ -214,45 +217,46 @@ class ArgHandler(object):
         """
         if value is None:
             return None
-        value = conv_to_unicode(value, sys.stdin.encoding)
         db_path = self.__deduce_db_path(value)
 
         if db_path:
             # We have a potential database path.
             # Check if it is good.
             if not self.check_db(db_path, self.force_unlock):
-                sys.exit(0)
+                sys.exit(1)
             if create:
-                self.__error( _("Error: Family Tree '%s' already exists.\n"
-                                "The '-C' option cannot be used.") % value)
-                sys.exit(0)
+                self.__error(_("Error: Family Tree '%s' already exists.\n"
+                               "The '-C' option cannot be used."
+                              ) % value)
+                sys.exit(1)
             return db_path
         elif create:
             # create the tree here, and continue
-            db_path, title = self.dbman.create_new_db_cli(title=value)
+            dbid = config.get('database.backend')
+            db_path, title = self.dbman.create_new_db_cli(title=value,
+                                                          dbid=dbid)
             return db_path
         else:
-            self.__error( _('Error: Input Family Tree "%s" does not exist.\n'
-                            "If GEDCOM, Gramps-xml or grdb, use the -i option "
-                            "to import into a Family Tree instead.") % value)
-            sys.exit(0)
+            self.__error(_('Error: Input Family Tree "%s" does not exist.\n'
+                           "If GEDCOM, Gramps-xml or grdb, use the -i option "
+                           "to import into a Family Tree instead."
+                          ) % value)
+            sys.exit(1)
 
     def __handle_import_option(self, value, family_tree_format):
         """
         Handle the "-i" or "--import" option.
         Only Files supported by a plugin can be imported, so not Family Trees.
         """
-        # Need to convert path/filename to unicode before opening
-        # For non latin characters in Windows path/file/user names
-        fname = conv_to_unicode(value, sys.stdin.encoding)
+        fname = value
         fullpath = os.path.abspath(os.path.expanduser(fname))
         if fname != '-' and not os.path.exists(fullpath):
             self.__error(_('Error: Import file %s not found.') % fname)
-            sys.exit(0)
-        
+            sys.exit(1)
+
         if family_tree_format is None:
             # Guess the file format based on the file extension.
-            # This will get the lower case extension without a period, 
+            # This will get the lower case extension without a period,
             # or an empty string.
             family_tree_format = os.path.splitext(fname)[-1][1:].lower()
 
@@ -261,16 +265,16 @@ class ArgHandler(object):
         for plugin in pmgr.get_import_plugins():
             if family_tree_format == plugin.get_extension():
                 plugin_found = True
-                
+
         if plugin_found:
             self.imports.append((fname, family_tree_format))
         else:
             self.__error(_('Error: Unrecognized type: "%(format)s" for '
-                           'import file: %(filename)s') % 
-                           {'format' : family_tree_format, 
-                            'filename' : fname})
-            sys.exit(0)
-            
+                           'import file: %(filename)s'
+                          ) % {'format'   : family_tree_format,
+                               'filename' : fname})
+            sys.exit(1)
+
     def __handle_export_option(self, value, family_tree_format):
         """
         Handle the "-e" or "--export" option.
@@ -279,9 +283,7 @@ class ArgHandler(object):
         """
         if self.gui:
             return
-        # Need to convert path/filename to unicode before opening
-        # For non latin characters in Windows path/file/user names
-        fname = conv_to_unicode(value, sys.stdin.encoding)
+        fname = value
         if fname == '-':
             fullpath = '-'
         else:
@@ -289,18 +291,19 @@ class ArgHandler(object):
             if os.path.exists(fullpath):
                 message = _("WARNING: Output file already exists!\n"
                             "WARNING: It will be overwritten:\n   %s"
-                            ) % fullpath
-                accepted = self.user.prompt(_('OK to overwrite?'), message, 
-                        _('yes'), _('no'))
+                           ) % fullpath
+                accepted = self.user.prompt(_('OK to overwrite?'), message,
+                                            _('yes'), _('no'),
+                                            default_label=_('yes'))
                 if accepted:
-                    self.__error(_("Will overwrite the existing file: %s") 
-                                   % fullpath)
+                    self.__error(_("Will overwrite the existing file: %s"
+                                  ) % fullpath)
                 else:
-                    sys.exit(0)
+                    sys.exit(1)
 
         if family_tree_format is None:
             # Guess the file format based on the file extension.
-            # This will get the lower case extension without a period, 
+            # This will get the lower case extension without a period,
             # or an empty string.
             family_tree_format = os.path.splitext(fname)[-1][1:].lower()
 
@@ -309,18 +312,18 @@ class ArgHandler(object):
         for plugin in pmgr.get_export_plugins():
             if family_tree_format == plugin.get_extension():
                 plugin_found = True
-                
+
         if plugin_found:
             self.exports.append((fullpath, family_tree_format))
         else:
-            self.__error(_("ERROR: Unrecognized format for export file %s") 
-                            % fname)
-            sys.exit(0)
-        
+            self.__error(_("ERROR: Unrecognized format for export file %s"
+                          ) % fname)
+            sys.exit(1)
+
     def __deduce_db_path(self, db_name_or_path):
         """
         Attempt to find a database path for the given parameter.
-        
+
         :returns: The path to a Gramps DB or None if a database can not be
                   deduced.
         """
@@ -336,20 +339,20 @@ class ArgHandler(object):
                 name_file_path = os.path.join(fullpath, NAME_FILE)
                 if os.path.isfile(name_file_path):
                     db_path = fullpath
-                    
+
         return db_path
 
     #-------------------------------------------------------------------------
-    # Overall argument handler: 
+    # Overall argument handler:
     # sorts out the sequence and details of operations
     #-------------------------------------------------------------------------
     def handle_args_gui(self):
         """
         Method to handle the arguments that can be given for a GUI session.
 
-        :returns: the filename of the family tree that should be opened if 
+        :returns: the filename of the family tree that should be opened if
                   user just passed a famtree or a filename.
-                  
+
         1. no options: a family tree can be given, if so, this name is tested
            and returned. If a filename, it is imported in a new db and name of
            new db returned
@@ -364,12 +367,13 @@ class ArgHandler(object):
             if not db_path:
                 # Apparently it is not a database. See if it is a file that
                 # can be imported.
-                db_path, title = self.dbman.import_new_db(self.open_gui, self.user)
+                db_path, title = self.dbman.import_new_db(self.open_gui,
+                                                          self.user)
 
             if db_path:
                 # Test if not locked or problematic
                 if not self.check_db(db_path, self.force_unlock):
-                    sys.exit(0)
+                    sys.exit(1)
                 # Add the file to the recent items
                 title = self.dbstate.db.get_dbname()
                 if not title:
@@ -378,89 +382,98 @@ class ArgHandler(object):
                 self.open = db_path
                 self.__open_action()
             else:
-                sys.exit(0)
+                sys.exit(_("Error: cannot open '%s'") % self.open_gui)
             return db_path
-        
-        # if not open_gui, parse any command line args. We can only have one 
+
+        # if not open_gui, parse any command line args. We can only have one
         #  open argument, and perhaps some import arguments
         self.__open_action()
         self.__import_action()
         return None
-    
+
     def handle_args_cli(self, cleanup=True):
         """
         Depending on the given arguments, import or open data, launch
         session, write files, and/or perform actions.
-        
+
         :param: climan: the manager of a CLI session
         :type: :class:`.CLIManager` object
         """
-
+        # Handle the "-l" List Family Trees option.
         if self.list:
             print(_('List of known Family Trees in your database path\n'))
 
             for name, dirname in sorted(self.dbman.family_tree_list(),
                                         key=lambda pair: pair[0].lower()):
+                if (self.database_names is None
+                        or any([(re.match("^" + dbname + "$", name)
+                                 or dbname == name)
+                                for dbname in self.database_names])):
+                    print(_('%(full_DB_path)s with name "%(f_t_name)s"'
+                           ) % {'full_DB_path' : dirname,
+                                'f_t_name'     : name})
+            return
 
-                print(_("%(full_DB_path)s with name \"%(f_t_name)s\"")
-                              % {'full_DB_path' : dirname, 'f_t_name' : name})
-            sys.exit(0)
+        # Handle the "--remove" Family Tree
+        if self.removes:
+            for name in self.removes:
+                self.dbman.remove_database(name, self.user)
+            return
 
+        # Handle the "-L" List Family Trees in detail option.
         if self.list_more:
-            print(_('Gramps Family Trees:'))
-            summary_list = self.dbman.family_tree_summary()
-            for summary in sorted(summary_list,
-                                  key=lambda sum: sum[_("Family Tree")].lower()):
-                print(_("Family Tree \"%s\":") % summary[_("Family Tree")])
-                for item in sorted(summary):
-                    if item != "Family Tree":
-                        # translators: needed for French, ignore otherwise
-                        print(_("   %s: %s") % (item, summary[item]))
-            sys.exit(0)
-           
+            self.dbman.print_family_tree_summaries(self.database_names)
+            return
+
+        # Handle the "-t" List Family Trees, tab delimited option.
         if self.list_table:
             print(_('Gramps Family Trees:'))
-            summary_list = self.dbman.family_tree_summary()
+            summary_list = self.dbman.family_tree_summary(self.database_names)
             if not summary_list:
-                sys.exit(0)
-            print(_("Family Tree"), end="")
+                return
+            # We have to construct the line elements together, to avoid
+            # insertion of blank spaces when print on the same line is used
+            line_list = [_("Family Tree")]
             for key in sorted(summary_list[0]):
-                if key !=  "Family Tree":
-                    print("\t ", end="")
-                    print(key, end="")
-            print()
+                if key != _("Family Tree"):
+                    line_list += [key]
+            print("\t".join(line_list))
             for summary in sorted(summary_list,
-                                  key=lambda sum: sum[_("Family Tree")].lower()):
-                print('"%s"' % summary[_("Family Tree")], end="")
+                                  key=lambda
+                                      sum: sum[_("Family Tree")].lower()):
+                line_list = [(_('"%s"') % summary[_("Family Tree")])]
                 for item in sorted(summary):
                     if item != _("Family Tree"):
-                        print("\t ", end="")
-                        print('"%s"' % summary[item], end="")
-                print()
-            sys.exit(0)
+                        # translators: used in French+Russian, ignore otherwise
+                        line_list += [(_('"%s"') % summary[item])]
+                print("\t".join(line_list))
+            return
 
         self.__open_action()
         self.__import_action()
-            
+
         for (action, op_string) in self.actions:
-            print(_("Performing action: %s.") % action, file=sys.stderr)
+            print(_("Performing action: %s."
+                   ) % action,
+                  file=sys.stderr)
             if op_string:
-                print(_("Using options string: %s")
-                        % op_string, file=sys.stderr)
+                print(_("Using options string: %s"
+                       ) % op_string,
+                      file=sys.stderr)
             self.cl_action(action, op_string)
 
         for expt in self.exports:
-            print(_("Exporting: file %(filename)s, format %(format)s.")
-                    % {'filename' : expt[0],
-                       'format' : expt[1]}, file=sys.stderr)
+            print(_("Exporting: file %(filename)s, format %(format)s."
+                   ) % {'filename' : expt[0],
+                        'format'   : expt[1]},
+                  file=sys.stderr)
             self.cl_export(expt[0], expt[1])
 
         if cleanup:
             self.cleanup()
-            print(_("Exiting."), file=sys.stderr)
-            sys.exit(0)
 
     def cleanup(self):
+        """ clean up any remaining files """
         print(_("Cleaning up."), file=sys.stderr)
         # remove files in import db subdir after use
         self.dbstate.db.close()
@@ -470,7 +483,7 @@ class ArgHandler(object):
     def __import_action(self):
         """
         Take action for all given import files.
-        
+
         .. note:: Family trees are not supported.
 
         If a family tree is open, the import happens on top of it. If not
@@ -479,52 +492,55 @@ class ArgHandler(object):
         have happened that is now finished), if this is GUI, it is opened.
         """
         if self.imports:
-            self.cl = bool(self.exports or self.actions or self.cl)
+            self.cl_bool = bool(self.exports or self.actions or self.cl_bool)
 
             if not self.open:
                 # Create empty dir for imported database(s)
                 if self.gui:
-                    self.imp_db_path, title = self.dbman.create_new_db_cli()
+                    dbid = config.get('database.backend')
+                    self.imp_db_path, title = self.dbman.create_new_db_cli(
+                        dbid=dbid)
                 else:
                     self.imp_db_path = get_empty_tempdir("import_dbdir")
-                    newdb = DbBsddb()
-                    newdb.write_version(self.imp_db_path)
-                
+                    dbid = config.get('database.backend')
+                    newdb = make_database(dbid)
+
                 try:
-                    self.sm.open_activate(self.imp_db_path)
+                    self.smgr.open_activate(self.imp_db_path, self.username, self.password)
                     msg = _("Created empty Family Tree successfully")
                     print(msg, file=sys.stderr)
                 except:
                     print(_("Error opening the file."), file=sys.stderr)
                     print(_("Exiting..."), file=sys.stderr)
-                    sys.exit(0)
+                    sys.exit(1)
 
             for imp in self.imports:
-                msg = _("Importing: file %(filename)s, format %(format)s.") % \
-                        {'filename' : imp[0], 'format' : imp[1]}
+                msg = _("Importing: file %(filename)s, format %(format)s."
+                       ) % {'filename' : imp[0],
+                            'format'   : imp[1]}
                 print(msg, file=sys.stderr)
                 self.cl_import(imp[0], imp[1])
 
     def __open_action(self):
         """
-        Take action on a family tree dir to open. It will be opened in the 
+        Take action on a family tree dir to open. It will be opened in the
         session manager
         """
         if self.open:
-            # Family Tree to open was given. Open it 
+            # Family Tree to open was given. Open it
             # Then go on and process the rest of the command line arguments.
-            self.cl = bool(self.exports or self.actions)
+            self.cl_bool = bool(self.exports or self.actions)
 
             # we load this file for use
             try:
-                self.sm.open_activate(self.open)
+                self.smgr.open_activate(self.open, self.username, self.password)
                 print(_("Opened successfully!"), file=sys.stderr)
             except:
                 print(_("Error opening the file."), file=sys.stderr)
                 print(_("Exiting..."), file=sys.stderr)
-                sys.exit(0)
+                sys.exit(1)
 
-    def check_db(self, dbpath, force_unlock = False):
+    def check_db(self, dbpath, force_unlock=False):
         """
         Test a given family tree path if it can be opened.
         """
@@ -536,7 +552,10 @@ class ArgHandler(object):
                           _("  Info: %s")) % find_locker_name(dbpath))
             return False
         if self.dbman.needs_recovery(dbpath):
-            self.__error( _("Database needs recovery, cannot open it!"))
+            self.__error(_("Database needs recovery, cannot open it!"))
+            return False
+        if self.dbman.backend_unavailable(dbpath):
+            self.__error(_("Database backend unavailable, cannot open it!"))
             return False
         return True
 
@@ -563,7 +582,7 @@ class ArgHandler(object):
     #-------------------------------------------------------------------------
     def cl_export(self, filename, family_tree_format):
         """
-        Command-line export routine. 
+        Command-line export routine.
         Try to write into filename using the family_tree_format.
         """
         pmgr = BasePluginManager.get_instance()
@@ -588,7 +607,7 @@ class ArgHandler(object):
             except:
                 options_str_dict = {}
                 print(_("Ignoring invalid options string."),
-                              file=sys.stderr)
+                      file=sys.stderr)
 
             name = options_str_dict.pop('name', None)
             _cl_list = pmgr.get_reg_reports(gui=False)
@@ -598,15 +617,15 @@ class ArgHandler(object):
                         mod = pmgr.load_plugin(pdata)
                         if not mod:
                             #import of plugin failed
-                            return 
+                            return
                         category = pdata.category
                         report_class = eval('mod.' + pdata.reportclass)
                         options_class = eval('mod.' + pdata.optionclass)
                         if category in (CATEGORY_BOOK, CATEGORY_CODE):
-                            options_class(self.dbstate.db, name, category, 
+                            options_class(self.dbstate.db, name, category,
                                           options_str_dict)
                         else:
-                            cl_report(self.dbstate.db, name, category, 
+                            cl_report(self.dbstate.db, name, category,
                                       report_class, options_class,
                                       options_str_dict)
                         return
@@ -614,29 +633,30 @@ class ArgHandler(object):
                 msg = _("Unknown report name.")
             else:
                 msg = _("Report name not given. "
-                        "Please use one of %(donottranslate)s=reportname") % \
-                        {'donottranslate' : '[-p|--options] name'}
+                        "Please use one of %(donottranslate)s=reportname"
+                       ) % {'donottranslate' : '[-p|--options] name'}
 
             print(_("%s\n Available names are:") % msg, file=sys.stderr)
-            for pdata in sorted(_cl_list, key= lambda pdata: pdata.id.lower()):
+            for pdata in sorted(_cl_list, key=lambda pdata: pdata.id.lower()):
                 # Print cli report name ([item[0]), GUI report name (item[4])
                 if len(pdata.id) <= 25:
-                    print("   %s%s- %s"
-                                 % ( pdata.id, " " * (26 - len(pdata.id)),
-                                     pdata.name), file=sys.stderr)
+                    print("   %s%s- %s" % (pdata.id,
+                                           " " * (26 - len(pdata.id)),
+                                           pdata.name),
+                          file=sys.stderr)
                 else:
-                    print("   %s\t- %s"
-                                  % (pdata.id, pdata.name), file=sys.stderr)
+                    print("   %s\t- %s" % (pdata.id, pdata.name),
+                          file=sys.stderr)
 
         elif action == "tool":
             from gramps.gui.plug import tool
             try:
-                options_str_dict = dict( [ tuple(chunk.split('=')) for
-                                           chunk in options_str.split(',') ] )
+                options_str_dict = dict([tuple(chunk.split('='))
+                                         for chunk in options_str.split(',')])
             except:
                 options_str_dict = {}
                 print(_("Ignoring invalid options string."),
-                              file=sys.stderr)
+                      file=sys.stderr)
 
             name = options_str_dict.pop('name', None)
             _cli_tool_list = pmgr.get_reg_tools(gui=False)
@@ -646,36 +666,36 @@ class ArgHandler(object):
                         mod = pmgr.load_plugin(pdata)
                         if not mod:
                             #import of plugin failed
-                            return 
+                            return
                         category = pdata.category
                         tool_class = eval('mod.' + pdata.toolclass)
                         options_class = eval('mod.' + pdata.optionclass)
-                        tool.cli_tool(
-                                dbstate=self.dbstate, 
-                                name=name, 
-                                category=category, 
-                                tool_class=tool_class,
-                                options_class=options_class, 
-                                options_str_dict=options_str_dict,
-                                user=self.user)
+                        tool.cli_tool(dbstate=self.dbstate,
+                                      name=name,
+                                      category=category,
+                                      tool_class=tool_class,
+                                      options_class=options_class,
+                                      options_str_dict=options_str_dict,
+                                      user=self.user)
                         return
                 msg = _("Unknown tool name.")
             else:
                 msg = _("Tool name not given. "
-                        "Please use one of %(donottranslate)s=toolname.") % \
-                        {'donottranslate' : '[-p|--options] name'}
+                        "Please use one of %(donottranslate)s=toolname."
+                       ) % {'donottranslate' : '[-p|--options] name'}
 
             print(_("%s\n Available names are:") % msg, file=sys.stderr)
             for pdata in sorted(_cli_tool_list,
                                 key=lambda pdata: pdata.id.lower()):
                 # Print cli report name ([item[0]), GUI report name (item[4])
                 if len(pdata.id) <= 25:
-                    print("   %s%s- %s"
-                                  % ( pdata.id, " " * (26 - len(pdata.id)),
-                                      pdata.name), file=sys.stderr)
+                    print("   %s%s- %s" % (pdata.id,
+                                           " " * (26 - len(pdata.id)),
+                                           pdata.name),
+                          file=sys.stderr)
                 else:
-                    print("   %s\t- %s"
-                                  % (pdata.id, pdata.name), file=sys.stderr)
+                    print("   %s\t- %s" % (pdata.id, pdata.name),
+                          file=sys.stderr)
 
         elif action == "book":
             try:
@@ -683,20 +703,20 @@ class ArgHandler(object):
             except:
                 options_str_dict = {}
                 print(_("Ignoring invalid options string."),
-                              file=sys.stderr)
+                      file=sys.stderr)
 
             name = options_str_dict.pop('name', None)
             book_list = BookList('books.xml', self.dbstate.db)
             if name:
                 if name in book_list.get_book_names():
-                    cl_book(self.dbstate.db, name, book_list.get_book(name), 
+                    cl_book(self.dbstate.db, name, book_list.get_book(name),
                             options_str_dict)
                     return
                 msg = _("Unknown book name.")
             else:
                 msg = _("Book name not given. "
-                        "Please use one of %(donottranslate)s=bookname.") % \
-                        {'donottranslate' : '[-p|--options] name'}
+                        "Please use one of %(donottranslate)s=bookname."
+                       ) % {'donottranslate' : '[-p|--options] name'}
 
             print(_("%s\n Available names are:") % msg, file=sys.stderr)
             for name in sorted(book_list.get_book_names()):
@@ -704,4 +724,4 @@ class ArgHandler(object):
 
         else:
             print(_("Unknown action: %s.") % action, file=sys.stderr)
-            sys.exit(0)
+            sys.exit(1)
