@@ -15,11 +15,11 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
 """
-Package providing filtering framework for GRAMPS.
+Package providing filtering framework for Gramps.
 """
 
 #SystemFilters = None
@@ -27,7 +27,8 @@ CustomFilters = None
 
 from ..const import CUSTOM_FILTERS
 from ._filterlist import FilterList
-from ._genericfilter import GenericFilter, GenericFilterFactory
+from ._genericfilter import (GenericFilter, GenericFilterFactory,
+                             DeferredFilter, DeferredFamilyFilter)
 from ._paramfilter import ParamFilter
 from ._searchfilter import SearchFilter, ExactSearchFilter
 
@@ -35,12 +36,12 @@ from ._searchfilter import SearchFilter, ExactSearchFilter
     #global SystemFilters
     #SystemFilters = FilterList(SYSTEM_FILTERS)
     #SystemFilters.load()
-    
+
 def reload_custom_filters():
     global CustomFilters
     CustomFilters = FilterList(CUSTOM_FILTERS)
     CustomFilters.load()
-    
+
 #if not SystemFilters:
     #reload_system_filters()
 
