@@ -31,7 +31,7 @@ _ = glocale.translation.gettext
 
 #-------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
 #-------------------------------------------------------------------------
 from . import Rule
@@ -48,7 +48,7 @@ class HasSourceCountBase(Rule):
                    "connected to it (actually citations are counted)"
     category    = _('Citation/source filters')
 
-    def prepare(self, db):
+    def prepare(self, db, user):
         # things we want to do just once, not for every handle
         if  self.list[1] == 'less than':
             self.count_type = 0
