@@ -16,7 +16,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
 #-------------------------------------------------------------------------
@@ -29,7 +29,7 @@ _ = glocale.translation.gettext
 
 #-------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
 #-------------------------------------------------------------------------
 from .._hasgrampsid import HasGrampsId
@@ -41,7 +41,7 @@ from .._hasgrampsid import HasGrampsId
 #-------------------------------------------------------------------------
 class HasSourceIdOf(HasGrampsId):
     """Rule that checks for a citation with a source which has a specific
-    GRAMPS ID"""
+    Gramps ID"""
 
     name        = _('Citation with Source <Id>')
     description = _("Matches a citation with a source with a specified Gramps "
