@@ -17,7 +17,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
 #-------------------------------------------------------------------------
@@ -30,7 +30,7 @@ _ = glocale.translation.gettext
 
 #-------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
 #-------------------------------------------------------------------------
 from .. import MatchesFilterBase
@@ -54,14 +54,14 @@ class MatchesSourceFilter(MatchesFilterBase):
     # we want to have this filter show source filters
     namespace   = 'Source'
 
-    def prepare(self, db):
-        MatchesFilterBase.prepare(self, db)
+    def prepare(self, db, user):
+        MatchesFilterBase.prepare(self, db, user)
         self.MRF_filt = self.find_filter()
-            
+
     def apply(self, db, object):
         if self.MRF_filt is None :
             return False
-        
+
         source_handle = object.source_handle
         if self.MRF_filt.check(db, source_handle):
             return True
