@@ -28,7 +28,7 @@ _ = glocale.translation.gettext
 
 #-------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
 #-------------------------------------------------------------------------
 from ....lib.notetype import NoteType
@@ -43,15 +43,15 @@ class HasNote(Rule):
     """Rule that checks for a note with a particular value"""
 
 
-    labels      = [ _('Text:'), 
-                    _('Note type:'), 
+    labels      = [ _('Text:'),
+                    _('Note type:'),
                     ]
     name        = _('Notes matching parameters')
     description = _("Matches Notes with particular parameters")
     category    = _('General filters')
     allow_regex = True
 
-    def prepare(self, dbase):
+    def prepare(self, db, user):
         if self.list[1]:
             self.ntype = NoteType()
             self.ntype.set_from_xml_str(self.list[1])
