@@ -15,7 +15,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
 #-------------------------------------------------------------------------
@@ -28,7 +28,7 @@ _ = glocale.translation.gettext
 
 #-------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
 #-------------------------------------------------------------------------
 from ._isancestorof import IsAncestorOf
@@ -49,7 +49,7 @@ class IsAncestorOfFilterMatch(IsAncestorOf):
     description = _("Matches people that are ancestors "
                     "of anybody matched by a filter")
 
-    def prepare(self,db):
+    def prepare(self, db, user):
         self.db = db
         self.map = set()
         try:
@@ -59,12 +59,20 @@ class IsAncestorOfFilterMatch(IsAncestorOf):
                 first = 1
         except IndexError:
             first = 1
-            
+
         filt = MatchesFilter(self.list[0:1])
-        filt.requestprepare(db)
+        filt.requestprepare(db, user)
+        if user:
+            user.begin_progress(self.category,
+                                _('Retrieving all sub-filter matches'),
+                                db.get_number_of_people())
         for person in db.iter_people():
+            if user:
+                user.step_progress()
             if filt.apply(db, person):
                 self.init_ancestor_list(db, person, first)
+        if user:
+            user.end_progress()
         filt.requestreset()
 
     def reset(self):
