@@ -15,7 +15,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
 #-------------------------------------------------------------------------
@@ -28,7 +28,7 @@ _ = glocale.translation.gettext
 
 #-------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
 #-------------------------------------------------------------------------
 from .. import Rule
@@ -47,9 +47,9 @@ class IsMoreThanNthGenerationDescendantOf(Rule):
     category    = _("Descendant filters")
     description = _("Matches people that are descendants of a specified "
                  "person at least N generations away")
-    
-    
-    def prepare(self ,db):
+
+
+    def prepare(self, db, user):
         self.db = db
         self.map = set()
         try:
