@@ -28,13 +28,12 @@ _ = glocale.translation.gettext
 
 #-------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
 #-------------------------------------------------------------------------
 from ....utils.alive import probably_alive
 from .. import Rule
 from ....datehandler import parser
-from ....constfunc import conv_to_unicode_direct
 
 #-------------------------------------------------------------------------
 # "People probably alive"
@@ -47,9 +46,9 @@ class ProbablyAlive(Rule):
     description = _("Matches people without indications of death that are not too old")
     category    = _('General filters')
 
-    def prepare(self,db):
+    def prepare(self, db, user):
         try:
-            self.current_date = parser.parse(conv_to_unicode_direct(self.list[0]))
+            self.current_date = parser.parse(str(self.list[0]))
         except:
             self.current_date = None
 
