@@ -15,7 +15,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
 #-------------------------------------------------------------------------
@@ -28,7 +28,7 @@ _ = glocale.translation.gettext
 
 #-------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
 #-------------------------------------------------------------------------
 from .._regexpidbase import RegExpIdBase
@@ -39,7 +39,7 @@ from .._regexpidbase import RegExpIdBase
 #
 #-------------------------------------------------------------------------
 class RegExpIdOf(RegExpIdBase):
-    """Rule that checks for a person whose GRAMPS ID
+    """Rule that checks for a person whose Gramps ID
     matches regular expression.
     """
 
