@@ -15,7 +15,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 # gen.filters.rules/Place/_InLatLonNeighborhood.py
 
@@ -30,7 +30,7 @@ _ = glocale.translation.gettext
 
 #-------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
 #-------------------------------------------------------------------------
 from .. import Rule
@@ -46,7 +46,7 @@ class InLatLonNeighborhood(Rule):
         Latitude or Longitude or"""
 
 
-    labels      = [_('Latitude:'), _('Longitude:'), 
+    labels      = [_('Latitude:'), _('Longitude:'),
                     _('Rectangle height:'), _('Rectangle width:')]
     name        = _('Places in neighborhood of given position')
     description = _("Matches places with latitude or longitude positioned in "
@@ -55,7 +55,7 @@ class InLatLonNeighborhood(Rule):
                     )
     category    = _('Position filters')
 
-    def prepare(self,db):
+    def prepare(self, db, user):
         if self.list[0] :
             try:
                 self.halfheight = float(self.list[2])/2.
@@ -67,7 +67,7 @@ class InLatLonNeighborhood(Rule):
             self.halfheight = -1
             #give dummy value
             self.list[0] = '0.0'
-        
+
         if self.list[1] :
             try:
                 self.halfwidth = float(self.list[3])/2.
@@ -79,7 +79,7 @@ class InLatLonNeighborhood(Rule):
             self.halfwidth = -1
             #give dummy value
             self.list[1] = '0.0'
-            
+
         #we allow a band instead of a triangle
         self.lat, self.lon = conv_lat_lon(self.list[0],self.list[1],"D.D8")
         if self.lat is not None and self.lon is not None :
@@ -87,17 +87,17 @@ class InLatLonNeighborhood(Rule):
             self.lon = float(self.lon)
         else :
             self.lat = None; self.lon = None
-            
+
         #we define the two squares we must look in
         #    can be 0, so check on None
         if self.lat is not None and self.halfheight is not None and self.halfheight != -1 :
-            self.S = self.lat + self.halfheight 
+            self.S = self.lat + self.halfheight
             if self.S > 90. : self.S = 90.
-            self.N = self.lat - self.halfheight 
+            self.N = self.lat - self.halfheight
             if self.N < -90. : self.N = -90.
         self.doublesquares = False
         if self.lon is not None and self.halfwidth is not None and self.halfwidth != -1 :
-            if self.halfwidth >= 180. : 
+            if self.halfwidth >= 180. :
                 #the entire longitude is allowed, reset values
                 self.lon = 0.
                 self.E = 180.
@@ -117,26 +117,26 @@ class InLatLonNeighborhood(Rule):
                     self.W2 = self.W + 360.
                     self.E2 = 180.
                     self.W  = -180
-                
-            
+
+
     def apply(self,db,place):
         if self.halfheight == -1 and self.halfwidth ==-1 :
             return False
-        
+
         # when given, must be valid
         if self.lat is None or self.lon is None :
             return False
-        
+
         # if height/width given, they must be valid
         if self.halfheight is None or self.halfwidth is None :
             return False
-        
+
         #now we know at least one is given in the filter and is valid
-        
+
         # the place we look at must have lat AND lon entered
         if not ( place.get_latitude().strip and place.get_longitude().strip() ):
             return False
-        
+
         latpl, lonpl = conv_lat_lon(place.get_latitude(),
                                     place.get_longitude(), "D.D8")
         if latpl and lonpl :
@@ -146,18 +146,18 @@ class InLatLonNeighborhood(Rule):
                 # check lat
                 if latpl < self.N or latpl > self.S :
                     return False
-            
+
             if self.halfwidth != -1 :
                 #check lon: more difficult, we may cross the 180/-180 boundary
                 # and must keep counting
                 if self.doublesquares :
-                    #two squares to look in : 
+                    #two squares to look in :
                     if (lonpl <self.W or lonpl > self.E) and \
                         (lonpl <self.W2 or lonpl > self.E2) :
                         return False
                 elif (lonpl <self.W or lonpl > self.E) :
                     return False
-                    
+
             return True
-            
+
         return False
