@@ -32,7 +32,7 @@ _ = glocale.translation.gettext
 
 #-------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
 #-------------------------------------------------------------------------
 from .. import Rule
@@ -48,9 +48,9 @@ class HasRepository(Rule):
     description = _("Matches sources with a certain number of repository references")
     category    = _('General filters')
 
-    def prepare(self, db):
+    def prepare(self, db, user):
         # things we want to do just once, not for every handle
-        if self.list[1] == 'lesser than':
+        if self.list[1] == 'less than':
             self.count_type = 0
         elif self.list[1] == 'greater than':
             self.count_type = 2
@@ -58,10 +58,10 @@ class HasRepository(Rule):
             self.count_type = 1 # "equal to"
 
         self.userSelectedCount = int(self.list[0])
-        
+
     def apply(self, db, obj):
         count = len(obj.get_reporef_list())
-        if self.count_type == 0:     # "lesser than"
+        if self.count_type == 0:     # "less than"
             return count < self.userSelectedCount
         elif self.count_type == 2:   # "greater than"
             return count > self.userSelectedCount
