@@ -15,25 +15,21 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-"Define text formatting tag types."
-
-#------------------------------------------------------------------------
-#
-# Python modules
-#
-#------------------------------------------------------------------------
-from ..const import GRAMPS_LOCALE as glocale
-_ = glocale.translation.gettext
+"""
+Define text formatting tag types.
+"""
 
 #-------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
 #-------------------------------------------------------------------------
 from .grampstype import GrampsType
+from ..const import GRAMPS_LOCALE as glocale
+_ = glocale.translation.gettext
 
 #-------------------------------------------------------------------------
 #
@@ -41,10 +37,11 @@ from .grampstype import GrampsType
 #
 #-------------------------------------------------------------------------
 class StyledTextTagType(GrampsType):
-    """Text formatting tag type definition.
-    
-    Here we only define new class variables. For details see :class:`~gen.lib.grampstype.GrampsType`.
-    
+    """
+    Text formatting tag type definition.
+
+    Here we only define new class variables. For details see
+    :class:`~gen.lib.grampstype.GrampsType`.
     """
     NONE_TYPE = -1
     BOLD = 0
@@ -56,10 +53,10 @@ class StyledTextTagType(GrampsType):
     HIGHLIGHT = 6
     SUPERSCRIPT = 7
     LINK = 8
-    
+
     _CUSTOM = NONE_TYPE
     _DEFAULT = NONE_TYPE
-    
+
     _DATAMAP = [
         (BOLD, _("Bold"), "bold"),
         (ITALIC, _("Italic"), "italic"),
@@ -83,7 +80,7 @@ class StyledTextTagType(GrampsType):
         SUPERSCRIPT: bool,
         LINK: str,
     }
-    
+
     STYLE_DEFAULT = {
         BOLD: False,
         ITALIC: False,
