@@ -28,7 +28,6 @@
 #------------------------------------------------------------------------
 from ...const import GRAMPS_LOCALE as glocale
 _ = glocale.translation.gettext
-import io
 
 #------------------------------------------------------------------------
 #
@@ -63,19 +62,19 @@ class DocBackendError(Exception):
 
     def __str__(self):
         return self.value
-    
+
 #------------------------------------------------------------------------
 #
 # Document Backend class
 #
 #------------------------------------------------------------------------
 
-class DocBackend(object):
+class DocBackend:
     """
-    Base class for text document backends. 
-    The DocBackend manages a file to which it writes. It further knowns 
-    enough of the file format to be able to translate between the BaseDoc API 
-    and the file format. 
+    Base class for text document backends.
+    The DocBackend manages a file to which it writes. It further knowns
+    enough of the file format to be able to translate between the BaseDoc API
+    and the file format.
     Specifically for text reports a translation of styled notes to the file
     format usage is done.
     """
@@ -88,7 +87,7 @@ class DocBackend(object):
     HIGHLIGHT = 6
     SUPERSCRIPT = 7
     LINK = 8
-    
+
     SUPPORTED_MARKUP = []
 
     ESCAPE_FUNC = lambda: noescape
@@ -97,7 +96,7 @@ class DocBackend(object):
     STYLETYPE_MAP = {
         }
     CLASSMAP = None
-    
+
     #STYLETAGTABLE to store markup for write_markup associated with style tags
     STYLETAG_MARKUP = {
         BOLD        : ("", ""),
@@ -113,16 +112,16 @@ class DocBackend(object):
         """
         self.__file = None
         self._filename = filename
-    
+
     def getf(self):
         """
         Obtain the filename on which backend writes
         """
         return self._filename
-    
+
     def setf(self, value):
         """
-        Set the filename on which the backend writes, changing the value 
+        Set the filename on which the backend writes, changing the value
         passed on initialization.
         Can only be done if the previous filename is not open.
         """
@@ -143,7 +142,7 @@ class DocBackend(object):
                                             % self.filename)
         self._checkfilename()
         try:
-            self.__file = io.open(self.filename, "w", encoding="utf-8")
+            self.__file = open(self.filename, "w", encoding="utf-8")
         except IOError as msg:
             errmsg = "%s\n%s" % (_("Could not create %s") % self.filename, msg)
             raise DocBackendError(errmsg)
@@ -155,7 +154,7 @@ class DocBackend(object):
         Check to make sure filename satisfies the standards for this filetype
         """
         pass
-    
+
     def close(self):
         """
         Closes the file that is written on.
@@ -163,23 +162,23 @@ class DocBackend(object):
         if self.__file is None:
             raise IOError('No file open')
         self.__file.close()
-        self.__file = None        
+        self.__file = None
 
     def write(self, string):
         """
-        Write a string to the file. There is no return value. 
-        Due to buffering, the string may not actually show up until the 
+        Write a string to the file. There is no return value.
+        Due to buffering, the string may not actually show up until the
         :meth:`close` method is called.
         """
         self.__file.write(string)
 
     def writelines(self, sequence):
         """
-        Write a sequence of strings to the file. The sequence can be any 
-        iterable object producing strings, typically a list of strings. 
+        Write a sequence of strings to the file. The sequence can be any
+        iterable object producing strings, typically a list of strings.
         """
         self.__file.writelines(sequence)
-    
+
     def escape(self, preformatted=False):
         """
         The escape func on text for this file format.
@@ -189,25 +188,25 @@ class DocBackend(object):
         :type preformatted: bool
         """
         return self.ESCAPE_FUNC()
-        
-    
+
+
     def find_tag_by_stag(self, s_tag):
         """
         :param s_tag: object: assumed styledtexttag
         :param s_tagvalue: None/int/str: value associated with the tag
-        
+
         A styled tag is type with a value. Every styled tag must be converted
-        to the tags used in the corresponding markup for the backend, 
-        eg <b>text</b> for bold in html. These markups are stored in 
+        to the tags used in the corresponding markup for the backend,
+        eg <b>text</b> for bold in html. These markups are stored in
         STYLETAG_MARKUP. They are tuples for begin and end tag. If a markup is
         not present yet, it is created, using the :meth:`_create_xmltag` method
         you can overwrite.
         """
         tagtype = s_tag.name
-        
+
         if not self.STYLETYPE_MAP or \
         self.CLASSMAP != tagtype.__class__.__name__ :
-            self.CLASSMAP == tagtype.__class__.__name__
+            self.CLASSMAP = tagtype.__class__.__name__
             self.STYLETYPE_MAP[tagtype.BOLD]        = self.BOLD
             self.STYLETYPE_MAP[tagtype.ITALIC]      = self.ITALIC
             self.STYLETYPE_MAP[tagtype.UNDERLINE]   = self.UNDERLINE
@@ -218,7 +217,7 @@ class DocBackend(object):
             self.STYLETYPE_MAP[tagtype.SUPERSCRIPT] = self.SUPERSCRIPT
             self.STYLETYPE_MAP[tagtype.LINK]        = self.LINK
 
-        if s_tag.name == 'Link':
+        if s_tag.name == tagtype.LINK:
             return self.format_link(s_tag.value)
         typeval = int(s_tag.name)
         s_tagvalue = s_tag.value
@@ -231,7 +230,7 @@ class DocBackend(object):
             tag_name = "%d %d" % (typeval, int(s_tagvalue))
         if not tag_name:
             return None
-        
+
         tags = self.STYLETAG_MARKUP.get(tag_name)
         if tags is not None:
             return tags
@@ -248,30 +247,30 @@ class DocBackend(object):
         if tagtype not in self.SUPPORTED_MARKUP:
             return None
         return ('', '')
-    
+
     def add_markup_from_styled(self, text, s_tags, split='', escape=True):
         """
         Input is plain text, output is text with markup added according to the
         s_tags which are assumed to be styledtexttags.
-        When split is given the text will be split over the value given, and 
+        When split is given the text will be split over the value given, and
         tags applied in such a way that it the text can be safely splitted in
         pieces along split.
-        
+
         :param text: str, a piece of text
         :param s_tags: styledtexttags that must be applied to the text
-        :param split: str, optional. A string along which the output can 
+        :param split: str, optional. A string along which the output can
                       be safely split without breaking the styling.
- 
-        As adding markup means original text must be escaped, ESCAPE_FUNC is 
-        used. This can be used to convert the text of a styledtext to the format 
+
+        As adding markup means original text must be escaped, ESCAPE_FUNC is
+        used. This can be used to convert the text of a styledtext to the format
         needed for a document backend.  Do not call this method in a report,
         use the :meth:`write_markup` method.
-            
+
         .. note:: the algorithm is complex as it assumes mixing of tags is not
                   allowed: eg <b>text<i> here</b> not</i> is assumed invalid
                   as markup. If the s_tags require such a setup, what is
                   returned is <b>text</b><i><b> here</b> not</i>
-                  overwrite this method if this complexity is not needed. 
+                  overwrite this method if this complexity is not needed.
         """
         if not escape:
             escape_func = self.ESCAPE_FUNC
@@ -320,7 +319,7 @@ class DocBackend(object):
                         #obtain new values
                         start = start + splitpos + lensplit
                         splitpos = text[start:pos].find(split)
-                    
+
                 otext += self.ESCAPE_FUNC()(text[start:pos])
             #write out tags
             for tag in tagspos[pos]:
@@ -361,7 +360,7 @@ class DocBackend(object):
                         #obtain new values
                         start = start + splitpos + lensplit
                         splitpos = text[start:pos].find(split)
-                    
+
                 otext += self.ESCAPE_FUNC()(text[start:pos])
             for opentag in reversed(opentags):
                 otext += opentag[1]
