@@ -15,7 +15,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
 #-------------------------------------------------------------------------
@@ -31,6 +31,7 @@ import csv
 #
 #-------------------------------------------------------------------------
 from .tabbeddoc import *
+from ...constfunc import win
 
 class CSVTab(TabbedDoc):
 
@@ -48,7 +49,8 @@ class CSVTab(TabbedDoc):
         else:
             self.filename = filename
 
-        self.f = open(self.filename, "w")
+        self.f = open(self.filename, "w",
+                      encoding='utf_8_sig' if win() else 'utf_8')
         self.writer = csv.writer(self.f)
 
     def close(self):
