@@ -1,7 +1,7 @@
 #
 # Gramps - a GTK+/GNOME based genealogy program
 #
-# Copyright (C) 2011	John Ralls, Fremont, CA
+# Copyright (C) 2011    John Ralls, Fremont, CA
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -75,7 +75,7 @@ locale, leaving $LANGUAGE unset (which is the same as setting it to
 #
 #------------------------------------------------------------------------
 
-import sys, os, subprocess, locale
+import os, subprocess, locale
 import logging
 LOG = logging.getLogger(".gramps.gen.utils.grampslocale.mac")
 LOG.propagate = True
@@ -100,8 +100,7 @@ def mac_setup_localization(glocale):
             if not answer:
                 LOG.debug("No prefs found for %s:%s", domain, key)
                 return None
-            if not sys.version_info[0] < 3:
-                answer = answer.decode("utf-8")
+            answer = answer.decode("utf-8")
             LOG.debug("Found %s for defaults %s:%s", answer.strip(), domain, key)
             return answer
         except OSError as err:
@@ -150,7 +149,7 @@ def mac_setup_localization(glocale):
         locale = None
         calendar = None
         currency = None
-        div = locale_string.strip().split(b"@")
+        div = locale_string.strip().split("@")
         LOG.debug("Checking Locale %s", ' '.join(div))
         locale = glocale.check_available_translations(div[0])
         if len(div) > 1:
@@ -299,6 +298,3 @@ def mac_setup_localization(glocale):
         glocale.currency = locale.getlocale(locale.LC_MONETARY)[0] or glocale.lang
 
     glocale.numeric = locale.getlocale(locale.LC_NUMERIC)[0] or glocale.lang
-
-
-
