@@ -16,7 +16,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 # gui/editors/__init__.py
 
@@ -46,6 +46,8 @@ from .edittaglist import EditTagList
 from .editurl import EditUrl
 from .editlink import EditLink
 from .filtereditor import FilterEditor, EditFilter
+from gramps.gen.lib import (Person, Family, Event, Place, Repository, Source,
+                            Citation, Media, Note)
 
 # Map from gramps.gen.lib name to Editor:
 EDITORS = {
@@ -60,36 +62,48 @@ EDITORS = {
     'Note': EditNote,
     }
 
+CLASSES = {
+    'Person': Person,
+    'Event': Event,
+    'Family': Family,
+    'Media': Media,
+    'Source': Source,
+    'Citation': Citation,
+    'Place': Place,
+    'Repository': Repository,
+    'Note': Note,
+    }
+
 def EditObject(dbstate, uistate, track, obj_class, prop=None, value=None, callback=None):
     """
-    Generic Object Editor. 
+    Generic Object Editor.
     obj_class is Person, Source, Repository, etc.
     prop is 'handle', 'gramps_id', or None (for new object)
     value is string handle, string gramps_id, or None (for new object)
     """
     import logging
     LOG = logging.getLogger(".Edit")
-    if obj_class in dbstate.db.get_table_names():
+    if obj_class in EDITORS.keys():
         if value is None:
-            obj = dbstate.db.get_table_metadata(obj_class)["class_func"]()
+            obj = CLASSES[obj_class]
             try:
                 EDITORS[obj_class](dbstate, uistate, track, obj, callback=callback)
             except Exception as msg:
-                LOG.warn(str(msg)) 
+                LOG.warning(str(msg))
         elif prop in ("gramps_id", "handle"):
-            obj = dbstate.db.get_table_metadata(obj_class)[prop + "_func"](value)
+            obj = dbstate.db.method('get_%s_from_%s', obj_class, prop)(value)
             if obj:
                 try:
                     EDITORS[obj_class](dbstate, uistate, track, obj, callback=callback)
                 except Exception as msg:
-                    LOG.warn(str(msg)) 
+                    LOG.warning(str(msg))
             else:
-                LOG.warn("gramps://%s/%s/%s not found" % 
+                LOG.warning("gramps://%s/%s/%s not found" %
                          (obj_class, prop, value))
         else:
-            LOG.warn("unknown property to edit '%s'; "
+            LOG.warning("unknown property to edit '%s'; "
                      "should be 'gramps_id' or 'handle'" % prop)
     else:
-        LOG.warn("unknown object to edit '%s'; "
+        LOG.warning("unknown object to edit '%s'; "
                  "should be one of %s" % (obj_class, list(EDITORS.keys())))
 
