@@ -16,29 +16,29 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-# $Id$
-
 #-------------------------------------------------------------------------
 #
 # Python classes
 #
 #-------------------------------------------------------------------------
-from gramps.gen.const import GRAMPS_LOCALE as glocale
-_ = glocale.translation.gettext
 from gi.repository import Gtk
 from gi.repository import GObject
+from gi.repository import GLib
 
 #-------------------------------------------------------------------------
 #
-# GRAMPS classes
+# Gramps classes
 #
 #-------------------------------------------------------------------------
+from gramps.gen.const import GRAMPS_LOCALE as glocale
+_ = glocale.translation.gettext
 from gramps.gen.lib import Event, EventRef, EventRoleType, EventType
 from gramps.gen.errors import WindowActiveError
 from ...ddtargets import DdTargets
+from .embeddedlist import TEXT_COL, MARKUP_COL, ICON_COL
 from .groupembeddedlist import GroupEmbeddedList
 from .eventrefmodel import EventRefModel
 from ...dbguielement import DbGUIElement
@@ -55,7 +55,7 @@ class EventEmbedList(DbGUIElement, GroupEmbeddedList):
     _DND_TYPE   = DdTargets.EVENTREF
     _DND_EXTRA  = DdTargets.EVENT
     _WORKGROUP = EventRefModel._ROOTINDEX
-    
+
     _WORKNAME = _("Family")
     _FATHNAME = _("Father")
     _MOTHNAME = _("Mother")
@@ -72,20 +72,22 @@ class EventEmbedList(DbGUIElement, GroupEmbeddedList):
     #index = column in model. Value =
     #  (name, sortcol in model, width, markup/text, weigth_col
     _column_names = [
-        (_('Description'), EventRefModel.COL_DESCR[0], 150, 0, -1),
-        (_('Type'), EventRefModel.COL_TYPE[0], 120, 0,
-                                            EventRefModel.COL_FONTWEIGHT[0]),
-        (_('ID'), -1, 100, 0, -1),
-        (_('Date'), EventRefModel.COL_SORTDATE[0], 150, 1, -1),
-        (_('Place'), EventRefModel.COL_PLACE[0], 240, 0, -1),
-        (_('Role'), EventRefModel.COL_ROLE[0], 80, 0, -1),
-        (_('Main Participants'), EventRefModel.COL_PARTIC[0], 240, 0,
-                                            EventRefModel.COL_FONTWEIGHT[0]),
+        (_('Description'), EventRefModel.COL_DESCR[0], 240, TEXT_COL,
+                            EventRefModel.COL_FONTWEIGHT[0], None),
+        (_('Type'), EventRefModel.COL_TYPE[0], 120, TEXT_COL,
+                            EventRefModel.COL_FONTWEIGHT[0], None),
+        (_('ID'), EventRefModel.COL_GID[0], 60, TEXT_COL, -1, None),
+        (_('Date'), EventRefModel.COL_SORTDATE[0], 150, MARKUP_COL, -1, None),
+        (_('Place'), EventRefModel.COL_PLACE[0], 240, 0, -1, None),
+        (_('Role'), EventRefModel.COL_ROLE[0], 80, TEXT_COL, -1, None),
+        (_('Main Participants'), EventRefModel.COL_PARTIC[0], 240, TEXT_COL,
+                            -1, None),
         None,
         None,
         None,
-        (_('Age'), EventRefModel.COL_SORTAGE[0], 60, 0, -1),
-        None
+        (_('Age'), EventRefModel.COL_SORTAGE[0], 60, TEXT_COL, -1, None),
+        None,
+        (_('Private'), EventRefModel.COL_PRIVATE[0], 30, ICON_COL, -1, 'gramps-lock')
         ]
 
     def __init__(self, dbstate, uistate, track, obj, build_model=EventRefModel, **kwargs):
@@ -93,10 +95,10 @@ class EventEmbedList(DbGUIElement, GroupEmbeddedList):
         self._groups = []
         self._data = []
         DbGUIElement.__init__(self, dbstate.db)
-        GroupEmbeddedList.__init__(self, dbstate, uistate, track, _('_Events'), 
-                              build_model, share_button=True, 
+        GroupEmbeddedList.__init__(self, dbstate, uistate, track, _('_Events'),
+                              build_model, share_button=True,
                               move_buttons=True, **kwargs)
-    
+
     def _connect_db_signals(self):
         """
         called on init of DbGUIElement, connect to db as required.
@@ -112,15 +114,15 @@ class EventEmbedList(DbGUIElement, GroupEmbeddedList):
         """
         Callback method called when a tracked event changes (description
         changes, source added, ...)
-        Note that adding an event 
+        Note that adding an event
         """
         self.rebuild_callback()
-    
+
     def event_delete(self, obj):
         """
-        Callback method called when a tracked event is deleted. 
-        There are two possibilities: 
-        * a tracked non-workgroup event is deleted, just rebuilding the view  
+        Callback method called when a tracked event is deleted.
+        There are two possibilities:
+        * a tracked non-workgroup event is deleted, just rebuilding the view
             will correct this.
         * a workgroup event is deleted. The event must be removed from the obj
             so that no inconsistent data is shown.
@@ -143,8 +145,8 @@ class EventEmbedList(DbGUIElement, GroupEmbeddedList):
         self.rebuild_callback()
 
     def get_ref_editor(self):
-        from .. import EditFamilyEventRef
-        return EditFamilyEventRef
+        from .. import EditEventRef
+        return EditEventRef
 
     def get_icon_name(self):
         return 'gramps-event'
@@ -186,14 +188,15 @@ class EventEmbedList(DbGUIElement, GroupEmbeddedList):
 
     def column_order(self):
         """
-        The columns to show as a tuple containing 
+        The columns to show as a tuple containing
         tuples (show/noshow, model column)
         """
         return ((1, 1),  # type
-                (1, 6),  # main participants
+                (1, 0),  # description
                 (1, 3),  # date
                 (1, 4),  # place
-                (1, 0),  # description
+                (1, 6),  # main participants
+                (1, 12), # private
                 (1, 5),  # role
                 (1, 2),  # gramps id
                 (1, 10),  # age
@@ -212,8 +215,9 @@ class EventEmbedList(DbGUIElement, GroupEmbeddedList):
 
         event = None
         for event_ref in self.get_data()[0]:
-            event = self.dbstate.db.get_event_from_handle(event_ref.ref)
-            type_list.append(event.get_type())
+            if event_ref.get_role() == self.default_role():
+                event = self.dbstate.db.get_event_from_handle(event_ref.ref)
+                type_list.append(event.get_type())
 
         _std_types = self.default_types()
         for etype in _std_types:
@@ -245,7 +249,7 @@ class EventEmbedList(DbGUIElement, GroupEmbeddedList):
                     "or another event reference that is associated with "
                     "the same event is being edited.\n\nTo edit this event "
                     "reference, you need to close the event.")
-    
+
     def share_button_clicked(self, obj):
         SelectEvent = SelectorFactory('Event')
 
@@ -261,7 +265,8 @@ class EventEmbedList(DbGUIElement, GroupEmbeddedList):
             except WindowActiveError:
                 from ...dialog import WarningDialog
                 WarningDialog(_("Cannot share this reference"),
-                              self.__blocked_text())
+                              self.__blocked_text(),
+                              parent=self.uistate.window)
 
     def edit_button_clicked(self, obj):
         ref = self.get_selected()
@@ -274,7 +279,8 @@ class EventEmbedList(DbGUIElement, GroupEmbeddedList):
             except WindowActiveError:
                 from ...dialog import WarningDialog
                 WarningDialog(_("Cannot edit this reference"),
-                              self.__blocked_text())
+                              self.__blocked_text(),
+                              parent=self.uistate.window)
         elif ref and ref[0] != self._WORKGROUP:
             #bring up family editor
             key = self._groups[ref[0]][0]
@@ -284,16 +290,16 @@ class EventEmbedList(DbGUIElement, GroupEmbeddedList):
         reference.ref = primary.handle
         data = self.get_data()[self._WORKGROUP]
         data.append(reference)
-        self.callman.register_handles({'event': [primary.handle]}) 
+        self.callman.register_handles({'event': [primary.handle]})
         self.changed = True
         self.rebuild()
-        GObject.idle_add(self.tree.scroll_to_cell,
+        GLib.idle_add(self.tree.scroll_to_cell,
                          (self._WORKGROUP, len(data) - 1))
 
     def object_edited(self, ref, event):
         """
-        Called as callback after eventref has been edited. 
-        Note that if the event changes too (so not only the ref data), then 
+        Called as callback after eventref has been edited.
+        Note that if the event changes too (so not only the ref data), then
         an event-update signal from the database will also be raised, and the
         rebuild done here will not be needed. There is no way to avoid this ...
         """
@@ -305,8 +311,8 @@ class EventEmbedList(DbGUIElement, GroupEmbeddedList):
             return GroupEmbeddedList.get_popup_menu_items(self)
         else:
             return [
-                (True, True, Gtk.STOCK_ADD, self.add_button_clicked),
-                (False,True, Gtk.STOCK_EDIT, self.edit_button_clicked),
+                (True, _('_Add'), self.add_button_clicked),
+                (False, _('_Edit'), self.edit_button_clicked),
                 ]
 
     def _non_native_change(self):
@@ -315,9 +321,9 @@ class EventEmbedList(DbGUIElement, GroupEmbeddedList):
         """
         from ...dialog import WarningDialog
         WarningDialog(
-                    _("Cannot change Person"),
-                    _("You cannot change Person events in the Family Editor")
-                    )
+            _("Cannot change Person"),
+            _("You cannot change Person events in the Family Editor"),
+            parent=self.uistate.window)
 
     def _handle_drag(self, row, obj):
         """
@@ -343,8 +349,8 @@ class EventEmbedList(DbGUIElement, GroupEmbeddedList):
                       "Either the associated event is already being edited "
                       "or another event reference that is associated with "
                       "the same event is being edited.\n\nTo edit this event "
-                      "reference, you need to close the event.")
-                    )
+                      "reference, you need to close the event."),
+                    parent=self.uistate.window)
         else:
             self.dropnotworkgroup(row, obj)
 
@@ -362,7 +368,7 @@ class EventEmbedList(DbGUIElement, GroupEmbeddedList):
     def editnotworkgroup(self, key):
         """
         Edit non native event in own editor
-        """ 
+        """
         person = self.dbstate.db.get_person_from_handle(key)
         try:
             from .. import EditPerson
@@ -382,7 +388,7 @@ class EventEmbedList(DbGUIElement, GroupEmbeddedList):
         we allow to change the default name like this
         """
         self.dropnotworkgroup(None, None)
-    
+
     def move_to_work(self, row_from, row_to, obj):
         """
         move from a non workgroup to the workgroup
@@ -404,10 +410,10 @@ class EventEmbedList(DbGUIElement, GroupEmbeddedList):
 
     def post_rebuild(self, prebuildpath):
         """
-        Allow post rebuild specific handling. 
+        Allow post rebuild specific handling.
         @param prebuildpath: path selected before rebuild, None if none
         @type prebuildpath: tree path
         """
         self.tree.expand_all()
-        if not prebuildpath is None:
+        if prebuildpath is not None:
             self.selection.select_path(prebuildpath)
