@@ -74,7 +74,7 @@ class EditLink(ManagedWindow):
         self.simple_access = SimpleAccess(self.dbstate.db)
         self.callback = callback
 
-        ManagedWindow.__init__(self, uistate, track, url)
+        ManagedWindow.__init__(self, uistate, track, url, modal=True)
 
         self._local_init()
         self._connect_signals()
@@ -142,7 +142,7 @@ class EditLink(ManagedWindow):
     def update_ui(self, widget):
         url = self.url_link.get_text()
         # text needs to have 3 or more chars://and at least one char
-        match = re.match("\w{3,}://\w+", url)
+        match = re.match(r"\w{3,}://\w+", url)
         if match:
             self.ok_button.set_sensitive(True)
         else:
