@@ -42,19 +42,18 @@ from gi.repository import Gdk
 #-------------------------------------------------------------------------
 from gramps.gen.const import GRAMPS_LOCALE as glocale
 _ = glocale.translation.sgettext
-from gramps.gen.constfunc import conv_to_unicode
 from ..utils import open_file_with_default_application
-from gramps.gen.lib import MediaObject, NoteType
+from gramps.gen.lib import Media, NoteType
 from gramps.gen.db import DbTxn
 from gramps.gen.mime import get_description, get_type
-from ..thumbnails import get_thumbnail_image, find_mime_type_pixbuf
+from gramps.gen.utils.thumbnails import get_thumbnail_image, find_mime_type_pixbuf
 from gramps.gen.utils.file import (media_path_full, find_file, create_checksum)
 from .editprimary import EditPrimary
 from ..widgets import (MonitoredDate, MonitoredEntry, PrivacyButton,
                          MonitoredTagList)
 from .displaytabs import (CitationEmbedList, MediaAttrEmbedList, NoteTab,
                          MediaBackRefList)
-from .addmedia import AddMediaObject
+from .addmedia import AddMedia
 from ..dialog import ErrorDialog
 from ..glade import Glade
 from gramps.gen.const import URL_MANUAL_SECT2
@@ -78,15 +77,15 @@ class EditMedia(EditPrimary):
     def __init__(self, dbstate, uistate, track, obj, callback=None):
 
         EditPrimary.__init__(self, dbstate, uistate, track, obj,
-                             dbstate.db.get_object_from_handle, 
-                             dbstate.db.get_object_from_gramps_id, callback)
+                             dbstate.db.get_media_from_handle,
+                             dbstate.db.get_media_from_gramps_id, callback)
         if not self.obj.get_handle():
             #show the addmedia dialog immediately, with track of parent.
-            AddMediaObject(dbstate, self.uistate, self.track, self.obj, 
+            AddMedia(dbstate, self.uistate, self.track, self.obj,
                            self._update_addmedia)
 
     def empty_object(self):
-        return MediaObject()
+        return Media()
 
     def get_menu_title(self):
         if self.obj.get_handle():
@@ -104,12 +103,10 @@ class EditMedia(EditPrimary):
 
     def _local_init(self):
         assert(self.obj)
-        self.width_key = 'interface.media-width'
-        self.height_key = 'interface.media-height'
-        
         self.glade = Glade()
-        self.set_window(self.glade.toplevel, 
+        self.set_window(self.glade.toplevel,
                         None, self.get_menu_title())
+        self.setup_configs('interface.media', 650, 450)
 
     def _connect_signals(self):
         self.define_cancel_button(self.glade.get_object('button91'))
@@ -120,7 +117,7 @@ class EditMedia(EditPrimary):
 
     def _connect_db_signals(self):
         """
-        Connect any signals that need to be connected. 
+        Connect any signals that need to be connected.
         Called by the init routine of the base class (_EditPrimary).
         """
         self._add_db_signal('media-rebuild', self._do_close)
@@ -137,15 +134,15 @@ class EditMedia(EditPrimary):
                                            self.obj.set_description,
                                            self.obj.get_description,
                                            self.db.readonly)
-        
+
         self.gid = MonitoredEntry(self.glade.get_object("gid"),
-                                  self.obj.set_gramps_id, 
+                                  self.obj.set_gramps_id,
                                   self.obj.get_gramps_id, self.db.readonly)
 
         self.tags = MonitoredTagList(
-            self.glade.get_object("tag_label"), 
-            self.glade.get_object("tag_button"), 
-            self.obj.set_tag_list, 
+            self.glade.get_object("tag_label"),
+            self.glade.get_object("tag_button"),
+            self.obj.set_tag_list,
             self.obj.get_tag_list,
             self.db,
             self.uistate, self.track,
@@ -157,7 +154,7 @@ class EditMedia(EditPrimary):
         self.pixmap = self.glade.get_object("pixmap")
         ebox = self.glade.get_object('eventbox')
         ebox.connect('button-press-event', self.button_press_event)
-        
+
         self.mimetext = self.glade.get_object("type")
         self.setup_filepath()
         self.determine_mime()
@@ -187,7 +184,7 @@ class EditMedia(EditPrimary):
         mtype = self.obj.get_mime_type()
         if mtype:
             pb = get_thumbnail_image(
-                        media_path_full(self.db, self.obj.get_path()), 
+                        media_path_full(self.db, self.obj.get_path()),
                         mtype)
             self.pixmap.set_from_pixbuf(pb)
         else:
@@ -208,7 +205,7 @@ class EditMedia(EditPrimary):
         self.citation_tab = CitationEmbedList(self.dbstate,
                                               self.uistate,
                                               self.track,
-                                              self.obj.get_citation_list(), 
+                                              self.obj.get_citation_list(),
                                               self.get_menu_title())
         self._add_tab(notebook, self.citation_tab)
         self.track_ref_for_deletion("citation_tab")
@@ -219,11 +216,11 @@ class EditMedia(EditPrimary):
                                       self.obj.get_attribute_list())
         self._add_tab(notebook, self.attr_tab)
         self.track_ref_for_deletion("attr_tab")
-        
+
         self.note_tab = NoteTab(self.dbstate,
                                 self.uistate,
                                 self.track,
-                                self.obj.get_note_list(), 
+                                self.obj.get_note_list(),
                                 notetype=NoteType.MEDIA)
         self._add_tab(notebook, self.note_tab)
         self.track_ref_for_deletion("note_tab")
@@ -248,18 +245,18 @@ class EditMedia(EditPrimary):
             self.view_media(obj)
 
     def view_media(self, obj):
-        ref_obj = self.dbstate.db.get_object_from_handle(self.obj.handle)
+        ref_obj = self.dbstate.db.get_media_from_handle(self.obj.handle)
 
         if ref_obj:
             media_path = media_path_full(self.dbstate.db,
                                                ref_obj.get_path())
-            open_file_with_default_application(media_path)
+            open_file_with_default_application(media_path, self.uistate)
 
     def select_file(self, val):
         self.determine_mime()
         path = self.file_path.get_text()
-        self.obj.set_path(conv_to_unicode(path))
-        AddMediaObject(self.dbstate, self.uistate, self.track, self.obj, 
+        self.obj.set_path(path)
+        AddMedia(self.dbstate, self.uistate, self.track, self.obj,
                        self._update_addmedia)
 
     def _update_addmedia(self, obj):
@@ -288,7 +285,8 @@ class EditMedia(EditPrimary):
         if self.object_is_empty():
             ErrorDialog(_("Cannot save media object"),
                         _("No data exists for this media object. Please "
-                          "enter data or cancel the edit."))
+                          "enter data or cancel the edit."),
+                        parent=self.window)
             self.ok_button.set_sensitive(True)
             return
 
@@ -298,7 +296,7 @@ class EditMedia(EditPrimary):
             name = prim_object.get_description()
             msg1 = _("Cannot save media object. ID already exists.")
             msg2 = _("You have attempted to use the existing Gramps ID with "
-                         "value %(id)s. This value is already used by '" 
+                         "value %(id)s. This value is already used by '"
                          "%(prim_object)s'. Please enter a different ID or leave "
                          "blank to get the next available ID value.") % {
                          'id' : id, 'prim_object' : name }
@@ -306,36 +304,37 @@ class EditMedia(EditPrimary):
             self.ok_button.set_sensitive(True)
             return
 
-        path = conv_to_unicode(self.file_path.get_text())
+        path = self.file_path.get_text()
         full_path = media_path_full(self.db, path)
         if os.path.isfile(full_path):
             self.determine_mime()
-        else:                                                              
-            msg1 = _("There is no media matching the current path value!") 
-            msg2 = _("You have attempted to use the path with "            
-                            "value '%(path)s'. This path does not exist!"     
-                            " Please enter a different path") % {             
-                            'path' : path }                                   
-            ErrorDialog(msg1, msg2, parent=self.window)                                    
-            self.ok_button.set_sensitive(True)                             
-            return                                                         
+        else:
+            msg1 = _("There is no media matching the current path value!")
+            msg2 = _("You have attempted to use the path with "
+                            "value '%(path)s'. This path does not exist!"
+                            " Please enter a different path") % {
+                            'path' : path }
+            ErrorDialog(msg1, msg2, parent=self.window)
+            self.ok_button.set_sensitive(True)
+            return
 
         self.obj.set_path(path)
 
-        with DbTxn('', self.db) as trans:
-            if not self.obj.get_handle():
-                self.db.add_object(self.obj, trans)
-                msg = _("Add Media Object (%s)") % self.obj.get_description()
-            else:
-                if not self.obj.get_gramps_id():
-                    self.obj.set_gramps_id(self.db.find_next_object_gramps_id())
-                self.db.commit_media_object(self.obj, trans)
-                msg = _("Edit Media Object (%s)") % self.obj.get_description()
-            trans.set_description(msg)
+        if not self.obj.handle:
+            with DbTxn(_("Add Media Object (%s)") % self.obj.get_description(),
+                       self.db) as trans:
+                self.db.add_media(self.obj, trans)
+        else:
+            if self.data_has_changed():
+                with DbTxn(_("Edit Media Object (%s)") % self.obj.get_description(),
+                           self.db) as trans:
+                    if not self.obj.get_gramps_id():
+                        self.obj.set_gramps_id(self.db.find_next_media_gramps_id())
+                    self.db.commit_media(self.obj, trans)
 
         if self.callback:
             self.callback(self.obj)
-        self.close()
+        self._do_close()
 
     def data_has_changed(self):
         """
@@ -344,7 +343,7 @@ class EditMedia(EditPrimary):
         entered date when importing from a XML file, so we can get an
         incorrect fail.
         """
-        
+
         if self.db.readonly:
             return False
         elif self.obj.handle:
@@ -358,18 +357,18 @@ class EditMedia(EditPrimary):
             cmp_obj = self.empty_object()
             return cmp_obj.serialize(True)[1:] != self.obj.serialize()[1:]
 
-class DeleteMediaQuery(object):
+class DeleteMediaQuery:
 
     def __init__(self, dbstate, uistate, media_handle, the_lists):
         self.db = dbstate.db
         self.uistate = uistate
         self.media_handle = media_handle
         self.the_lists = the_lists
-        
+
     def query_response(self):
         with DbTxn(_("Remove Media Object"), self.db) as trans:
             self.db.disable_signals()
-        
+
             (person_list, family_list, event_list,
                     place_list, source_list, citation_list) = self.the_lists
 
@@ -416,4 +415,4 @@ class DeleteMediaQuery(object):
                 self.db.commit_citation(citation, trans)
 
             self.db.enable_signals()
-            self.db.remove_object(self.media_handle, trans)
+            self.db.remove_media(self.media_handle, trans)
