@@ -16,7 +16,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
 #-------------------------------------------------------------------------
@@ -24,17 +24,27 @@
 # python modules
 #
 #-------------------------------------------------------------------------
-from gramps.gen.const import GRAMPS_LOCALE as glocale
-_ = glocale.translation.gettext
 
 #-------------------------------------------------------------------------
 #
 # gramps modules
 #
 #-------------------------------------------------------------------------
+from gramps.gen.const import GRAMPS_LOCALE as glocale
+_ = glocale.translation.sgettext
 from .editsecondary import EditSecondary
 from ..widgets import MonitoredEntry, PrivacyButton, MonitoredDataType
 from ..glade import Glade
+from gramps.gen.const import URL_MANUAL_SECT1
+
+#-------------------------------------------------------------------------
+#
+# Constants
+#
+#-------------------------------------------------------------------------
+
+WIKI_HELP_PAGE = URL_MANUAL_SECT1
+WIKI_HELP_SEC = _('manual|Internet_Address_Editor')
 
 #-------------------------------------------------------------------------
 #
@@ -49,22 +59,23 @@ class EditUrl(EditSecondary):
                                url, callback)
 
     def _local_init(self):
-        self.width_key = 'interface.url-width'
-        self.height_key = 'interface.url-height'
-        
+
         self.top = Glade()
         self.jump = self.top.get_object('jump')
 
         self.set_window(self.top.toplevel,
                         self.top.get_object("title"),
                         _('Internet Address Editor'))
-            
+        self.setup_configs('interface.url', 600, 150)
+
     def _connect_signals(self):
         self.jump.connect('clicked', self.jump_to)
         self.define_cancel_button(self.top.get_object('button125'))
         self.define_ok_button(self.top.get_object('button124'), self.save)
-        self.define_help_button(self.top.get_object('button130'))
-        
+        # TODO help button (rename glade button name)
+        self.define_help_button(self.top.get_object('button130'),
+                WIKI_HELP_PAGE, WIKI_HELP_SEC)
+
     def jump_to(self, obj):
         if self.obj.get_path():
             from ..display import display_url
@@ -72,20 +83,22 @@ class EditUrl(EditSecondary):
 
     def _setup_fields(self):
         self.des  = MonitoredEntry(self.top.get_object("url_des"),
-                                   self.obj.set_description, 
+                                   self.obj.set_description,
                                    self.obj.get_description, self.db.readonly)
 
-        self.addr  = MonitoredEntry(self.top.get_object("url_addr"), 
-                                    self.obj.set_path, self.obj.get_path, 
+        self.addr  = MonitoredEntry(self.top.get_object("url_addr"),
+                                    self.obj.set_path, self.obj.get_path,
                                     self.db.readonly)
-        
+
         self.priv = PrivacyButton(self.top.get_object("priv"),
                                   self.obj, self.db.readonly)
 
-        self.type_sel = MonitoredDataType(self.top.get_object("type"), 
-                                          self.obj.set_type, 
-                                          self.obj.get_type, self.db.readonly)
-            
+        self.type_sel = MonitoredDataType(self.top.get_object("type"),
+                                          self.obj.set_type,
+                                          self.obj.get_type,
+                                          self.db.readonly,
+                                          self.db.get_url_types())
+
     def build_menu_names(self, obj):
         etitle =_('Internet Address Editor')
         return (etitle, etitle)
