@@ -39,7 +39,7 @@ log = logging.getLogger(".filtereditor")
 
 #-------------------------------------------------------------------------
 #
-# GTK/GNOME 
+# GTK/GNOME
 #
 #-------------------------------------------------------------------------
 from gi.repository import Gtk
@@ -48,20 +48,20 @@ from gi.repository import GObject
 
 #-------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
 #-------------------------------------------------------------------------
 from gramps.gen.const import GRAMPS_LOCALE as glocale
 _ = glocale.translation.sgettext
-from gramps.gen.filters import (GenericFilterFactory, FilterList, 
+from gramps.gen.filters import (GenericFilterFactory, FilterList,
                                 reload_custom_filters)
 from gramps.gen.filters.rules._matchesfilterbase import MatchesFilterBase
 from ..listmodel import ListModel
 from ..managedwindow import ManagedWindow
-from ..dialog import QuestionDialog
+from ..dialog import QuestionDialog, ErrorDialog
 from gramps.gen.const import RULE_GLADE, URL_MANUAL_PAGE
 from ..display import display_help
-from gramps.gen.errors import WindowActiveError
+from gramps.gen.errors import WindowActiveError, FilterError
 from gramps.gen.lib import (AttributeType, EventType, FamilyRelType,
                             NameOriginType, NameType, NoteType, PlaceType)
 from gramps.gen.filters import rules
@@ -120,19 +120,19 @@ _name2typeclass = {
 class MyBoolean(Gtk.CheckButton):
 
     def __init__(self, label=None):
-        GObject.GObject.__init__(self)
+        Gtk.CheckButton.__init__(self)
         self.set_label(label)
         self.show()
 
     def get_text(self):
         """
-        Return the text to save. 
-        
-        It should be the same no matter the present locale (English or numeric 
+        Return the text to save.
+
+        It should be the same no matter the present locale (English or numeric
         types).
         This class sets this to get_display_text, but when localization
         is an issue (events/attr/etc types) then it has to be overridden.
-        
+
         """
         return str(int(self.get_active()))
 
@@ -151,7 +151,7 @@ class MyBoolean(Gtk.CheckButton):
 class MyInteger(Gtk.SpinButton):
 
     def __init__(self, min, max):
-        GObject.GObject.__init__(self)
+        Gtk.SpinButton.__init__(self)
         self.set_adjustment(Gtk.Adjustment(value=min, lower=min, upper=max,
                                            step_increment=1))
         self.show()
@@ -174,12 +174,12 @@ class MyFilters(Gtk.ComboBox):
     def __init__(self, filters, filter_name=None):
         """
         Construct the combobox from the entries of the filters list.
-        
+
         Filter_name is name of calling filter.
         If filter_name is given, it will be excluded from the dropdown box.
-        
+
         """
-        GObject.GObject.__init__(self)
+        Gtk.ComboBox.__init__(self)
         store = Gtk.ListStore(GObject.TYPE_STRING)
         self.set_model(store)
         cell = Gtk.CellRendererText()
@@ -194,7 +194,7 @@ class MyFilters(Gtk.ComboBox):
             store.append(row=[fname])
         self.set_active(0)
         self.show()
-        
+
     def get_text(self):
         active = self.get_active()
         if active < 0:
@@ -211,9 +211,9 @@ class MyFilters(Gtk.ComboBox):
 #
 #-------------------------------------------------------------------------
 class MyList(Gtk.ComboBox):
- 
+
     def __init__(self, clist, clist_trans, default=0):
-        GObject.GObject.__init__(self)
+        Gtk.ComboBox.__init__(self)
         store = Gtk.ListStore(GObject.TYPE_STRING)
         self.set_model(store)
         cell = Gtk.CellRendererText()
@@ -224,7 +224,7 @@ class MyList(Gtk.ComboBox):
             store.append(row=[name])
         self.set_active(default)
         self.show()
-    
+
     def get_text(self):
         active = self.get_active()
         return self.clist[active]
@@ -241,7 +241,7 @@ class MyList(Gtk.ComboBox):
 class MyLesserEqualGreater(Gtk.ComboBox):
 
     def __init__(self, default=0):
-        GObject.GObject.__init__(self)
+        Gtk.ComboBox.__init__(self)
         store = Gtk.ListStore(GObject.TYPE_STRING)
         self.set_model(store)
         cell = Gtk.CellRendererText()
@@ -273,13 +273,13 @@ class MyLesserEqualGreater(Gtk.ComboBox):
 #
 #-------------------------------------------------------------------------
 class MyPlaces(Gtk.Entry):
-    
+
     def __init__(self, places):
-        GObject.GObject.__init__(self)
-        
+        Gtk.Entry.__init__(self)
+
         fill_entry(self, places)
         self.show()
-        
+
 #-------------------------------------------------------------------------
 #
 # MyID - Person/GRAMPS ID selection box with a standard interface
@@ -300,9 +300,9 @@ class MyID(Gtk.Box):
         'Note'   : _('Note'),
         'Citation' : _('Citation'),
         }
-    
+
     def __init__(self, dbstate, uistate, track, namespace='Person'):
-        GObject.GObject.__init__(self)
+        Gtk.Box.__init__(self)
         self.set_orientation(Gtk.Orientation.HORIZONTAL)
         self.set_homogeneous(False)
         self.set_spacing(6)
@@ -310,7 +310,7 @@ class MyID(Gtk.Box):
         self.db = dbstate.db
         self.uistate = uistate
         self.track = track
-        
+
         self.namespace = namespace
         self.entry = Gtk.Entry()
         self.entry.show()
@@ -334,7 +334,7 @@ class MyID(Gtk.Box):
             self.set_text('')
         else:
             self.set_text(val.get_gramps_id())
-        
+
     def get_text(self):
         return str(self.entry.get_text())
 
@@ -358,7 +358,7 @@ class MyID(Gtk.Box):
             citation = self.db.get_citation_from_gramps_id(gramps_id)
             name = citation.get_page()
         elif self.namespace == 'Media':
-            obj = self.db.get_object_from_gramps_id(gramps_id)
+            obj = self.db.get_media_from_gramps_id(gramps_id)
             name = obj.get_path()
         elif self.namespace == 'Repository':
             repo = self.db.get_repository_from_gramps_id(gramps_id)
@@ -386,7 +386,7 @@ class MyID(Gtk.Box):
 #
 #-------------------------------------------------------------------------
 class MySource(MyID):
-    
+
     _empty_id_txt = _('Give or select a source ID, leave empty to find objects'
               ' with no source.')
     def __init__(self, dbstate, uistate, track):
@@ -399,7 +399,7 @@ class MySource(MyID):
 #
 #-------------------------------------------------------------------------
 class MySelect(Gtk.ComboBox):
-    
+
     def __init__(self, type_class, additional):
         #we need to inherit and have an combobox with an entry
         Gtk.ComboBox.__init__(self, has_entry=True)
@@ -410,7 +410,7 @@ class MySelect(Gtk.ComboBox):
                                           additional,
                                           type_class._MENU)
         self.show()
-        
+
     def get_text(self):
         return self.type_class(self.sel.get_values()).xml_str()
 
@@ -425,11 +425,11 @@ class MySelect(Gtk.ComboBox):
 #
 #-------------------------------------------------------------------------
 class MyEntry(Gtk.Entry):
-    
+
     def __init__(self):
-        GObject.GObject.__init__(self)
+        Gtk.Entry.__init__(self)
         self.show()
-        
+
 #-------------------------------------------------------------------------
 #
 # EditRule
@@ -439,8 +439,6 @@ class EditRule(ManagedWindow):
     def __init__(self, namespace, dbstate, uistate, track, filterdb, val,
                  label, update, filter_name):
         ManagedWindow.__init__(self, uistate, track, EditRule)
-        self.width_key = "interface.edit-rule-width"
-        self.height_key = "interface.edit-rule-height"
         self.namespace = namespace
         self.dbstate = dbstate
         self.db = dbstate.db
@@ -450,11 +448,13 @@ class EditRule(ManagedWindow):
 
         self.active_rule = val
         self.define_glade('rule_editor', RULE_GLADE)
-        
+
         self.set_window(self.get_widget('rule_editor'),
                         self.get_widget('rule_editor_title'),label)
+        self.setup_configs('interface.edit-rule', 600, 450)
         self.window.hide()
         self.valuebox = self.get_widget('valuebox')
+        self.rname_filter = self.get_widget('ruletreefilter')
         self.rname = self.get_widget('ruletree')
         self.rule_name = self.get_widget('rulename')
         self.description = self.get_widget('description')
@@ -486,7 +486,7 @@ class EditRule(ManagedWindow):
             class_list = rules.repository.editor_rule_list
         elif self.namespace == 'Note':
             class_list = rules.note.editor_rule_list
-        
+
         for class_obj in class_list:
             arglist = class_obj.labels
             vallist = []
@@ -515,7 +515,7 @@ class EditRule(ManagedWindow):
                 elif v == _('Number of generations:'):
                     t = MyInteger(1, 32)
                 elif v == _('ID:'):
-                    t = MyID(self.dbstate, self.uistate, self.track, 
+                    t = MyID(self.dbstate, self.uistate, self.track,
                              self.namespace)
                 elif v == _('Source ID:'):
                     t = MySource(self.dbstate, self.uistate, self.track)
@@ -565,8 +565,7 @@ class EditRule(ManagedWindow):
                 elif v == _('Regular-Expression matching:'):
                     t = MyBoolean(_('Use regular expression'))
                 elif v == _('Include Family events:'):
-                    t = MyBoolean(_('Also family events where person is '
-                                    'wife/husband'))
+                    t = MyBoolean(_('Also family events where person is spouse'))
                 elif v == _('Primary Role:'):
                     t = MyBoolean(_('Only include primary participants'))
                 elif v == _('Tag:'):
@@ -574,7 +573,7 @@ class EditRule(ManagedWindow):
                     taglist = taglist + [tag.get_name() for tag in dbstate.db.iter_tags()]
                     t = MyList(taglist, taglist)
                 elif v == _('Confidence level:'):
-                    t = MyList(list(map(str, list(range(5)))), 
+                    t = MyList(list(map(str, list(range(5)))),
                                [_(conf_strings[i]) for i in range(5)])
                 elif v == _('Date:'):
                     t = DateEntry(self.uistate, self.track)
@@ -582,6 +581,9 @@ class EditRule(ManagedWindow):
                     long_days = displayer.long_days
                     days_of_week = long_days[2:] + long_days[1:2]
                     t = MyList(list(map(str, range(7))), days_of_week)
+                elif v == _('Units:'):
+                    t = MyList([0, 1, 2],
+                               [_('kilometers'), _('miles'), _('degrees')])
                 else:
                     t = MyEntry()
                 t.set_hexpand(True)
@@ -619,11 +621,13 @@ class EditRule(ManagedWindow):
             self.page_num = self.page_num + 1
         self.page_num = 0
         self.store = Gtk.TreeStore(GObject.TYPE_STRING, GObject.TYPE_PYOBJECT)
+        self.ruletree_filter = self.store.filter_new()
+        self.ruletree_filter.set_visible_func(self.rtree_visible_func)
         self.selection = self.rname.get_selection()
-        col = Gtk.TreeViewColumn(_('Rule Name'), Gtk.CellRendererText(), 
+        col = Gtk.TreeViewColumn(_('Rule Name'), Gtk.CellRendererText(),
                                  text=0)
         self.rname.append_column(col)
-        self.rname.set_model(self.store)
+        self.rname.set_model(self.ruletree_filter)
 
         prev = None
         last_top = None
@@ -670,13 +674,14 @@ class EditRule(ManagedWindow):
                 tlist[i].set_text(r[i])
             if class_obj.allow_regex:
                 use_regex.set_active(self.active_rule.use_regex)
-            
+
         self.selection.connect('changed', self.on_node_selected)
         self.rname.connect('button-press-event', self._button_press)
         self.rname.connect('key-press-event', self._key_press)
         self.get_widget('rule_editor_ok').connect('clicked', self.rule_ok)
         self.get_widget('rule_editor_cancel').connect('clicked', self.close_window)
         self.get_widget('rule_editor_help').connect('clicked', self.on_help_clicked)
+        self.rname_filter.connect('changed', self.on_rname_filter_changed)
 
         self._set_size()
         self.show()
@@ -699,8 +704,8 @@ class EditRule(ManagedWindow):
     def _key_press(self, obj, event):
         if event.keyval in (Gdk.KEY_Return, Gdk.KEY_KP_Enter):
             return self.expand_collapse()
-        return False    
-    
+        return False
+
     def expand_collapse(self):
         """
         Expand or collapse the selected parent name node.
@@ -727,7 +732,7 @@ class EditRule(ManagedWindow):
 
     def on_node_selected(self, obj):
         """
-        Update the informational display on the right hand side of the dialog 
+        Update the informational display on the right hand side of the dialog
         box with the description of the selected report.
         """
         store, node = self.selection.get_selected()
@@ -735,6 +740,12 @@ class EditRule(ManagedWindow):
             class_obj = store.get_value(node, 1)
             self.display_values(class_obj)
 
+    def on_rname_filter_changed(self, obj):
+        """
+        Update the ruletree based on the filter.
+        """
+        self.ruletree_filter.refilter()
+
     def display_values(self, class_obj):
         if class_obj in self.class2page:
             page = self.class2page[class_obj]
@@ -765,19 +776,29 @@ class EditRule(ManagedWindow):
         except KeyError:
             pass
 
+    def rtree_visible_func(self, model, iter, data):
+        """
+        Callback function to determine if a row of the tree is visible
+        """
+        filter_text = self.rname_filter.get_text()
+        tree_text = model[iter][0]
+        children = model[iter].iterchildren()
+        result = (not tree_text or
+                children.iter or
+                filter_text.lower() in tree_text.lower())
+        return result
+
 #-------------------------------------------------------------------------
 #
 # EditFilter
 #
 #-------------------------------------------------------------------------
 class EditFilter(ManagedWindow):
-    
+
     def __init__(self, namespace, dbstate, uistate, track, gfilter,
                  filterdb, update=None, selection_callback=None):
 
         ManagedWindow.__init__(self, uistate, track, self)
-        self.width_key = "interface.edit-filter-width"
-        self.height_key = "interface.edit-filter-height"
         self.namespace = namespace
         self.update = update
         self.dbstate = dbstate
@@ -785,20 +806,21 @@ class EditFilter(ManagedWindow):
         self.filter = gfilter
         self.filterdb = filterdb
         self.selection_callback = selection_callback
-        
-        self.define_glade('define_filter', RULE_GLADE)
-        
+
+        self.define_glade('define_filter', RULE_GLADE, also_load=["model1"])
+
         self.set_window(
             self.get_widget('define_filter'),
             self.get_widget('definition_title'),
             _('Define filter'))
-        
+        self.setup_configs('interface.edit-filter', 500, 420)
+
         self.rlist = ListModel(
             self.get_widget('rule_list'),
             [(_('Name'),-1,150),(_('Values'),-1,150)],
             self.select_row,
             self.on_edit_clicked)
-                                         
+
         self.fname = self.get_widget('filter_name')
         self.logical = self.get_widget('rule_apply')
         self.logical_not = self.get_widget('logical_not')
@@ -812,7 +834,7 @@ class EditFilter(ManagedWindow):
         self.edit_btn.connect('clicked', self.on_edit_clicked)
         self.del_btn.connect('clicked', self.on_delete_clicked)
         self.add_btn.connect('clicked', self.on_add_clicked)
-        
+
         self.get_widget('definition_help').connect('clicked',
                                         self.on_help_clicked)
         self.get_widget('definition_cancel').connect('clicked',
@@ -847,7 +869,7 @@ class EditFilter(ManagedWindow):
                  for filt in self.filterdb.get_filters(self.namespace)
                  if filt != self.filter]
         self.ok_btn.set_sensitive((len(name) != 0) and (name not in names))
-    
+
     def select_row(self, obj):
         store, node = self.rlist.get_selected()
         if node:
@@ -861,7 +883,7 @@ class EditFilter(ManagedWindow):
         self.rlist.clear()
         for r in self.filter.get_rules():
             self.rlist.add([r.name,r.display_values()],r)
-            
+
     def on_ok_clicked(self, obj):
         n = str(self.fname.get_text()).strip()
         if n == '':
@@ -877,9 +899,9 @@ class EditFilter(ManagedWindow):
                 break
         val = self.logical.get_active()
         # WARNING: must be listed in this order:
-        op = ('and' if val == 0 else 
-              'or' if val == 1 else 
-              'one' if val == 2 else 
+        op = ('and' if val == 0 else
+              'or' if val == 1 else
+              'one' if val == 2 else
               'sequence')
         self.logical.set_active(val)
         self.filter.set_logical_op(op)
@@ -890,7 +912,7 @@ class EditFilter(ManagedWindow):
         if self.selection_callback:
             self.selection_callback(self.filterdb, self.filter.get_name())
         self.close()
-        
+
     def on_add_clicked(self, obj):
         try:
             EditRule(self.namespace, self.dbstate, self.uistate, self.track,
@@ -923,7 +945,7 @@ class EditFilter(ManagedWindow):
             gfilter = self.rlist.get_object(node)
             self.filter.delete_rule(gfilter)
             self.draw_rules()
-            
+
 #-------------------------------------------------------------------------
 #
 # ShowResults
@@ -942,9 +964,10 @@ class ShowResults(ManagedWindow):
             self.get_widget('test'),
             self.get_widget('test_title'),
             _('Filter Test'))
+        self.setup_configs('interface.showresults', 450, 400)
 
         render = Gtk.CellRendererText()
-        
+
         tree = self.get_widget('list')
         model = Gtk.ListStore(GObject.TYPE_STRING, GObject.TYPE_STRING)
         tree.set_model(model)
@@ -994,7 +1017,7 @@ class ShowResults(ManagedWindow):
             name = _pd.display(self.db, place)
             gid = place.get_gramps_id()
         elif self.namespace == 'Media':
-            obj = self.db.get_object_from_handle(handle)
+            obj = self.db.get_media_from_handle(handle)
             name = obj.get_description()
             gid = obj.get_gramps_id()
         elif self.namespace == 'Repository':
@@ -1008,7 +1031,7 @@ class ShowResults(ManagedWindow):
                 name = name[:80]+"..."
             gid = note.get_gramps_id()
         return (name, gid)
-        
+
     def sort_val_from_handle(self, handle):
         if self.namespace == 'Person':
             name = self.db.get_person_from_handle(handle).get_primary_name()
@@ -1026,7 +1049,7 @@ class ShowResults(ManagedWindow):
             place = self.db.get_place_from_handle(handle)
             sortname = _pd.display(self.db, place)
         elif self.namespace == 'Media':
-            sortname = self.db.get_object_from_handle(handle).get_description()
+            sortname = self.db.get_media_from_handle(handle).get_description()
         elif self.namespace == 'Repository':
             sortname = self.db.get_repository_from_handle(handle).get_name()
         elif self.namespace == 'Note':
@@ -1047,8 +1070,6 @@ class FilterEditor(ManagedWindow):
         self.db = dbstate.db
         self.filterdb = FilterList(filterdb)
         self.filterdb.load()
-        self.width_key = "interface.filter-editor-width"
-        self.height_key = "interface.filter-editor-height"
         self.namespace = namespace
 
         self.define_glade('filter_list', RULE_GLADE)
@@ -1065,7 +1086,8 @@ class FilterEditor(ManagedWindow):
 
         self.set_window(self.get_widget('filter_list'),
                         self.get_widget('filter_list_title'),
-                        _TITLES[self.namespace]) 
+                        _TITLES[self.namespace])
+        self.setup_configs('interface.filter-editor', 400, 350)
 
         self.edit.connect('clicked', self.edit_filter)
         self.clone.connect('clicked', self.clone_filter)
@@ -1075,7 +1097,7 @@ class FilterEditor(ManagedWindow):
         self.connect_button('filter_list_help', self.help_clicked)
         self.connect_button('filter_list_close', self.close)
         self.connect_button('filter_list_add', self.add_new_filter)
-        
+
         self.uistate.connect('filter-name-changed', self.clean_after_rename)
 
         self.clist = ListModel(
@@ -1089,7 +1111,7 @@ class FilterEditor(ManagedWindow):
 
     def build_menu_names(self, obj):
         return (_("Custom Filter Editor"), _("Custom Filter Editor"))
-        
+
     def help_clicked(self, obj):
         """Display the relevant portion of Gramps manual"""
         display_help(webpage=WIKI_HELP_PAGE,
@@ -1107,14 +1129,14 @@ class FilterEditor(ManagedWindow):
             self.clone.set_sensitive(False)
             self.delete.set_sensitive(False)
             self.test.set_sensitive(False)
-    
+
     def close(self, *obj):
         self.filterdb.save()
         reload_custom_filters()
         #reload_system_filters()
         self.uistate.emit('filters-changed', (self.namespace,))
         ManagedWindow.close(self, *obj)
-        
+
     def draw_filters(self):
         self.clist.clear()
         for f in self.filterdb.get_filters(self.namespace):
@@ -1145,7 +1167,12 @@ class FilterEditor(ManagedWindow):
         store, node = self.clist.get_selected()
         if node:
             filt = self.clist.get_object(node)
-            handle_list = filt.apply(self.db, self.get_all_handles())
+            try:
+                handle_list = filt.apply(self.db, self.get_all_handles())
+            except FilterError as msg:
+                (msg1, msg2) = msg.messages()
+                ErrorDialog(msg1, msg2, parent=self.window)
+                return
             ShowResults(self.db, self.uistate, self.track, handle_list,
                         filt.get_name(),self.namespace)
 
@@ -1157,12 +1184,12 @@ class FilterEditor(ManagedWindow):
             if self.check_recursive_filters(self.namespace, name):
                 QuestionDialog( _('Delete Filter?'),
                                 _('This filter is currently being used '
-                                  'as the base for other filters. Deleting'
+                                  'as the base for other filters. Deleting '
                                   'this filter will result in removing all '
                                   'other filters that depend on it.'),
                                 _('Delete Filter'),
                                 self._do_delete_selected_filter,
-                                self.window)
+                                parent=self.window)
             else:
                 self._do_delete_selected_filter()
 
@@ -1190,7 +1217,7 @@ class FilterEditor(ManagedWindow):
 
         The filter_set is amended with the found filters.
         """
-        filters = self.filterdb.get_filters(space)        
+        filters = self.filterdb.get_filters(space)
         name = gfilter.get_name()
         for the_filter in filters:
             if the_filter.get_name() == name:
@@ -1219,7 +1246,7 @@ class FilterEditor(ManagedWindow):
         elif self.namespace == 'Place':
             return self.db.iter_place_handles()
         elif self.namespace == 'Media':
-            return self.db.get_media_object_handles()
+            return self.db.get_media_handles()
         elif self.namespace == 'Repository':
             return self.db.get_repository_handles()
         elif self.namespace == 'Note':
