@@ -38,6 +38,7 @@ from gi.repository import Gdk
 #-------------------------------------------------------------------------
 from gramps.gen.plug import (START, END)
 from .pluginmanager import GuiPluginManager
+from .actiongroup import ActionGroup
 
 #-------------------------------------------------------------------------
 #
@@ -75,7 +76,7 @@ CATEGORY_ICON = {
 # Navigator class
 #
 #-------------------------------------------------------------------------
-class Navigator(object):
+class Navigator:
     """
     A class which defines the graphical representation of the Gramps navigator.
     """
@@ -91,19 +92,19 @@ class Navigator(object):
         self.cat_view_group = None
         self.merge_ids = []
 
-        self.top = Gtk.VBox()
-        
+        self.top = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
+
         frame = Gtk.Frame()
-        hbox = Gtk.HBox()
+        hbox = Gtk.Box()
         hbox.show()
         frame.add(hbox)
         frame.show()
-        
+
         self.select_button = Gtk.ToggleButton()
         self.select_button.set_relief(Gtk.ReliefStyle.NONE)
-        select_hbox = Gtk.HBox()
+        select_hbox = Gtk.Box()
         self.title_label = Gtk.Label(label='')
-        arrow = Gtk.Arrow(arrow_type=Gtk.ArrowType.DOWN, 
+        arrow = Gtk.Arrow(arrow_type=Gtk.ArrowType.DOWN,
                                     shadow_type=Gtk.ShadowType.NONE)
         select_hbox.pack_start(self.title_label, False, True, 0)
         select_hbox.pack_end(arrow, False, True, 0)
@@ -113,14 +114,14 @@ class Navigator(object):
                                    self.__menu_button_pressed)
 
         #close_button = Gtk.Button()
-        #img = Gtk.Image.new_from_stock(Gtk.STOCK_CLOSE, Gtk.IconSize.MENU)
+        #img = Gtk.Image.new_from_icon_name('window-close', Gtk.IconSize.MENU)
         #close_button.set_image(img)
         #close_button.set_relief(Gtk.ReliefStyle.NONE)
         #close_button.connect('clicked', self.cb_close_clicked)
         hbox.pack_start(self.select_button, False, True, 0)
         #hbox.pack_end(close_button, False, True, 0)
 
-        self.top.pack_end(frame, False, True, 0)        
+        self.top.pack_end(frame, False, True, 0)
 
         self.menu = Gtk.Menu()
         self.menu.show()
@@ -133,7 +134,7 @@ class Navigator(object):
         self.notebook.connect('switch_page', self.cb_switch_page)
         self.top.show()
         self.top.pack_start(self.notebook, True, True, 0)
-        
+
     def load_plugins(self, dbstate, uistate):
         """
         Load the sidebar plugins.
@@ -166,7 +167,7 @@ class Navigator(object):
                 stock_icon = page[0].stock_icon
                 if stock_icon is None:
                     stock_icon = cat_icon
-                self.view_toggle_actions[cat_num].append((pageid, 
+                self.view_toggle_actions[cat_num].append((pageid,
                             stock_icon,
                             page[0].name, modifier, page[0].name, view_num))
 
@@ -192,7 +193,7 @@ class Navigator(object):
         Return the top container widget for the GUI.
         """
         return self.top
-        
+
     def add(self, title, sidebar, order):
         """
         Add a page to the sidebar for a plugin.
@@ -222,13 +223,13 @@ class Navigator(object):
         # Add buttons to the menu for the different view in the category
         uimanager = self.viewmanager.uimanager
         if self.cat_view_group:
-            if self.cat_view_group in uimanager.get_action_groups(): 
+            if self.cat_view_group in uimanager.get_action_groups():
                 uimanager.remove_action_group(self.cat_view_group)
-                
+
             list(map(uimanager.remove_ui, self.merge_ids))
 
         if cat_num in self.ui_category:
-            self.cat_view_group = Gtk.ActionGroup(name='viewmenu')
+            self.cat_view_group = ActionGroup(name='viewmenu')
             self.cat_view_group.add_radio_actions(
                     self.view_toggle_actions[cat_num], value=view_num,
                     on_change=self.cb_view_clicked, user_data=cat_num)
@@ -265,7 +266,7 @@ class Navigator(object):
     def cb_menu_activate(self, menu, index):
         """
         Called when an item in the popup menu is selected.
-        """        
+        """
         self.notebook.set_current_page(index)
 
     def cb_switch_page(self, notebook, unused, index):
@@ -292,14 +293,22 @@ class Navigator(object):
 # Functions
 #
 #-------------------------------------------------------------------------
-def cb_menu_position(menu, button):
+def cb_menu_position(*args):
     """
     Determine the position of the popup menu.
     """
+    # takes two argument: menu, button
+    if len(args) == 2:
+        menu = args[0]
+        button = args[1]
+    # broken introspection can't handle MenuPositionFunc annotations corectly
+    else:
+        menu = args[0]
+        button = args[3]
     ret_val, x_pos, y_pos = button.get_window().get_origin()
     x_pos += button.get_allocation().x
     y_pos += button.get_allocation().y + button.get_allocation().height
-    
+
     return (x_pos, y_pos, False)
 
 def cb_menu_deactivate(menu, button):
