@@ -2,7 +2,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2007-2008 Donald N. Allingham
-# Copyright (C) 2008      Gary Burton 
+# Copyright (C) 2008      Gary Burton
 # Copyright (C) 2008      Robert Cheramy <robert@cheramy.net>
 #
 # This program is free software; you can redistribute it and/or modify
@@ -30,29 +30,44 @@
 
 #-------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
 #-------------------------------------------------------------------------
-from gramps.gen.const import GRAMPS_LOCALE as glocale
+from gramps.gen.const import COLON, GRAMPS_LOCALE as glocale
 _ = glocale.translation.gettext
 ngettext = glocale.translation.ngettext # else "nearby" comments are ignored
 from gramps.gen.config import config
 from gramps.gen.display.name import displayer as name_displayer
 from gramps.gen.filters import GenericFilter, rules
 from ...utils import ProgressMeter
-from gramps.gen.proxy import (PrivateProxyDb, 
-                              LivingProxyDb, 
-                              FilterProxyDb, 
+from ...user import User
+from gramps.gen.proxy import (PrivateProxyDb,
+                              LivingProxyDb,
+                              FilterProxyDb,
                               ReferencedBySelectionProxyDb)
-        
-class Progress(object):
+
+#-------------------------------------------------------------------------
+#
+# Attempt to load the GZIP library. Some version of python do not seem
+# to be compiled with this available.
+#
+#-------------------------------------------------------------------------
+try:
+    import gzip
+    _gzip_ok = 1
+except:
+    _gzip_ok = 0
+
+class Progress:
     """
     Mirros the same interface that the ExportAssistant uses in the
     selection, but this is for the preview selection.
     """
-    def __init__(self):
+    def __init__(self, parent):
         from gi.repository import Gtk
-        self.pm = ProgressMeter(_("Selecting Preview Data"), _('Selecting...'))
+        self.pm = ProgressMeter(_("Selecting Preview Data"),
+                                _('Selecting...'),
+                                parent=parent)
         self.progress_cnt = 0
         self.title = _("Selecting...")
         while Gtk.events_pending():
@@ -86,16 +101,18 @@ class Progress(object):
 # WriterOptionBox
 #
 #-------------------------------------------------------------------------
-class WriterOptionBox(object):
+class WriterOptionBox:
     """
     Create a VBox with the option widgets and define methods to retrieve
     the options.
-     
+
     """
-    def __init__(self, person, dbstate, uistate):
+    def __init__(self, person, dbstate, uistate, track=[], window=None):
         self.person = person
         self.dbstate = dbstate
         self.uistate = uistate
+        self.track = track
+        self.window = window
         self.preview_dbase = None
         self.preview_button = None
         self.preview_proxy_button = {}
@@ -114,7 +131,7 @@ class WriterOptionBox(object):
         self.initialized_show_options = False
         self.set_config(config)
         # The following are special properties. Create them to force the
-        # export wizard to not ask for a file, and to override the 
+        # export wizard to not ask for a file, and to override the
         # confirmation message:
         #self.no_fileselect = True
         #self.confirm_text = "You made it, kid!"
@@ -137,13 +154,14 @@ class WriterOptionBox(object):
         self.parse_options()
 
     def get_option_box(self):
-        """Build up a Gtk.Table that contains the standard options."""
+        """Build up a Gtk.Box that contains the standard options."""
         from gi.repository import Gtk
         from gi.repository import Pango
-        widget = Gtk.VBox()
-        
-        full_database_row = Gtk.HBox()
-        full_database_row.pack_start(Gtk.Label(_("Unfiltered Family Tree:")), True, True, 0)
+        widget = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
+
+        full_database_row = Gtk.Box()
+        label = Gtk.Label(label=_("Unfiltered Family Tree:"))
+        full_database_row.pack_start(label, True, True, 0)
         people_count = len(self.dbstate.db.get_person_handles())
         # translators: leave all/any {...} untranslated
         button = Gtk.Button(ngettext("{number_of} Person",
@@ -154,12 +172,12 @@ class WriterOptionBox(object):
         button.connect("clicked", self.show_preview_data)
         button.proxy_name = "unfiltered"
         self.preview_proxy_button["unfiltered"] = button
-        self.spacer = Gtk.HBox()
+        self.spacer = Gtk.Box()
         full_database_row.pack_end(self.spacer, False, True, 0)
         full_database_row.pack_end(button, False, True, 0)
 
         widget.pack_start(full_database_row, False, True, 0)
-        
+
         self.private_check = Gtk.CheckButton.new_with_mnemonic(
             _('_Do not include records marked private'))
         self.private_check.connect("clicked", self.mark_dirty)
@@ -175,13 +193,13 @@ class WriterOptionBox(object):
             widget.pack_start(frame, False, True, 0)
             row += 1
 
-        hbox = Gtk.HBox()
-        self.advanced_button = Gtk.Button(_("Change order"))
+        hbox = Gtk.Box()
+        self.advanced_button = Gtk.Button(label=_("Change order"))
         self.advanced_button.set_size_request(150, -1)
         self.proxy_options_showing = False
         self.advanced_button.connect("clicked", self.show_options)
         hbox.pack_end(self.advanced_button, False, True, 0)
-        self.preview_button = Gtk.Button(_("Calculate Previews"))
+        self.preview_button = Gtk.Button(label=_("Calculate Previews"))
         self.preview_button.connect("clicked", self.preview)
         hbox.pack_end(self.preview_button, False, True, 0)
         widget.pack_start(hbox, False, True, 0)
@@ -230,16 +248,17 @@ class WriterOptionBox(object):
             dbstate.db = self.proxy_dbase[widget.proxy_name]
             dbstate.open = True
         run_quick_report_by_name(dbstate,
-                                 self.uistate, 
-                                 'filterbyname', 
-                                 'all')
+                                 self.uistate,
+                                 'filterbyname',
+                                 'all',
+                                 track=self.track)
 
     def preview(self, widget):
         """
         Calculate previews to see the selected data.
         """
         self.parse_options()
-        pm = Progress()
+        pm = Progress(self.window)
         self.preview_dbase = self.get_filtered_database(self.dbstate.db, pm, preview=True)
         pm.close()
         self.preview_button.set_sensitive(0)
@@ -261,16 +280,17 @@ class WriterOptionBox(object):
         if proxy_name == "person":
             # Frame Person:
             self.filter_obj = Gtk.ComboBox()
-            label = Gtk.Label(label=_('_Person Filter') + ": ")
-            label.set_alignment(0, 0.5)
-            label.set_size_request(150, -1)
+            label = Gtk.Label(label=_('_Person Filter') + COLON)
+            label.set_halign(Gtk.Align.START)
+            label.set_size_request(120, -1)
+            label.set_padding(5, 0)
             label.set_use_underline(True)
             label.set_mnemonic_widget(self.filter_obj)
-            box = Gtk.HBox()
+            box = Gtk.Box()
             box.pack_start(label, False, True, 0)
             box.pack_start(self.filter_obj, True, True, 0)
             box.pack_start(
-                SimpleButton(Gtk.STOCK_EDIT, 
+                SimpleButton('gtk-edit',
                    lambda obj: self.edit_filter('Person', self.filter_obj)),
                 False, True, 0)
             button.set_tooltip_text(_("Click to see preview after person filter"))
@@ -278,34 +298,37 @@ class WriterOptionBox(object):
             # Frame Note:
             # Objects for choosing a Note filter:
             self.filter_note = Gtk.ComboBox()
-            label_note = Gtk.Label(label=_('_Note Filter') + ": ")
-            label_note.set_alignment(0, 0.5)
-            label_note.set_size_request(150, -1)
+            label_note = Gtk.Label(label=_('_Note Filter') + COLON)
+            label_note.set_halign(Gtk.Align.START)
+            label_note.set_size_request(120, -1)
+            label_note.set_padding(5, 0)
             label_note.set_use_underline(True)
             label_note.set_mnemonic_widget(self.filter_note)
-            box = Gtk.HBox()
+            box = Gtk.Box()
             box.pack_start(label_note, False, True, 0)
             box.pack_start(self.filter_note, True, True, 0)
             box.pack_start(
-                SimpleButton(Gtk.STOCK_EDIT, 
+                SimpleButton('gtk-edit',
                    lambda obj: self.edit_filter('Note', self.filter_note)),
                 False, True, 0)
             button.set_tooltip_text(_("Click to see preview after note filter"))
         elif proxy_name == "privacy":
             # Frame 3:
-            label = Gtk.Label(label=_("Privacy Filter") + ":")
-            label.set_alignment(0, 0.5)
-            label.set_size_request(150, -1)
-            box = Gtk.HBox()
+            label = Gtk.Label(label=_("Privacy Filter") + COLON)
+            label.set_halign(Gtk.Align.START)
+            label.set_size_request(120, -1)
+            label.set_padding(5, 0)
+            box = Gtk.Box()
             box.pack_start(label, False, True, 0)
             box.add(self.private_check)
             button.set_tooltip_text(_("Click to see preview after privacy filter"))
         elif proxy_name == "living":
             # Frame 4:
-            label = Gtk.Label(label=_("Living Filter") + ":")
-            label.set_alignment(0, 0.5)
-            label.set_size_request(150, -1)
-            box = Gtk.HBox()
+            label = Gtk.Label(label=_("Living Filter") + COLON)
+            label.set_halign(Gtk.Align.START)
+            label.set_size_request(120, -1)
+            label.set_padding(5, 0)
+            box = Gtk.Box()
             box.pack_start(label, False, True, 0)
             self.restrict_option = Gtk.ComboBox()
             box.add(self.restrict_option)
@@ -313,10 +336,11 @@ class WriterOptionBox(object):
         elif proxy_name == "reference":
             # Frame 5:
             self.reference_filter = Gtk.ComboBox()
-            label = Gtk.Label(label=_('Reference Filter') + ": ")
-            label.set_alignment(0, 0.5)
-            label.set_size_request(150, -1)
-            box = Gtk.HBox()
+            label = Gtk.Label(label=_('Reference Filter') + COLON)
+            label.set_halign(Gtk.Align.START)
+            label.set_size_request(120, -1)
+            label.set_padding(5, 0)
+            box = Gtk.Box()
             box.pack_start(label, False, True, 0)
             box.pack_start(self.reference_filter, True, True, 0)
             button.set_tooltip_text(_("Click to see preview after reference filter"))
@@ -324,25 +348,23 @@ class WriterOptionBox(object):
             raise AttributeError("Unknown proxy '%s'" % proxy_name)
 
         frame = Gtk.Frame()
-        hbox = Gtk.HBox()
+        hbox = Gtk.Box()
         frame.add(hbox)
-        vbox = Gtk.HBox()
+        vbox = Gtk.Box()
         self.vbox_n.append(vbox)
         up = Gtk.Button()
         up.connect("clicked", self.swap)
         if row == 0:
             up.set_sensitive(0) # can't go up
         image = Gtk.Image()
-        image.set_from_stock(Gtk.STOCK_GO_UP,
-                             Gtk.IconSize.MENU)
+        image.set_from_icon_name('go-up', Gtk.IconSize.MENU)
         up.set_image(image)
         up.row = row - 1
         self.up_n.append(up)
         down = Gtk.Button()
         down.connect("clicked", self.swap)
         image = Gtk.Image()
-        image.set_from_stock(Gtk.STOCK_GO_DOWN,
-                             Gtk.IconSize.MENU)
+        image.set_from_icon_name('go-down', Gtk.IconSize.MENU)
         down.set_image(image)
         down.row = row
         if row == 4:
@@ -381,17 +403,15 @@ class WriterOptionBox(object):
                     self.vbox_n[n].pack_end(self.down_n[n], False, True, 0)
                 # some spacer buttons:
                 up = Gtk.Button()
-                up.set_sensitive(0) 
+                up.set_sensitive(0)
                 image = Gtk.Image()
-                image.set_from_stock(Gtk.STOCK_GO_UP,
-                                     Gtk.IconSize.MENU)
+                image.set_from_icon_name('go-up', Gtk.IconSize.MENU)
                 up.set_image(image)
                 self.spacer.pack_start(up, False, True, 0)
                 down = Gtk.Button()
-                down.set_sensitive(0) 
+                down.set_sensitive(0)
                 image = Gtk.Image()
-                image.set_from_stock(Gtk.STOCK_GO_DOWN,
-                                     Gtk.IconSize.MENU)
+                image.set_from_icon_name('go-down', Gtk.IconSize.MENU)
                 down.set_image(image)
                 self.spacer.pack_end(down, False, True, 0)
                 self.spacer_up = up
@@ -401,12 +421,12 @@ class WriterOptionBox(object):
             for n in range(5):
                 self.up_n[n].show()
                 self.down_n[n].show()
-            
+
         self.proxy_options_showing = not self.proxy_options_showing
 
     def swap(self, widget):
         """
-        Swap the order of two proxies. 
+        Swap the order of two proxies.
         """
         row1 = widget.row
         row2 = widget.row + 1
@@ -416,8 +436,11 @@ class WriterOptionBox(object):
         widget2 = self.proxy_widget[proxy2]
         parent1 = widget1.get_parent()
         parent2 = widget2.get_parent()
-        widget1.reparent(parent2)
-        widget2.reparent(parent1)
+        # widget reparent is deprecated from Gtk 3.14. use remove then add.
+        parent1.remove(widget1)
+        parent2.remove(widget2)
+        parent1.add(widget2)
+        parent2.add(widget1)
         self.swap_proxy_order(row1, row2)
         self.mark_dirty(widget)
 
@@ -431,17 +454,17 @@ class WriterOptionBox(object):
         # feature request 2356: avoid genitive form
         des.set_name(_("Descendants of %s") % name)
         des.add_rule(rules.person.IsDescendantOf([gramps_id, 1]))
-        
+
         df = GenericFilter()
         # feature request 2356: avoid genitive form
         df.set_name(_("Descendant Families of %s") % name)
         df.add_rule(rules.person.IsDescendantFamilyOf([gramps_id, 1]))
-        
+
         ans = GenericFilter()
         # feature request 2356: avoid genitive form
         ans.set_name(_("Ancestors of %s") % name)
         ans.add_rule(rules.person.IsAncestorOf([gramps_id, 1]))
-        
+
         com = GenericFilter()
         com.set_name(_("People with common ancestor with %s") % name)
         com.add_rule(rules.person.HasCommonAncestorWith([gramps_id]))
@@ -449,11 +472,11 @@ class WriterOptionBox(object):
         return [des, df, ans, com]
 
     def get_proxy_value(self, proxy_name):
-        return [value for (name, value) in 
+        return [value for (name, value) in
                 self.config.get('export.proxy-order') if name == proxy_name][0]
 
     def set_proxy_value(self, proxy_name, proxy_value):
-        [name_value for name_value in 
+        [name_value for name_value in
          self.config.get('export.proxy-order') if name_value[0] == proxy_name][0][1] = int(proxy_value)
 
     def get_proxy_names(self):
@@ -465,12 +488,12 @@ class WriterOptionBox(object):
 
     def parse_options(self):
         """
-        Extract the common values from the GTK widgets. 
-        
+        Extract the common values from the GTK widgets.
+
         After this function is called, the following variables are defined:
 
            private  = privacy requested
-           restrict = restrict information on living peoplel
+           restrict = restrict information on living people
            cfitler  = return the GenericFilter selected
            nfilter  = return the NoteFilter selected
            reference = restrict referenced/orphaned records
@@ -493,7 +516,7 @@ class WriterOptionBox(object):
             if node:
                 self.restrict_num = model[node][1]
             self.set_proxy_value("living", self.restrict_option.get_active())
-        
+
         if self.filter_note:
             model = self.filter_note.get_model()
             node = self.filter_note.get_active_iter()
@@ -559,7 +582,7 @@ class WriterOptionBox(object):
     def apply_proxy(self, proxy_name, dbase, progress=None):
         """
         Apply the named proxy to the dbase, and return.
-        proxy_name is one of 
+        proxy_name is one of
            ["person", "note", "privacy", "living", "reference"]
         """
         # If the private flag is set, apply the PrivateProxyDb
@@ -567,8 +590,8 @@ class WriterOptionBox(object):
             if self.private:
                 if progress:
                     progress.reset(_("Filtering private data"))
-                    progress.progress_cnt += 1
                     progress.update(progress.progress_cnt)
+                    progress.progress_cnt += 1
                 dbase = PrivateProxyDb(dbase)
 
         # If the restrict flag is set, apply the LivingProxyDb
@@ -576,43 +599,44 @@ class WriterOptionBox(object):
             if self.restrict_num > 0:
                 if progress:
                     progress.reset(_("Filtering living persons"))
-                    progress.progress_cnt += 1
                     progress.update(progress.progress_cnt)
+                    progress.progress_cnt += 1
                 mode = [None, # include living
                         LivingProxyDb.MODE_INCLUDE_LAST_NAME_ONLY,
+                        LivingProxyDb.MODE_REPLACE_COMPLETE_NAME,
                         LivingProxyDb.MODE_EXCLUDE_ALL,
-                        ][self.restrict_num]
+                       ][self.restrict_num]
                 dbase = LivingProxyDb(
-                            dbase, 
-                            mode) # 
+                            dbase,
+                            mode) #
 
-        # If the filter returned by cfilter is not empty, apply the 
+        # If the filter returned by cfilter is not empty, apply the
         # FilterProxyDb (Person Filter)
         elif proxy_name == "person":
             if self.cfilter != None and not self.cfilter.is_empty():
                 if progress:
                     progress.reset(_("Applying selected person filter"))
-                    progress.progress_cnt += 1
                     progress.update(progress.progress_cnt)
-                dbase = FilterProxyDb(
-                    dbase, self.cfilter)
+                    progress.progress_cnt += 1
+                dbase = FilterProxyDb(dbase, self.cfilter,
+                                      user=User(parent=self.window))
 
         # Apply the Note Filter
         elif proxy_name == "note":
             if self.nfilter != None and not self.nfilter.is_empty():
                 if progress:
                     progress.reset(_("Applying selected note filter"))
-                    progress.progress_cnt += 1
                     progress.update(progress.progress_cnt)
-                dbase = FilterProxyDb(
-                    dbase, note_filter=self.nfilter)
+                    progress.progress_cnt += 1
+                dbase = FilterProxyDb(dbase, note_filter=self.nfilter,
+                                      user=User(parent=self.window))
 
         # Apply the ReferencedBySelection
         elif proxy_name == "reference":
-            if progress:
+            if self.reference_num > 0 and progress:
                 progress.reset(_("Filtering referenced records"))
-                progress.progress_cnt += 1
                 progress.update(progress.progress_cnt)
+                progress.progress_cnt += 1
             if self.reference_num == 0:
                 pass
             elif self.reference_num == 1:
@@ -646,13 +670,14 @@ class WriterOptionBox(object):
         else:
             the_filter = GenericFilterFactory(namespace)()
         if the_filter:
-            EditFilter(namespace, self.dbstate, self.uistate, [],
+            EditFilter(namespace, self.dbstate, self.uistate, self.track,
                        the_filter, filterdb,
                        lambda : self.edit_filter_save(filterdb, namespace))
         else: # can't edit this filter
             from ...dialog import ErrorDialog
-            ErrorDialog(_("Cannot edit a system filter"), 
-                        _("Please select a different filter to edit"))
+            ErrorDialog(_("Cannot edit a system filter"),
+                        _("Please select a different filter to edit"),
+                        parent=self.window)
 
     def edit_filter_save(self, filterdb, namespace):
         """
@@ -705,10 +730,11 @@ class WriterOptionBox(object):
         elif namespace == "living":
             model = Gtk.ListStore(GObject.TYPE_STRING, int)
             row = 0
-            for item in [
-                _('Include all selected people'),
-                _('Replace given names of living people'),
-                _('Do not include living people')]:
+            for item in [_('Include all selected people'),
+                         _('Replace given names of living people'),
+                         _('Replace complete name of living people'),
+                         _('Do not include living people'),
+                        ]:
                 model.append(row=[item, row])
                 row += 1
 
@@ -722,3 +748,29 @@ class WriterOptionBox(object):
                 row += 1
 
         return model
+
+class WriterOptionBoxWithCompression(WriterOptionBox):
+    """
+    Extends the WriterOptionBox with option for using compression.
+    """
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.use_compression = _gzip_ok
+        self.use_compression_check = None
+
+    def get_use_compression(self):
+        return self.use_compression
+
+    def get_option_box(self):
+        from gi.repository import Gtk
+        option_box = super().get_option_box()
+        self.use_compression_check = Gtk.CheckButton(label=_("Use Compression"))
+        self.use_compression_check.set_active(1)
+        self.use_compression_check.set_sensitive(_gzip_ok)
+        option_box.pack_start(self.use_compression_check, False, True, 0)
+        return option_box
+
+    def parse_options(self):
+        super().parse_options()
+        if self.use_compression_check:
+            self.use_compression = self.use_compression_check.get_active()
