@@ -26,11 +26,8 @@
 # Standard python modules
 #
 #-------------------------------------------------------------------------
-import sys
-if sys.version_info[0] < 3:
-    from cStringIO import StringIO
-else:
-    from io import StringIO
+from abc import ABCMeta, abstractmethod
+from io import StringIO
 
 #-------------------------------------------------------------------------
 #
@@ -38,7 +35,6 @@ else:
 #
 #-------------------------------------------------------------------------
 import logging
-log = logging.getLogger(".Bookmarks")
 
 #-------------------------------------------------------------------------
 #
@@ -54,9 +50,11 @@ from gi.repository import Gtk
 #-------------------------------------------------------------------------
 from ..display import display_help
 from ..listmodel import ListModel
+from ..managedwindow import ManagedWindow
 from gramps.gen.utils.db import navigation_label
 from gramps.gen.const import URL_MANUAL_PAGE
 from gramps.gen.const import GRAMPS_LOCALE as glocale
+from gramps.gen.errors import HandleError
 _ = glocale.translation.sgettext
 
 #-------------------------------------------------------------------------
@@ -64,6 +62,7 @@ _ = glocale.translation.sgettext
 # Constants
 #
 #-------------------------------------------------------------------------
+LOG = logging.getLogger(".Bookmarks")
 WIKI_HELP_PAGE = '%s_-_Navigation' % URL_MANUAL_PAGE
 WIKI_HELP_SEC = _('manual|Bookmarks')
 
@@ -78,9 +77,9 @@ BTM = '''</menu></menubar></ui>'''
 
 DISABLED = -1
 
-class Bookmarks :
+class Bookmarks(metaclass=ABCMeta):
     "Handle the bookmarks interface for Gramps."
-    
+
     def __init__(self, dbstate, uistate, callback=None):
         """
         Create the bookmark editor.
@@ -92,34 +91,38 @@ class Bookmarks :
         self.dbstate = dbstate
         self.uistate = uistate
         self.bookmarks = None
-        self.update_bookmarks()
+        if self.dbstate.is_open():
+            self.update_bookmarks()
         self.active = DISABLED
         self.action_group = Gtk.ActionGroup(name='Bookmarks')
-        self.connect_signals()
+        if self.dbstate.is_open():
+            self.connect_signals()
         self.dbstate.connect('database-changed', self.db_changed)
+        self.dbstate.connect("no-database", self.undisplay)
 
     def db_changed(self, data):
         """
         Reconnect the signals on a database changed.
         """
-        self.connect_signals()
-        self.update_bookmarks()
+        if self.dbstate.is_open():
+            self.connect_signals()
+            self.update_bookmarks()
 
+    @abstractmethod
     def connect_signals(self):
         """
         Connect the person-delete signal
         """
-        raise NotImplementedError
 
+    @abstractmethod
     def get_bookmarks(self):
         """
         Retrieve bookmarks from the database.
         """
-        raise NotImplementedError
 
     def update_bookmarks(self):
         """
-        Assign bookmarks 
+        Assign bookmarks
         """
         self.bookmarks = self.get_bookmarks()
 
@@ -154,12 +157,13 @@ class Bookmarks :
 
         actions = []
         count = 0
+        bad_bookmarks = []  # list of bad bookmarks
 
-        if len(self.bookmarks.get()) > 0:
+        if self.dbstate.is_open() and len(self.bookmarks.get()) > 0:
             text.write('<placeholder name="GoToBook">')
             for item in self.bookmarks.get():
                 try:
-                    label, obj = self.make_label(item)
+                    label, dummy_obj = self.make_label(item)
                     func = self.callback(item)
                     action_id = "BM:%s" % item
                     actions.append((action_id, None, label, None, None, func))
@@ -167,20 +171,36 @@ class Bookmarks :
                     count += 1
                 except AttributeError:
                     pass
+                except HandleError:
+                    # if bookmark contains handle to something missing now
+                    bad_bookmarks.append(item)
             text.write('</placeholder>')
-            
+
         text.write(BTM)
         self.action_group.add_actions(actions)
         self.uistate.uimanager.insert_action_group(self.action_group, 1)
         self.active = self.uistate.uimanager.add_ui_from_string(text.getvalue())
         self.uistate.uimanager.ensure_update()
         text.close()
+        # Clean up any bad bookmarks (can happen if Gramps crashes;
+        # modified bookmarks set is saved only on normal Gramps close)
+        for handle in bad_bookmarks:
+            self.bookmarks.remove(handle)
 
+    @abstractmethod
     def make_label(self, handle):
-        raise NotImplementedError
+        """
+        Returns a  (label, object) tuple appropriate to the type of the object
+        that the handle refers to. The label is a text for the object, e.g. the
+        object name.
+        """
 
+    @abstractmethod
     def callback(self, handle):
-        raise NotImplementedError
+        """
+        Returns a unique call to a function with the associated handle. The
+        function that will be called is defined in the derived class
+        """
 
     def add(self, person_handle):
         """Append the person to the bottom of the bookmarks."""
@@ -204,51 +224,80 @@ class Bookmarks :
         if modified:
             self.redraw_and_report_change()
 
+    def edit(self):
+        """
+        Display the bookmark editor.
+
+        The current bookmarked people are inserted into the namelist,
+        attaching the person object to the corresponding row. The currently
+        selected row is attached to the name list. This is either 0 if the
+        list is not empty, or -1 if it is.
+        """
+        BookmarksDialog(self)
+
+class BookmarksDialog(ManagedWindow):
+    """
+    A dialog to enable the user to organize bookmarks.
+    """
+
+    def __init__(self, bm_class):
+
+        self.bm_class = bm_class
+        self.bookmarks = bm_class.bookmarks
+        self.dbstate = bm_class.dbstate
+        self.make_label = bm_class.make_label
+        uistate = bm_class.uistate
+
+        self.namemodel = None
+        self.top = None
+        self.modified = None
+        self.response = None
+        self.namelist = None
+
+        ManagedWindow.__init__(self, uistate, [], self.__class__, modal=True)
+        # the self.top.run() below makes Gtk make it modal, so any change to
+        # the previous line's "modal" would require that line to be changed
+
+        self.draw_window()
+        self.set_window(self.top, None, _("Organize Bookmarks"))
+        self.setup_configs('interface.bookmarksdialog', 400, 350)
+        self.show()
+        self.edit()
+
     def draw_window(self):
         """Draw the bookmark dialog box."""
-        title = _("%(title)s - Gramps") % {'title': _("Organize Bookmarks")}
-        self.top = Gtk.Dialog(title)
-        self.top.set_default_size(400, 350)
-        self.top.set_modal(True)
-        self.top.set_transient_for(self.uistate.window)
+        self.top = Gtk.Dialog(parent=self.parent_window)
         self.top.vbox.set_spacing(5)
         label = Gtk.Label(label='<span size="larger" weight="bold">%s</span>'
                           % _("Organize Bookmarks"))
         label.set_use_markup(True)
         self.top.vbox.pack_start(label, 0, 0, 5)
-        box = Gtk.HBox()
+        box = Gtk.Box()
         self.top.vbox.pack_start(box, 1, 1, 5)
-        
+
         name_titles = [(_('Name'), -1, 200), (_('ID'), -1, 50), ('', -1, 0)]
         self.namelist = Gtk.TreeView()
         self.namemodel = ListModel(self.namelist, name_titles)
-        self.namemodel_cols = len(name_titles)
 
         slist = Gtk.ScrolledWindow()
-        slist.add_with_viewport(self.namelist)
+        slist.add(self.namelist)
         slist.set_policy(Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.AUTOMATIC)
         box.pack_start(slist, 1, 1, 5)
-        bbox = Gtk.VButtonBox()
+        bbox = Gtk.ButtonBox(orientation=Gtk.Orientation.VERTICAL)
         bbox.set_layout(Gtk.ButtonBoxStyle.START)
         bbox.set_spacing(6)
-        up = Gtk.Button(stock=Gtk.STOCK_GO_UP)
-        down = Gtk.Button(stock=Gtk.STOCK_GO_DOWN)
-        delete = Gtk.Button(stock=Gtk.STOCK_REMOVE)
+        up = Gtk.Button.new_with_mnemonic(_('_Up'))
+        down = Gtk.Button.new_with_mnemonic(_('_Down'))
+        delete = Gtk.Button.new_with_mnemonic(_('_Remove'))
         up.connect('clicked', self.up_clicked)
         down.connect('clicked', self.down_clicked)
         delete.connect('clicked', self.delete_clicked)
-        self.top.add_button(Gtk.STOCK_CLOSE, Gtk.ResponseType.CLOSE)
-        self.top.add_button(Gtk.STOCK_HELP, Gtk.ResponseType.HELP)
-        self.top.connect('delete-event', self.close)
+        self.top.add_button(_('_Close'), Gtk.ResponseType.CLOSE)
+        self.top.add_button(_('_Help'), Gtk.ResponseType.HELP)
         bbox.add(up)
         bbox.add(down)
         bbox.add(delete)
         box.pack_start(bbox, 0, 0, 5)
-        self.top.show_all()
-    
-    def close(self, widget, event):
-        """Stop the bookmark organizer"""
-        self.top.response(Gtk.ResponseType.CLOSE)
 
     def edit(self):
         """
@@ -259,7 +308,6 @@ class Bookmarks :
         selected row is attached to the name list. This is either 0 if the
         list is not empty, or -1 if it is.
         """
-        self.draw_window()
         for handle in self.bookmarks.get():
             name, obj = self.make_label(handle)
             if obj:
@@ -269,18 +317,23 @@ class Bookmarks :
 
         self.modified = False
         while True:
+            # the self.top.run() makes Gtk make it modal, so any change to that
+            # line would require the ManagedWindow.__init__ to be changed also
             self.response = self.top.run()
             if self.response == Gtk.ResponseType.HELP:
                 self.help_clicked()
             elif self.response == Gtk.ResponseType.CLOSE:
                 if self.modified:
-                    self.redraw_and_report_change()
-                self.top.destroy()
+                    self.bm_class.redraw_and_report_change()
+                self.close()
+                break
+            elif self.response == Gtk.ResponseType.DELETE_EVENT:
+                # ManagedWindow already handles the delete-event signal
                 break
 
     def delete_clicked(self, obj):
         """Remove the current selection from the list."""
-        store, the_iter = self.namemodel.get_selected()
+        dummy_store, the_iter = self.namemodel.get_selected()
         if not the_iter:
             return
         row = self.namemodel.get_selected_row()
@@ -308,42 +361,48 @@ class Bookmarks :
             self.modified = True
 
     def help_clicked(self):
-        """Display the relevant portion of GRAMPS manual."""
+        """Display the relevant portion of Gramps manual."""
         display_help(webpage=WIKI_HELP_PAGE, section=WIKI_HELP_SEC)
 
+    def build_menu_names(self, obj): # this is meaningless while it's modal
+        return (_('Organize Bookmarks'), None)
+
 class ListBookmarks(Bookmarks):
+    """ Derived class from which all the specific type bookmark handlers are in
+    turn derived"""
 
     def __init__(self, dbstate, uistate, change_active):
         self.change_active = change_active
         Bookmarks.__init__(self, dbstate, uistate)
-    
+
     def callback(self, handle):
         return make_callback(handle, self.do_callback)
 
     def do_callback(self, handle):
+        """Callback routine"""
         self.change_active(handle)
 
-class PersonBookmarks(ListBookmarks) :
+class PersonBookmarks(ListBookmarks):
     "Handle the bookmarks interface for Gramps."
-    
+
     def __init__(self, dbstate, uistate, change_active):
         ListBookmarks.__init__(self, dbstate, uistate, change_active)
-        
+
     def make_label(self, handle):
         return navigation_label(self.dbstate.db, 'Person', handle)
 
     def connect_signals(self):
         self.dbstate.db.connect('person-delete', self.remove_handles)
-        
+
     def get_bookmarks(self):
         return self.dbstate.db.get_bookmarks()
-        
-class FamilyBookmarks(ListBookmarks) :
+
+class FamilyBookmarks(ListBookmarks):
     "Handle the bookmarks interface for Gramps."
-    
+
     def __init__(self, dbstate, uistate, change_active):
         ListBookmarks.__init__(self, dbstate, uistate, change_active)
-        
+
     def make_label(self, handle):
         return navigation_label(self.dbstate.db, 'Family', handle)
 
@@ -352,13 +411,13 @@ class FamilyBookmarks(ListBookmarks) :
 
     def get_bookmarks(self):
         return self.dbstate.db.get_family_bookmarks()
-        
-class EventBookmarks(ListBookmarks) :
+
+class EventBookmarks(ListBookmarks):
     "Handle the bookmarks interface for Gramps."
-    
+
     def __init__(self, dbstate, uistate, change_active):
         ListBookmarks.__init__(self, dbstate, uistate, change_active)
-        
+
     def make_label(self, handle):
         return navigation_label(self.dbstate.db, 'Event', handle)
 
@@ -367,13 +426,13 @@ class EventBookmarks(ListBookmarks) :
 
     def get_bookmarks(self):
         return self.dbstate.db.get_event_bookmarks()
-        
-class SourceBookmarks(ListBookmarks) :
+
+class SourceBookmarks(ListBookmarks):
     "Handle the bookmarks interface for Gramps."
 
     def __init__(self, dbstate, uistate, change_active):
         ListBookmarks.__init__(self, dbstate, uistate, change_active)
-        
+
     def make_label(self, handle):
         return navigation_label(self.dbstate.db, 'Source', handle)
 
@@ -382,13 +441,13 @@ class SourceBookmarks(ListBookmarks) :
 
     def get_bookmarks(self):
         return self.dbstate.db.get_source_bookmarks()
-        
-class CitationBookmarks(ListBookmarks) :
+
+class CitationBookmarks(ListBookmarks):
     "Handle the bookmarks interface for Gramps."
 
     def __init__(self, dbstate, uistate, change_active):
         ListBookmarks.__init__(self, dbstate, uistate, change_active)
-        
+
     def make_label(self, handle):
         return navigation_label(self.dbstate.db, 'Citation', handle)
 
@@ -403,30 +462,33 @@ class CitationBookmarks(ListBookmarks) :
             # Probably trying to bookmark a source when the navigation type is
             # citation. This can occur when in the Citation Tree View and we
             # bookmark a source.
-            
+
             # FIXME: See http://www.gramps-project.org/bugs/view.php?id=6352 a
             # more comprehensive solution is needed in the long term. See also
             # change_active in CitatinTreeView
-            from gramps.gui.dialog import WarningDialog
-            WarningDialog(_("Cannot bookmark this reference"),
-                          "Only Citations can be bookmarked in this view. "
-                          "You are probably trying to bookmark a Source in the "
-                          "Citation Tree View. In this view, only Citations "
-                          "can be bookmarked. To bookmark a Source, switch to "
-                          "the Source View")
+            from ..dialog import WarningDialog
+            WarningDialog(
+                _("Cannot bookmark this reference"),
+                # FIXME should this next string be translated?
+                "Only Citations can be bookmarked in this view. "
+                "You are probably trying to bookmark a Source in the "
+                "Citation Tree View. In this view, only Citations "
+                "can be bookmarked. To bookmark a Source, switch to "
+                "the Source View",
+                parent=self.uistate.window)
 
     def connect_signals(self):
         self.dbstate.db.connect('citation-delete', self.remove_handles)
 
     def get_bookmarks(self):
         return self.dbstate.db.get_citation_bookmarks()
-        
-class MediaBookmarks(ListBookmarks) :
+
+class MediaBookmarks(ListBookmarks):
     "Handle the bookmarks interface for Gramps."
-    
+
     def __init__(self, dbstate, uistate, change_active):
         ListBookmarks.__init__(self, dbstate, uistate, change_active)
-        
+
     def make_label(self, handle):
         return navigation_label(self.dbstate.db, 'Media', handle)
 
@@ -435,13 +497,13 @@ class MediaBookmarks(ListBookmarks) :
 
     def get_bookmarks(self):
         return self.dbstate.db.get_media_bookmarks()
-        
-class RepoBookmarks(ListBookmarks) :
+
+class RepoBookmarks(ListBookmarks):
     "Handle the bookmarks interface for Gramps."
-    
+
     def __init__(self, dbstate, uistate, change_active):
         ListBookmarks.__init__(self, dbstate, uistate, change_active)
-        
+
     def make_label(self, handle):
         return navigation_label(self.dbstate.db, 'Repository', handle)
 
@@ -450,13 +512,13 @@ class RepoBookmarks(ListBookmarks) :
 
     def get_bookmarks(self):
         return self.dbstate.db.get_repo_bookmarks()
-        
-class PlaceBookmarks(ListBookmarks) :
+
+class PlaceBookmarks(ListBookmarks):
     "Handle the bookmarks interface for Gramps."
-    
+
     def __init__(self, dbstate, uistate, change_active):
         ListBookmarks.__init__(self, dbstate, uistate, change_active)
-        
+
     def make_label(self, handle):
         return navigation_label(self.dbstate.db, 'Place', handle)
 
@@ -465,13 +527,13 @@ class PlaceBookmarks(ListBookmarks) :
 
     def get_bookmarks(self):
         return self.dbstate.db.get_place_bookmarks()
-        
-class NoteBookmarks(ListBookmarks) :
+
+class NoteBookmarks(ListBookmarks):
     "Handle the bookmarks interface for Gramps."
-    
+
     def __init__(self, dbstate, uistate, change_active):
         ListBookmarks.__init__(self, dbstate, uistate, change_active)
-        
+
     def make_label(self, handle):
         return navigation_label(self.dbstate.db, 'Note', handle)
 
@@ -480,7 +542,7 @@ class NoteBookmarks(ListBookmarks) :
 
     def get_bookmarks(self):
         return self.dbstate.db.get_note_bookmarks()
-        
+
 def make_callback(handle, function):
     """
     Build a unique call to the function with the associated handle.
