@@ -9,17 +9,17 @@
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
 #
-# This program is distributed in the hope that it will be useful, 
+# This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-__all__ = ["MonitoredCheckbox", "MonitoredEntry", 
+__all__ = ["MonitoredCheckbox", "MonitoredEntry",
            "MonitoredEntryIndicator", "MonitoredSpinButton",
            "MonitoredText", "MonitoredType", "MonitoredDataType",
            "MonitoredMenu", "MonitoredStrMenu", "MonitoredDate",
@@ -32,7 +32,6 @@ __all__ = ["MonitoredCheckbox", "MonitoredEntry",
 #-------------------------------------------------------------------------
 import logging
 _LOG = logging.getLogger(".widgets.monitoredwidgets")
-import sys
 
 #-------------------------------------------------------------------------
 #
@@ -55,7 +54,6 @@ from ..autocomp import StandardCustomSelector, fill_entry
 from gramps.gen.datehandler import displayer, parser
 from gramps.gen.lib.date import Date, NextYear
 from gramps.gen.errors import ValidationError
-from gramps.gen.constfunc import cuni
 
 #-------------------------------------------------------------------------
 #
@@ -71,7 +69,7 @@ _KP_ENTER = Gdk.keyval_from_name("KP_Enter")
 # MonitoredCheckbox class
 #
 #-------------------------------------------------------------------------
-class MonitoredCheckbox(object):
+class MonitoredCheckbox:
 
     def __init__(self, obj, button, set_val, get_val, on_toggle=None,
                  readonly = False):
@@ -96,15 +94,15 @@ class MonitoredCheckbox(object):
 ##        self.set_val = None
 ##        self.get_val = None
 ##        self.obj = None
-        
+
 #-------------------------------------------------------------------------
 #
 # MonitoredEntry class
 #
 #-------------------------------------------------------------------------
-class MonitoredEntry(object):
+class MonitoredEntry:
 
-    def __init__(self, obj, set_val, get_val, read_only=False, 
+    def __init__(self, obj, set_val, get_val, read_only=False,
                  autolist=None, changed=None):
         self.obj = obj
         self.set_val = set_val
@@ -134,24 +132,20 @@ class MonitoredEntry(object):
 
     def set_text(self, text):
         self.obj.set_text(text)
-        
+
     def connect(self, signal, callback, *data):
         self.obj.connect(signal, callback, *data)
 
     def _on_change(self, obj):
-        if sys.version_info[0] < 3:
-            self.set_val(cuni(obj.get_text(), 'utf-8'))
-        else:
-            #all is unicode
-            self.set_val(obj.get_text())
+        self.set_val(obj.get_text())
         if self.changed:
             self.changed(obj)
 
     def force_value(self, value):
         self.obj.set_text(value)
 
-    def get_value(self, value):
-        return cuni(self.obj.get_text())
+    def get_value(self):
+        return str(self.obj.get_text())
 
     def enable(self, value):
         self.obj.set_sensitive(value)
@@ -171,10 +165,10 @@ class MonitoredEntry(object):
 #-------------------------------------------------------------------------
 class MonitoredEntryIndicator(MonitoredEntry):
     """
-    Show an Entry box with an indicator in it that disappears when 
+    Show an Entry box with an indicator in it that disappears when
     entry becomes active
     """
-    def __init__(self, obj, set_val, get_val, indicator, read_only=False, 
+    def __init__(self, obj, set_val, get_val, indicator, read_only=False,
                  autolist=None, changed=None):
         MonitoredEntry.__init__(self, obj, set_val, get_val, read_only,
                                 autolist, changed)
@@ -189,12 +183,12 @@ class MonitoredEntryIndicator(MonitoredEntry):
             Gdk.RGBA.parse(rgba, 'grey')
             self.obj.override_color(Gtk.StateType.NORMAL, rgba)
             self.obj.override_font(Pango.FontDescription('sans italic'))
-            self.fockey = self.obj.connect('focus-in-event', 
+            self.fockey = self.obj.connect('focus-in-event',
                                                self._obj_focus)
-    
+
     def _on_change(self, obj):
         if not self.indicatorshown:
-            self.set_val(cuni(obj.get_text()))
+            self.set_val(str(obj.get_text()))
             if self.changed:
                 self.changed(obj)
 
@@ -214,7 +208,7 @@ class MonitoredEntryIndicator(MonitoredEntry):
 # MonitoredSpinButton class
 #
 #-------------------------------------------------------------------------
-class MonitoredSpinButton(object):
+class MonitoredSpinButton:
     """
     Class for signal handling of spinbuttons.
     (Code is a modified copy of :class:`MonitoredEntry`)
@@ -229,7 +223,7 @@ class MonitoredSpinButton(object):
         :param get_val: callback to be called to retrieve value for obj
         :param read_only: If SpinButton is read only.
         """
-        
+
         self.obj = obj
         self.set_val = set_val
         self.get_val = get_val
@@ -258,7 +252,7 @@ class MonitoredSpinButton(object):
         :param set_val: callback to be called when SpinButton is changed
         :param get_val: callback to be called to retrieve value for SpinButton
         """
-        
+
         self.set_val = set_val
         self.get_val = get_val
         self.update()
@@ -269,9 +263,9 @@ class MonitoredSpinButton(object):
 
         :param value: Value to be set.
         """
-        
+
         self.obj.set_value(value)
-        
+
     def connect(self, signal, callback):
         """
         Connect the signal of monitored widget to the specified callback.
@@ -279,7 +273,7 @@ class MonitoredSpinButton(object):
         :param signal: Signal prototype for which a connection should be set up.
         :param callback: Callback function to be called when signal is emitted.
         """
-        
+
         self.obj.connect(signal, callback)
 
     def _on_change(self, obj):
@@ -289,7 +283,7 @@ class MonitoredSpinButton(object):
         :param obj: Widget that has been changed.
         :type obj: Gtk.SpinButton
         """
-        
+
         self.set_val(obj.get_value())
         if self.changed:
             self.changed(obj)
@@ -300,7 +294,7 @@ class MonitoredSpinButton(object):
 
         :param value: Value to be set.
         """
-        
+
         self.obj.set_value(value)
 
     def get_value(self):
@@ -320,7 +314,7 @@ class MonitoredSpinButton(object):
         :param value: If widget should be editable or deactivated.
         :type value: bool
         """
-        
+
         self.obj.set_sensitive(value)
         self.obj.set_editable(value)
 
@@ -328,7 +322,7 @@ class MonitoredSpinButton(object):
         """
         Assign the keyboard focus to the monitored widget.
         """
-        
+
         self.obj.grab_focus()
 
     def update(self):
@@ -336,7 +330,7 @@ class MonitoredSpinButton(object):
         Updates value of monitored SpinButton with the value returned by the
         get_val callback.
         """
-        
+
         if self.get_val():
             self.obj.set_value(self.get_val())
 
@@ -345,7 +339,7 @@ class MonitoredSpinButton(object):
 # MonitoredText class
 #
 #-------------------------------------------------------------------------
-class MonitoredText(object):
+class MonitoredText:
 
     def __init__(self, obj, set_val, get_val, read_only=False):
         self.buf = obj.get_buffer()
@@ -367,16 +361,16 @@ class MonitoredText(object):
 
     def on_change(self, obj):
         s, e = self.buf.get_bounds()
-        self.set_val(cuni(self.buf.get_text(s, e, False)))
+        self.set_val(str(self.buf.get_text(s, e, False)))
 
 #-------------------------------------------------------------------------
 #
 # MonitoredType class
 #
 #-------------------------------------------------------------------------
-class MonitoredType(object):
+class MonitoredType:
 
-    def __init__(self, obj, set_val, get_val, mapping, custom, readonly=False, 
+    def __init__(self, obj, set_val, get_val, mapping, custom, readonly=False,
                  custom_values=None):
         self.set_val = set_val
         self.get_val = get_val
@@ -421,10 +415,10 @@ class MonitoredType(object):
 # MonitoredDataType class
 #
 #-------------------------------------------------------------------------
-class MonitoredDataType(object):
-    
+class MonitoredDataType:
 
-    def __init__(self, obj, set_val, get_val, readonly=False, 
+
+    def __init__(self, obj, set_val, get_val, readonly=False,
                  custom_values=None, ignore_values=None):
         """
         Constructor for the MonitoredDataType class.
@@ -443,7 +437,7 @@ class MonitoredDataType(object):
         :type custom_values: list of str, tuple or GrampsType
         :param ignore_values: list of values not to show in the combobox. If the
                               result of get_val is in these, it is not ignored
-        :type ignore_values: list of int 
+        :type ignore_values: list of int
         """
         self.set_val = set_val
         self.get_val = get_val
@@ -456,7 +450,7 @@ class MonitoredDataType(object):
             default = int(val)
         else:
             default = None
-            
+
         map = get_val().get_map().copy()
         if ignore_values :
             for key in list(map.keys()):
@@ -464,10 +458,10 @@ class MonitoredDataType(object):
                     del map[key]
 
         self.sel = StandardCustomSelector(
-            map, 
-            obj, 
-            get_val().get_custom(), 
-            default, 
+            map,
+            obj,
+            get_val().get_custom(),
+            default,
             additional=custom_values,
             menu=get_val().get_menu())
 
@@ -510,9 +504,9 @@ class MonitoredDataType(object):
 # MonitoredMenu class
 #
 #-------------------------------------------------------------------------
-class MonitoredMenu(object):
+class MonitoredMenu:
 
-    def __init__(self, obj, set_val, get_val, mapping, 
+    def __init__(self, obj, set_val, get_val, mapping,
                  readonly=False, changed=None):
         self.set_val = set_val
         self.get_val = get_val
@@ -556,7 +550,7 @@ class MonitoredMenu(object):
 # MonitoredStrMenu class
 #
 #-------------------------------------------------------------------------
-class MonitoredStrMenu(object):
+class MonitoredStrMenu:
 
     def __init__(self, obj, set_val, get_val, mapping, readonly=False):
         self.set_val = set_val
@@ -564,7 +558,7 @@ class MonitoredStrMenu(object):
 
         self.obj = obj
         self.model = Gtk.ListStore(GObject.TYPE_STRING)
-        
+
         # Make sure that the menu is visible on small screen devices.
         # Some LDS temples were not visible on a 4 or 5 column layout.
         # See bug #7333
@@ -577,14 +571,14 @@ class MonitoredStrMenu(object):
 
         default = get_val()
         active = 0
-        
+
         for t, v in mapping:
             self.model.append(row=[v])
             self.data.append(t)
             index += 1
             if t == default:
                 active = index
-            
+
         self.obj.set_model(self.model)
         self.obj.set_active(active)
         self.obj.connect('changed', self.on_change)
@@ -607,7 +601,7 @@ class MonitoredStrMenu(object):
 # MonitoredDate class
 #
 #-------------------------------------------------------------------------
-class MonitoredDate(object):
+class MonitoredDate:
     """
     Class that associates a pixmap with a text widget, providing visual
     feedback that indicates if the text widget contains a valid date.
@@ -617,7 +611,7 @@ class MonitoredDate(object):
         Create a connection between the date_obj, text_obj and the pixmap_obj.
         Assigns callbacks to parse and change date when the text
         in text_obj is changed, and to invoke Date Editor when the LED
-        button_obj is pressed. 
+        button_obj is pressed.
         """
         self.uistate = uistate
         self.track = track
@@ -626,28 +620,28 @@ class MonitoredDate(object):
         self.button_obj = button
 
         image = Gtk.Image()
-        image.set_from_stock('gramps-date-edit', Gtk.IconSize.BUTTON)
+        image.set_from_icon_name('gramps-date-edit', Gtk.IconSize.BUTTON)
         self.button_obj.set_image(image)
         self.button_obj.set_relief(Gtk.ReliefStyle.NORMAL)
         self.pixmap_obj = self.button_obj.get_child()
-        
+
         self.text_obj.connect('validate', self.validate)
         self.text_obj.connect('content-changed', self.set_date)
         self.button_obj.connect('clicked', self.invoke_date_editor)
-        
+
         self.text_obj.set_text(displayer.display(self.date_obj))
         self.text_obj.validate()
 
         self.text_obj.set_editable(not readonly)
         self.button_obj.set_sensitive(not readonly)
-        
+
     def set_date(self, widget):
         """
         Parse date from text entry to date object
         """
-        date = parser.parse(cuni(self.text_obj.get_text()))
+        date = parser.parse(str(self.text_obj.get_text()))
         self.date_obj.copy(date)
-        
+
     def validate(self, widget, data):
         """
         Validate current date in text entry
@@ -685,12 +679,12 @@ class MonitoredDate(object):
 # MonitoredComboSelectedEntry class
 #
 #-------------------------------------------------------------------------
-class MonitoredComboSelectedEntry(object):
+class MonitoredComboSelectedEntry:
     """
     A MonitoredEntry driven by a Combobox to select what the entry field
     works upon
     """
-    def __init__(self, objcombo, objentry, textlist, set_val_list, 
+    def __init__(self, objcombo, objentry, textlist, set_val_list,
                  get_val_list, default=0, read_only=False):
         """
         Create a MonitoredComboSelectedEntry
@@ -705,14 +699,14 @@ class MonitoredComboSelectedEntry(object):
         self.objentry = objentry
         self.set_val_list = set_val_list
         self.get_val_list = get_val_list
-        
+
         #fill the combobox, set on a specific entry
         self.mapping = dict([[i,x] for (i,x) in zip(list(range(len(textlist))),
                                                     textlist)])
 
         self.active_key = default
         self.active_index = 0
-        
+
         self.__fill()
         self.objcombo.clear()
         self.objcombo.set_model(self.store)
@@ -721,11 +715,11 @@ class MonitoredComboSelectedEntry(object):
         self.objcombo.add_attribute(cell, 'text', 1)
         self.objcombo.set_active(self.active_index)
         self.objcombo.connect('changed', self.on_combochange)
-        
+
         #fill the entrybox with required data
         self.entry_reinit()
         self.objentry.connect('changed', self._on_change_entry)
-        
+
         #set correct editable
         self.enable(not read_only)
 
@@ -766,13 +760,13 @@ class MonitoredComboSelectedEntry(object):
 
     def on_combochange(self, obj):
         """
-        callback for change on the combo, change active iter, update 
+        callback for change on the combo, change active iter, update
         associated entrybox
         """
         self.active_key = self.store.get_value(self.objcombo.get_active_iter(),
                                                0)
         self.entry_reinit()
-    
+
     def reinit(self, set_val_list, get_val_list):
         """
         The interface is attached to another object, so the methods need to be
@@ -797,7 +791,7 @@ class MonitoredComboSelectedEntry(object):
         self.set_val_list[self.active_key](self.get_value_entry())
 
     def get_value_entry(self):
-        return cuni(self.objentry.get_text())
+        return str(self.objentry.get_text())
 
     def enable(self, value):
         self.objentry.set_sensitive(value)
@@ -815,7 +809,7 @@ class MonitoredComboSelectedEntry(object):
 # MonitoredTagList class
 #
 #-------------------------------------------------------------------------
-class MonitoredTagList(object):
+class MonitoredTagList:
     """
     A MonitoredTagList consists of a label to display a list of tags and a
     button to invoke the tag editor.
@@ -835,14 +829,15 @@ class MonitoredTagList(object):
                 self.tag_list.append((handle, tag.get_name()))
 
         self.all_tags = []
-        for tag in self.db.iter_tags():
+        for handle in self.db.get_tag_handles(sort_handles=True):
+            tag = self.db.get_tag_from_handle(handle)
             self.all_tags.append((tag.get_handle(), tag.get_name()))
 
         self.label = label
-        self.label.set_alignment(0, 0.5)
+        self.label.set_halign(Gtk.Align.START)
         self.label.set_ellipsize(Pango.EllipsizeMode.END)
         image = Gtk.Image()
-        image.set_from_stock('gramps-tag', Gtk.IconSize.MENU)
+        image.set_from_icon_name('gramps-tag', Gtk.IconSize.MENU)
         button.set_image (image)
         button.set_tooltip_text(_('Edit the tag list'))
         button.connect('button-press-event', self.cb_edit)
