@@ -46,7 +46,7 @@ from gi.repository import Pango
 
 #-------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
 #-------------------------------------------------------------------------
 from gramps.gen.lib import StyledTextTagType
@@ -60,9 +60,9 @@ from .toolcomboentry import ToolComboEntry
 from .springseparator import SpringSeparatorAction
 from ..spell import Spell
 from ..display import display_url
-from ..utils import SystemFonts, get_link_color
+from ..utils import SystemFonts, match_primary_mask, get_link_color
 from gramps.gen.config import config
-from gramps.gen.constfunc import has_display
+from gramps.gen.constfunc import has_display, mac
 from ..actiongroup import ActionGroup
 
 #-------------------------------------------------------------------------
@@ -71,22 +71,23 @@ from ..actiongroup import ActionGroup
 #
 #-------------------------------------------------------------------------
 if has_display():
-    HAND_CURSOR = Gdk.Cursor.new(Gdk.CursorType.HAND2)
-    REGULAR_CURSOR = Gdk.Cursor.new(Gdk.CursorType.XTERM)
+    display = Gdk.Display.get_default()
+    HAND_CURSOR = Gdk.Cursor.new_for_display(display, Gdk.CursorType.HAND2)
+    REGULAR_CURSOR = Gdk.Cursor.new_for_display(display, Gdk.CursorType.XTERM)
 
 FORMAT_TOOLBAR = '''
 <ui>
 <toolbar name="ToolBar">
-  <toolitem action="%d"/>  
-  <toolitem action="%d"/>  
+  <toolitem action="%d"/>
+  <toolitem action="%d"/>
+  <toolitem action="%d"/>
+  <toolitem action="%d"/>
   <toolitem action="%d"/>
   <toolitem action="Undo"/>
   <toolitem action="Redo"/>
   <toolitem action="%d"/>
   <toolitem action="%d"/>
   <toolitem action="%d"/>
-  <toolitem action="%d"/>
-  <toolitem action="%d"/>
   <toolitem action="spring"/>
   <toolitem action="clear"/>
 </toolbar>
@@ -104,14 +105,15 @@ FORMAT_TOOLBAR = '''
 FONT_SIZES = [8, 9, 10, 11, 12, 13, 14, 16, 18, 20, 22,
               24, 26, 28, 32, 36, 40, 48, 56, 64, 72]
 
-USERCHARS = "-A-Za-z0-9"
-PASSCHARS = "-A-Za-z0-9,?;.:/!%$^*&~\"#'"
-HOSTCHARS = "-A-Za-z0-9"
-PATHCHARS = "-A-Za-z0-9_$.+!*(),;:@&=?/~#%"
+USERCHARS = r"-\w"
+PASSCHARS = r"-\w,?;.:/!%$^*&~\"#'"
+HOSTCHARS = r"-\w"
+PATHCHARS = r"-\w$.+!*(),;:@&=?/~#%"
 #SCHEME = "(news:|telnet:|nntp:|file:/|https?:|ftps?:|webcal:)"
 SCHEME = "(file:/|https?:|ftps?:|webcal:)"
 USER = "[" + USERCHARS + "]+(:[" + PASSCHARS + "]+)?"
-URLPATH = "/[" + PATHCHARS + "]*[^]'.}>) \t\r\n,\\\"]"
+HOST = r"([-\w.]+|\[[0-9A-F:]+\])?"
+URLPATH = "(/[" + PATHCHARS + "]*)?[^]'.:}> \t\r\n,\\\"]"
 
 (GENURL, HTTP, MAIL, LINK) = list(range(4))
 
@@ -134,14 +136,14 @@ def find_parent_with_attr(self, attr="dbstate"):
 class StyledTextEditor(Gtk.TextView):
     """
     StyledTextEditor is an enhanced Gtk.TextView to edit :class:`.StyledText`.
-    
+
     StyledTextEditor is a gui object for :class:`.StyledTextBuffer`. It offers
-    :meth:`set_text` and :meth:`get_text` convenience methods to set and get the 
+    :meth:`set_text` and :meth:`get_text` convenience methods to set and get the
     buffer's text.
-    
+
     StyledTextEditor provides a formatting toolbar, which can be retrieved
     by the :meth:`get_toolbar` method.
-    
+
     StyledTextEdit defines a new signal: 'match-changed', which is raised
     whenever the mouse cursor reaches or leaves a matched string in the text.
     The feature uses the regexp pattern mathing mechanism of
@@ -149,7 +151,7 @@ class StyledTextEditor(Gtk.TextView):
     The signal's default handler highlights the URL strings. URL's can be
     followed from the editor's popup menu or by pressing the <CTRL>Left
     mouse button.
-    
+
     :ivar last_match: previously matched string, used for generating the
                       'match-changed' signal.
     :type last_match: tuple or None
@@ -164,23 +166,23 @@ class StyledTextEditor(Gtk.TextView):
     :type toolbar: Gtk.Toolbar
     :ivar url_match: stores the matched URL and other mathing parameters.
     :type url_match: tuple or None
-    
+
     """
     __gtype_name__ = 'StyledTextEditor'
-    
+
     __gsignals__ = {
-        'match-changed': (GObject.SignalFlags.RUN_FIRST, 
+        'match-changed': (GObject.SignalFlags.RUN_FIRST,
                           None, #return value
                           (GObject.TYPE_PYOBJECT,)), # arguments
     }
-    
+
     def __init__(self):
         """Setup initial instance variable values."""
         self.textbuffer = UndoableStyledBuffer()
         self.undo_disabled = self.textbuffer.undo_disabled # see bug 7097
         self.textbuffer.connect('style-changed', self._on_buffer_style_changed)
         self.textbuffer.connect('changed', self._on_buffer_changed)
-        GObject.GObject.__init__(self)
+        Gtk.TextView.__init__(self)
         self.set_buffer(self.textbuffer)
 
         st_cont = self.get_style_context()
@@ -202,16 +204,16 @@ class StyledTextEditor(Gtk.TextView):
         self.selclick = False
 
     # virtual methods
-    
+
     def do_match_changed(self, match):
         """
         Default signal handler.
-        
+
         URL highlighting.
-        
+
         :param match: the new match parameters
         :type match: tuple or None
-        
+
         .. warning:: Do not override the handler, but connect to the signal.
         """
         window = self.get_window(Gtk.TextWindowType.TEXT)
@@ -220,7 +222,7 @@ class StyledTextEditor(Gtk.TextView):
         if match and (match[MATCH_FLAVOR] in (GENURL, HTTP, MAIL)):
             start_offset = match[MATCH_START]
             end_offset = match[MATCH_END]
-            
+
             start = self.textbuffer.get_iter_at_offset(start_offset)
             end = self.textbuffer.get_iter_at_offset(end_offset)
 
@@ -233,20 +235,19 @@ class StyledTextEditor(Gtk.TextView):
         else:
             window.set_cursor(REGULAR_CURSOR)
             self.url_match = None
-        
+
     def on_key_press_event(self, widget, event):
         """Signal handler.
-        
+
         Handle formatting shortcuts.
-        
+
         """
         if ((Gdk.keyval_name(event.keyval) == 'Z') and
-            (event.get_state() & Gdk.ModifierType.CONTROL_MASK) and 
-            (event.get_state() & Gdk.ModifierType.SHIFT_MASK)):
+            match_primary_mask(event.get_state(), Gdk.ModifierType.SHIFT_MASK)):
             self.redo()
             return True
         elif ((Gdk.keyval_name(event.keyval) == 'z') and
-              (event.get_state() & Gdk.ModifierType.CONTROL_MASK)):
+              match_primary_mask(event.get_state())):
             self.undo()
             return True
         else:
@@ -258,23 +259,23 @@ class StyledTextEditor(Gtk.TextView):
                     action.activate()
                     return True
         return False
-        
+
     def on_insert_at_cursor(self, widget, string):
         """Signal handler. for debugging only."""
         _LOG.debug("Textview insert '%s'" % string)
-        
+
     def on_delete_from_cursor(self, widget, mode, count):
         """Signal handler. for debugging only."""
         _LOG.debug("Textview delete type %d count %d" % (mode, count))
-        
+
     def on_paste_clipboard(self, widget):
         """Signal handler. for debugging only."""
         _LOG.debug("Textview paste clipboard")
-    
+
     def on_motion_notify_event(self, widget, event):
         """
         Signal handler.
-        
+
         As the mouse cursor moves the handler checks if there's a new
         regexp match at the new location. If match changes the
         'match-changed' signal is raised.
@@ -286,20 +287,18 @@ class StyledTextEditor(Gtk.TextView):
             iter_at_location = iter_at_location[1]
         self.match = self.textbuffer.match_check(iter_at_location.get_offset())
         tooltip = None
-        if not self.match:
-            for tag in (tag for tag in iter_at_location.get_tags()
-                        if tag.get_property('name').startswith("link")):
-                self.match = (x, y, LINK, tag.data, tag)
-                tooltip = self.make_tooltip_from_link(tag)
-                break
-        
+        for tag in (tag for tag in iter_at_location.get_tags()
+                    if tag.get_property('name').startswith("link")):
+            self.match = (x, y, LINK, tag.data, tag)
+            tooltip = self.make_tooltip_from_link(tag)
+            break
+
         if self.match != self.last_match:
             self.emit('match-changed', self.match)
 
         self.last_match = self.match
-        self.get_root_window().get_pointer()
-        if tooltip:
-            self.set_tooltip_text(tooltip)
+        # self.get_root_window().get_pointer()  # Doesn't seem to do anythhing!
+        self.set_tooltip_text(tooltip)
         return False
 
     def make_tooltip_from_link(self, link_tag):
@@ -315,7 +314,9 @@ class StyledTextEditor(Gtk.TextView):
             if url.startswith("gramps://"):
                 obj_class, prop, value = url[9:].split("/")
                 display = simple_access.display(obj_class, prop, value) or url
-        return display
+        return display + ((_("\nCommand-Click to follow link") if mac() else
+                           _("\nCtrl-Click to follow link"))
+                          if self.get_editable() else '')
 
     def on_button_release_event(self, widget, event):
         """
@@ -325,24 +326,24 @@ class StyledTextEditor(Gtk.TextView):
                 event.button == 1):
             bounds = self.textbuffer.get_selection_bounds()
             if bounds:
-                clip = Gtk.Clipboard.get_for_display(Gdk.Display.get_default(), 
+                clip = Gtk.Clipboard.get_for_display(Gdk.Display.get_default(),
                         Gdk.SELECTION_PRIMARY)
-                clip.set_text(str(self.textbuffer.get_text(bounds[0], 
+                clip.set_text(str(self.textbuffer.get_text(bounds[0],
                                                         bounds[1], True)), -1)
         return False
-            
+
     def on_button_press_event(self, widget, event):
         """
         Signal handler.
-        
+
         Handles the <CTRL> + Left click over a URL match.
         """
         self.selclick=False
         if ((event.type == Gdk.EventType.BUTTON_PRESS) and
-            (event.button == 1) and
-            (event.get_state() and Gdk.ModifierType.CONTROL_MASK) and
-            (self.url_match)):
-            
+            (event.button == 1) and (self.url_match) and
+            (match_primary_mask(event.get_state()) or
+             not self.get_editable())):
+
             flavor = self.url_match[MATCH_FLAVOR]
             url = self.url_match[MATCH_STRING]
             self._open_url_cb(None, url, flavor)
@@ -355,9 +356,9 @@ class StyledTextEditor(Gtk.TextView):
     def on_populate_popup(self, widget, menu):
         """
         Signal handler.
-        
+
         Insert extra menuitems:
-        
+
         1. Insert spellcheck selector submenu for spell checking.
         2. Insert extra menus depending on ULR match result.
         """
@@ -366,7 +367,7 @@ class StyledTextEditor(Gtk.TextView):
         spell_menu.set_submenu(self._create_spell_menu())
         spell_menu.show_all()
         menu.prepend(spell_menu)
-        
+
         search_menu = Gtk.MenuItem(label=_("Search selection on web"))
         search_menu.connect('activate', self.search_web)
         search_menu.show_all()
@@ -376,7 +377,7 @@ class StyledTextEditor(Gtk.TextView):
         if self.url_match:
             flavor = self.url_match[MATCH_FLAVOR]
             url = self.url_match[MATCH_STRING]
-            
+
             if flavor == MAIL:
                 open_menu = Gtk.MenuItem(label=_('_Send Mail To...'))
                 open_menu.set_use_underline(True)
@@ -388,10 +389,10 @@ class StyledTextEditor(Gtk.TextView):
                 copy_menu = Gtk.MenuItem(label=_('Copy _Link Address'))
                 copy_menu.set_use_underline(True)
 
-            if flavor == LINK:
+            if flavor == LINK and self.get_editable():
                 edit_menu = Gtk.MenuItem(label=_('_Edit Link'))
                 edit_menu.set_use_underline(True)
-                edit_menu.connect('activate', self._edit_url_cb, 
+                edit_menu.connect('activate', self._edit_url_cb,
                                   self.url_match[-1], # tag
                                   )
                 edit_menu.show()
@@ -401,7 +402,7 @@ class StyledTextEditor(Gtk.TextView):
             copy_menu.show()
 
             menu.prepend(copy_menu)
-            
+
             open_menu.connect('activate', self._open_url_cb, url, flavor)
             open_menu.show()
             menu.prepend(open_menu)
@@ -412,9 +413,9 @@ class StyledTextEditor(Gtk.TextView):
         """
         selection = self.textbuffer.get_selection_bounds()
         if len(selection) > 0:
-            display_url(config.get("behavior.web-search-url") % 
-                        {'text': 
-                         self.textbuffer.get_text(selection[0], 
+            display_url(config.get("behavior.web-search-url") %
+                        {'text':
+                         self.textbuffer.get_text(selection[0],
                                                   selection[1], True)})
 
     def reset(self):
@@ -426,7 +427,7 @@ class StyledTextEditor(Gtk.TextView):
         self.redo_action.set_sensitive(False)
 
     # private methods
-    
+
     def _connect_signals(self):
         """Connect to several signals of the super class Gtk.TextView."""
         self.connect('key-press-event', self.on_key_press_event)
@@ -437,11 +438,11 @@ class StyledTextEditor(Gtk.TextView):
         self.connect('button-press-event', self.on_button_press_event)
         self.connect('button-release-event', self.on_button_release_event)
         self.connect('populate-popup', self.on_populate_popup)
-        
+
     def _create_toolbar(self):
         """
         Create a formatting toolbar.
-        
+
         :returns: toolbar containing text formatting toolitems.
         :rtype: Gtk.Toolbar
         """
@@ -455,24 +456,25 @@ class StyledTextEditor(Gtk.TextView):
             (str(StyledTextTagType.UNDERLINE), 'format-text-underline', None,
             None, _('Underline'), self._on_toggle_action_activate),
         ]
-        
+
         self.toggle_actions = [action[0] for action in format_toggle_actions]
 
         # ...then the normal actions, which have a ToolButton as proxy
         format_actions = [
-            (str(StyledTextTagType.FONTCOLOR), 'gramps-font-color', None, None,
-             _('Font Color'), self._on_action_activate),
-            (str(StyledTextTagType.HIGHLIGHT), 'gramps-font-bgcolor', None,
-            None, _('Background Color'), self._on_action_activate),
-            (str(StyledTextTagType.LINK), 'go-jump', None, None,
+            (str(StyledTextTagType.FONTCOLOR), 'gramps-font-color',
+             _('Font Color'), None, _('Font Color'), self._on_action_activate),
+            (str(StyledTextTagType.HIGHLIGHT), 'gramps-font-bgcolor',
+             _('Background Color'), None, _('Background Color'),
+             self._on_action_activate),
+            (str(StyledTextTagType.LINK), 'go-jump', _('Link'), None,
              _('Link'), self._on_link_activate),
-            ('clear', 'edit-clear', None, None,
+            ('clear', 'edit-clear', _('Clear Markup'), None,
              _('Clear Markup'), self._format_clear_cb),
         ]
-        
+
         # ...last the custom actions, which have custom proxies
         default = StyledTextTagType.STYLE_DEFAULT[StyledTextTagType.FONTFACE]
-        fonts = SystemFonts()        
+        fonts = SystemFonts()
         fontface_action = ValueAction(str(StyledTextTagType.FONTFACE),
                                       _("Font family"),
                                       default,
@@ -496,7 +498,7 @@ class StyledTextEditor(Gtk.TextView):
         fontsize_action.connect('changed', self._on_valueaction_changed)
 
         spring = SpringSeparatorAction("spring", "", "", None)
-        
+
         # action accelerators
         self.action_accels = {
             '<PRIMARY>i': str(StyledTextTagType.ITALIC),
@@ -521,42 +523,45 @@ class StyledTextEditor(Gtk.TextView):
         self.action_group.add_action(fontface_action)
         self.action_group.add_action(fontsize_action)
         self.action_group.add_action(spring)
-        
+
         # define the toolbar and create the proxies via ensure_update()
         uimanager = Gtk.UIManager()
         uimanager.insert_action_group(self.action_group, 0)
         uimanager.add_ui_from_string(FORMAT_TOOLBAR)
         uimanager.ensure_update()
-        
+
         # get the toolbar and set it's style
-        toolbar = uimanager.get_widget('/ToolBar')      
+        toolbar = uimanager.get_widget('/ToolBar')
         toolbar.set_style(Gtk.ToolbarStyle.ICONS)
         self.undo_action.set_sensitive(False)
         self.redo_action.set_sensitive(False)
 
         return toolbar
-        
+
+    def set_transient_parent(self, parent=None):
+        self.transient_parent = parent
+
     def _init_url_match(self):
         """Setup regexp matching for URL match."""
         self.textbuffer.create_tag('hyperlink',
                                    underline=Pango.Underline.SINGLE,
                                    foreground=self.linkcolor)
-        self.textbuffer.match_add(SCHEME + "//(" + USER + "@)?[" +
-                                  HOSTCHARS + ".]+" + "(:[0-9]+)?(" +
-                                  URLPATH + ")?/?", GENURL)
-        self.textbuffer.match_add("(www|ftp)[" + HOSTCHARS + "]*\\.[" +
-                                  HOSTCHARS + ".]+" + "(:[0-9]+)?(" +
-                                  URLPATH + ")?/?", HTTP)
-        self.textbuffer.match_add("(mailto:)?[a-z0-9][a-z0-9.-]*@[a-z0-9]"
-                                  "[a-z0-9-]*(\\.[a-z0-9][a-z0-9-]*)+", MAIL)
-        
+        self.textbuffer.match_add(SCHEME + "//(" + USER + "@)?" +
+                                  HOST + "(:[0-9]+)?" +
+                                  URLPATH, GENURL)
+        self.textbuffer.match_add(r"(www\.|ftp\.)[" + HOSTCHARS + r"]*\.[" +
+                                  HOSTCHARS + ".]+" + "(:[0-9]+)?" +
+                                  URLPATH, HTTP)
+        self.textbuffer.match_add(r"(mailto:)?[\w][-.\w]*@[\w]"
+                                  r"[-\w]*(\.[\w][-.\w]*)+", MAIL)
+
     def _create_spell_menu(self):
         """
         Create a menu with all the installed spellchecks.
-        
+
         It is called each time the popup menu is opened. Each spellcheck
         forms a radio menu item, and the selected spellcheck is set as active.
-        
+
         :returns: menu containing all the installed spellchecks.
         :rtype: Gtk.Menu
         """
@@ -569,18 +574,18 @@ class StyledTextEditor(Gtk.TextView):
             menuitem.set_active(lang == active_spellcheck)
             menuitem.connect('activate', self._spell_change_cb, lang)
             menu.append(menuitem)
-            
+
             if group is None:
                 group = menuitem
-            
+
         return menu
 
     # Callback functions
-    
+
     def _on_toggle_action_activate(self, action):
         """
         Toggle a style.
-        
+
         Toggle styles are e.g. 'bold', 'italic', 'underline'.
         """
         if self._internal_style_change:
@@ -599,13 +604,13 @@ class StyledTextEditor(Gtk.TextView):
         selection_bounds = self.textbuffer.get_selection_bounds()
         if selection_bounds:
             # Paste text to clipboards
-            text = str(self.textbuffer.get_text(selection_bounds[0], 
+            text = str(self.textbuffer.get_text(selection_bounds[0],
                                                 selection_bounds[1], True))
-            clipboard = Gtk.Clipboard.get_for_display(Gdk.Display.get_default(), 
+            clipboard = Gtk.Clipboard.get_for_display(Gdk.Display.get_default(),
                         Gdk.SELECTION_CLIPBOARD)
 
             clipboard.set_text(text, -1)
-            clipboard = Gtk.Clipboard.get_for_display(Gdk.Display.get_default(), 
+            clipboard = Gtk.Clipboard.get_for_display(Gdk.Display.get_default(),
                         Gdk.SELECTION_PRIMARY)
             clipboard.set_text(text, -1)
             uri_dialog(self, None, self.setlink_callback)
@@ -617,9 +622,9 @@ class StyledTextEditor(Gtk.TextView):
         if uri:
             _LOG.debug("applying style 'link' with value '%s'" % uri)
             if not tag:
-                tag = LinkTag(self.textbuffer, 
+                tag = LinkTag(self.textbuffer,
                               data=uri,
-                              underline=Pango.Underline.SINGLE, 
+                              underline=Pango.Underline.SINGLE,
                               foreground=self.linkcolor)
                 selection_bounds = self.textbuffer.get_selection_bounds()
                 self.textbuffer.apply_tag(tag,
@@ -635,9 +640,13 @@ class StyledTextEditor(Gtk.TextView):
         current_value = self.textbuffer.get_style_at_cursor(style)
 
         if style == StyledTextTagType.FONTCOLOR:
-            color_dialog = Gtk.ColorChooserDialog(_("Select font color"))
+            color_dialog = Gtk.ColorChooserDialog(
+                title=_("Select font color"),
+                transient_for=self.transient_parent)
         elif style == StyledTextTagType.HIGHLIGHT:
-            color_dialog = Gtk.ColorChooserDialog(_("Select background color"))
+            color_dialog = Gtk.ColorChooserDialog(
+                title=_("Select background color"),
+                transient_for=self.transient_parent)
         else:
             _LOG.debug("unknown style: '%d'" % style)
             return
@@ -653,7 +662,7 @@ class StyledTextEditor(Gtk.TextView):
                                    int(rgba.green * 255),
                                    int(rgba.blue * 255))
         color_dialog.destroy()
-        
+
         if response == Gtk.ResponseType.OK:
             _LOG.debug("applying style '%d' with value '%s'" %
                        (style, str(value)))
@@ -663,7 +672,7 @@ class StyledTextEditor(Gtk.TextView):
         """Apply a format set by a ValueAction type of action."""
         if self._internal_style_change:
             return
-        
+
         style = int(action.get_name())
 
         value = action.get_value()
@@ -674,12 +683,12 @@ class StyledTextEditor(Gtk.TextView):
             self.textbuffer.apply_style(style, value)
         except ValueError:
             _LOG.debug("unable to convert '%s' to '%s'" %
-                       (text, StyledTextTagType.STYLE_TYPE[style]))
+                       (value, StyledTextTagType.STYLE_TYPE[style]))
 
     def _format_clear_cb(self, action):
         """
         Remove all formats from the selection or from all.
-        
+
         Remove only our own tags without touching other ones (e.g. Gtk.Spell),
         thus remove_all_tags() can not be used.
         """
@@ -689,7 +698,7 @@ class StyledTextEditor(Gtk.TextView):
                 self.textbuffer.remove_style(style)
 
             start, end = self.textbuffer.get_bounds()
-            tags = self.textbuffer._get_tag_from_range(start.get_offset(), 
+            tags = self.textbuffer._get_tag_from_range(start.get_offset(),
                                                        end.get_offset())
             for tag_name, tag_data in tags.items():
                 if tag_name.startswith("link"):
@@ -711,14 +720,14 @@ class StyledTextEditor(Gtk.TextView):
                 self._internal_style_change = True
                 action.set_active(style_value)
                 self._internal_style_change = False
-            
+
             if ((style == StyledTextTagType.FONTFACE) or
                 (style == StyledTextTagType.FONTSIZE)):
                 action = self.action_group.get_action(str(style))
                 self._internal_style_change = True
                 action.set_value(style_value)
                 self._internal_style_change = False
-            
+
     def _spell_change_cb(self, menuitem, spellcheck):
         """Set spell checker spellcheck according to user selection."""
         self.spellcheck.set_active_spellcheck(spellcheck)
@@ -727,7 +736,7 @@ class StyledTextEditor(Gtk.TextView):
         """Open the URL in a browser."""
         if not url:
             return
-        
+
         if flavor == HTTP:
             url = 'http:' + url
         elif flavor == MAIL:
@@ -745,9 +754,9 @@ class StyledTextEditor(Gtk.TextView):
                     # Edit the object:
                     obj_class, prop, value = url[9:].split("/")
                     from ..editors import EditObject
-                    EditObject(win_obj.dbstate, 
-                               win_obj.uistate, 
-                               win_obj.track, 
+                    EditObject(win_obj.dbstate,
+                               win_obj.uistate,
+                               win_obj.track,
                                obj_class, prop, value)
                     return
         else:
@@ -758,14 +767,14 @@ class StyledTextEditor(Gtk.TextView):
             display_url(url, obj.uistate)
         else:
             display_url(url)
-    
+
     def _copy_url_cb(self, menuitem, url, flavor):
         """Copy url to both useful selections."""
-        clipboard = Gtk.Clipboard.get_for_display(Gdk.Display.get_default(), 
+        clipboard = Gtk.Clipboard.get_for_display(Gdk.Display.get_default(),
                         Gdk.SELECTION_CLIPBOARD)
         clipboard.set_text(url, -1)
-        
-        clipboard = Gtk.Clipboard.get_for_display(Gdk.Display.get_default(), 
+
+        clipboard = Gtk.Clipboard.get_for_display(Gdk.Display.get_default(),
                         Gdk.SELECTION_PRIMARY)
         clipboard.set_text(url, -1)
 
@@ -778,21 +787,21 @@ class StyledTextEditor(Gtk.TextView):
         bounds = self.textbuffer.get_selection_bounds()
         if bounds:
             text = str(self.textbuffer.get_text(bounds[0], bounds[1], True))
-            clipboard = Gtk.Clipboard.get_for_display(Gdk.Display.get_default(), 
+            clipboard = Gtk.Clipboard.get_for_display(Gdk.Display.get_default(),
                         Gdk.SELECTION_CLIPBOARD)
             clipboard.set_text(text, -1)
-            clipboard = Gtk.Clipboard.get_for_display(Gdk.Display.get_default(), 
+            clipboard = Gtk.Clipboard.get_for_display(Gdk.Display.get_default(),
                         Gdk.SELECTION_PRIMARY)
             clipboard.set_text(text, -1)
-        uri_dialog(self, link_tag.data, 
+        uri_dialog(self, link_tag.data,
                    lambda uri: self.setlink_callback(uri, link_tag))
-    
+
     # public methods
-    
+
     def set_text(self, text):
         """
         Set the text of the text buffer of the editor.
-        
+
         :param text: formatted text to edit in the view.
         :type text: :class:`.StyledText`
         """
@@ -802,17 +811,17 @@ class StyledTextEditor(Gtk.TextView):
     def get_text(self):
         """
         Get the text of the text buffer of the editor.
-        
+
         :returns: the formatted text from the editor.
         :rtype: :class:`.StyledText`
         """
         start, end = self.textbuffer.get_bounds()
         return self.textbuffer.get_text(start, end, True)
-    
+
     def get_toolbar(self):
         """
         Get the formatting toolbar of the editor.
-        
+
         :returns: toolbar widget to use as formatting GUI.
         :rtype: Gtk.Toolbar
         """
@@ -835,7 +844,7 @@ def uri_dialog(self, uri, callback):
             # make a default link
             uri = "http://"
             # Check in order for an open page:
-            for object_class in ["Person", "Place", "Event", "Family", 
+            for object_class in ["Person", "Place", "Event", "Family",
                                  "Repository", "Source", "Media"]:
                 handle = obj.uistate.get_active(object_class)
                 if handle:
