@@ -9,7 +9,7 @@
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
 #
-# This program is distributed in the hope that it will be useful, 
+# This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
@@ -52,7 +52,7 @@ from gi.repository import Pango
 #-------------------------------------------------------------------------
 from gramps.gen.errors import MaskError, ValidationError, WindowActiveError
 from .undoableentry import UndoableEntry
-
+from gramps.gen.constfunc import is_quartz
 #============================================================================
 #
 # MaskedEntry and ValidatableMaskedEntry copied and merged from the Kiwi
@@ -64,17 +64,17 @@ from .undoableentry import UndoableEntry
 
 (DIRECTION_LEFT, DIRECTION_RIGHT) = (1, -1)
 
-(INPUT_ASCII_LETTER, 
- INPUT_ALPHA, 
- INPUT_ALPHANUMERIC, 
+(INPUT_ASCII_LETTER,
+ INPUT_ALPHA,
+ INPUT_ALPHANUMERIC,
  INPUT_DIGIT) = list(range(4))
 
 INPUT_FORMATS = {
-    '0': INPUT_DIGIT, 
-    'L': INPUT_ASCII_LETTER, 
-    'A': INPUT_ALPHANUMERIC, 
-    'a': INPUT_ALPHANUMERIC, 
-    '&': INPUT_ALPHA, 
+    '0': INPUT_DIGIT,
+    'L': INPUT_ASCII_LETTER,
+    'A': INPUT_ALPHANUMERIC,
+    'a': INPUT_ALPHANUMERIC,
+    '&': INPUT_ALPHA,
     }
 
 # Todo list: Other useful Masks
@@ -83,13 +83,13 @@ INPUT_FORMATS = {
 #  C - Alpha, optional
 
 INPUT_CHAR_MAP = {
-    INPUT_ASCII_LETTER:     lambda text: text in string.ascii_letters, 
-    INPUT_ALPHA:            str.isalpha, 
-    INPUT_ALPHANUMERIC:     str.isalnum, 
-    INPUT_DIGIT:            str.isdigit, 
+    INPUT_ASCII_LETTER:     lambda text: text in string.ascii_letters,
+    INPUT_ALPHA:            str.isalpha,
+    INPUT_ALPHANUMERIC:     str.isalnum,
+    INPUT_DIGIT:            str.isdigit,
     }
 
-(COL_TEXT, 
+(COL_TEXT,
  COL_OBJECT) = list(range(2))
 
 class MaskedEntry(UndoableEntry):
@@ -101,7 +101,7 @@ class MaskedEntry(UndoableEntry):
       - Mask, force the input to meet certain requirements
       - IconEntry, allows you to have an icon inside the entry
       - convenience functions for completion
-    
+
     .. note:: Gramps does not use the mask feature at the moment, so that code
               path is not tested
     """
@@ -122,7 +122,7 @@ class MaskedEntry(UndoableEntry):
         self.connect('focus-out-event', self._on_focus_out_event)
         self.connect('move-cursor', self._on_move_cursor)
         self.connect('button-press-event', self._on_button_press_event)
-        self.connect('notify::cursor-position', 
+        self.connect('notify::cursor-position',
                      self._on_notify_cursor_position)
 
         self._completion = None
@@ -173,7 +173,7 @@ class MaskedEntry(UndoableEntry):
     def set_mask(self, mask):
         """
         Set the mask of the Entry.
-        
+
         Supported format characters are:
 
           - '0' digit
@@ -182,7 +182,7 @@ class MaskedEntry(UndoableEntry):
           - 'a' alphanumeric, honors the locale
           - 'A' alphanumeric, honors the locale
 
-        This is similar to MaskedTextBox: 
+        This is similar to MaskedTextBox:
         http://msdn2.microsoft.com/en-us/library/system.windows.forms.maskedtextbox.mask(VS.80).aspx
 
         Example mask for a ISO-8601 date
@@ -332,7 +332,7 @@ class MaskedEntry(UndoableEntry):
             start, end = self._mask_fields[field]
             return end - start
 
-    def _shift_text(self, start, end, direction=DIRECTION_LEFT, 
+    def _shift_text(self, start, end, direction=DIRECTION_LEFT,
                     positions=1):
         """
         Shift the text, to the right or left, n positions. Note that this
@@ -361,11 +361,11 @@ class MaskedEntry(UndoableEntry):
                 # Non-static char shoud be here. Get the next one (depending
                 # on the direction, and the number of positions to skip.)
                 #
-                # When shifting left, the next char will be on the right, 
+                # When shifting left, the next char will be on the right,
                 # so, it will be appended, to the new text.
                 # Otherwise, when shifting right, the char will be
                 # prepended.
-                next_pos = self._get_next_non_static_char_pos(i, direction, 
+                next_pos = self._get_next_non_static_char_pos(i, direction,
                                                               positions-1)
 
                 # If its outside the bounds of the region, ignore it.
@@ -393,7 +393,7 @@ class MaskedEntry(UndoableEntry):
 
         return new_text
 
-    def _get_next_non_static_char_pos(self, pos, direction=DIRECTION_LEFT, 
+    def _get_next_non_static_char_pos(self, pos, direction=DIRECTION_LEFT,
                                       skip=0):
         """
         Get next non-static char position, skiping some chars, if necessary.
@@ -484,7 +484,7 @@ class MaskedEntry(UndoableEntry):
 
     def _get_completion(self):
         # Check so we have completion enabled, not this does not
-        # depend on the property, the user can manually override it, 
+        # depend on the property, the user can manually override it,
         # as long as there is a completion object set
         completion = self.get_completion()
         if completion:
@@ -503,7 +503,7 @@ class MaskedEntry(UndoableEntry):
         #completion.set_model(Gtk.ListStore(str, object))
         completion.set_model(Gtk.ListStore(GObject.TYPE_STRING))
         completion.set_text_column(0)
-        #completion.connect("match-selected", 
+        #completion.connect("match-selected",
                            #self._on_completion__match_selected)
 
         self._completion = Gtk.Entry.get_completion(self)
@@ -513,7 +513,7 @@ class MaskedEntry(UndoableEntry):
     def set_completion_mode(self, popup=None, inline=None):
         """
         Set the way how completion is presented.
-        
+
         :param popup: enable completion in popup window
         :type popup: boolean
         :param inline: enable inline completion
@@ -524,7 +524,7 @@ class MaskedEntry(UndoableEntry):
             completion.set_popup_completion(popup)
         if inline is not None:
             completion.set_inline_completion(inline)
-            
+
     def _completion_exact_match_func(self, completion, key, iter):
         model = completion.get_model()
         if not len(model):
@@ -576,7 +576,7 @@ class MaskedEntry(UndoableEntry):
 
         :param new: The char that wants to be inserted.
         :param pos: The position where it wants to be inserted.
-        :returns: Returns None if it can be inserted. If it cannot be, 
+        :returns: Returns None if it can be inserted. If it cannot be,
                   return the next position where it can be successfuly
                   inserted.
         """
@@ -610,7 +610,7 @@ class MaskedEntry(UndoableEntry):
 
         return None
 
-#   When inserting new text, supose, the entry, at some time is like this, 
+#   When inserting new text, supose, the entry, at some time is like this,
 #   ahd the user presses '0', for instance:
 #   --------------------------------
 #   | ( 1 2 )   3 4 5   - 6 7 8 9  |
@@ -772,7 +772,7 @@ class MaskedEntry(UndoableEntry):
 
         # Shift Left
         new_text = (text[:start] +
-                    self._shift_text(start, _end, DIRECTION_LEFT, 
+                    self._shift_text(start, _end, DIRECTION_LEFT,
                                      end-start) +
                     text[_end:])
 
@@ -908,7 +908,7 @@ class MaskedEntry(UndoableEntry):
         self.set_icon_from_icon_name(Gtk.EntryIconPosition.SECONDARY, icon_name)
 
     # Gtk.EntryCompletion convenience function
-    
+
     def prefill(self, itemdata, sort=False):
         if not isinstance(itemdata, (list, tuple)):
             raise TypeError("'data' parameter must be a list or tuple of item "
@@ -953,37 +953,32 @@ class ValidatableMaskedEntry(MaskedEntry):
     __gtype_name__ = 'ValidatableMaskedEntry'
 
     __gsignals__ = {
-        'content-changed': (GObject.SignalFlags.RUN_FIRST, 
-                            None, 
-                            ()), 
-        'validation-changed': (GObject.SignalFlags.RUN_FIRST, 
-                               None, 
-                               (GObject.TYPE_BOOLEAN, )), 
-        'validate': (GObject.SignalFlags.RUN_LAST, 
-                     GObject.TYPE_PYOBJECT, 
-                     (GObject.TYPE_PYOBJECT, )), 
-        'changed': 'override', 
+        'content-changed': (GObject.SignalFlags.RUN_FIRST,
+                            None,
+                            ()),
+        'validation-changed': (GObject.SignalFlags.RUN_FIRST,
+                               None,
+                               (GObject.TYPE_BOOLEAN, )),
+        'validate': (GObject.SignalFlags.RUN_LAST,
+                     GObject.TYPE_PYOBJECT,
+                     (GObject.TYPE_PYOBJECT, )),
+        'changed': 'override',
     }
 
-    if GLib.MINOR_VERSION < 42:
-        __gparam = GObject.PARAM_READWRITE
-    else:
-        __gparam = GObject.ParamFlags.READWRITE
-
     __gproperties__ = {
-        'data-type': (GObject.TYPE_PYOBJECT, 
-                       'Data Type of the widget', 
-                       'Type object', 
-                       __gparam), 
-        'mandatory': (GObject.TYPE_BOOLEAN, 
-                      'Mandatory', 
-                      'Mandatory', 
-                      False, 
-                      __gparam),
+        'data-type': (GObject.TYPE_PYOBJECT,
+                       'Data Type of the widget',
+                       'Type object',
+                       GObject.PARAM_READWRITE),
+        'mandatory': (GObject.TYPE_BOOLEAN,
+                      'Mandatory',
+                      'Mandatory',
+                      False,
+                      GObject.PARAM_READWRITE),
     }
-                            
+
     # FIXME put the data type support back
-    #allowed_data_types = (basestring, datetime.date, datetime.time, 
+    #allowed_data_types = (basestring, datetime.date, datetime.time,
                           #datetime.datetime, object) + number
 
     def __init__(self, data_type=None, err_color="pink", error_icon=ERROR_ICON):
@@ -993,7 +988,7 @@ class ValidatableMaskedEntry(MaskedEntry):
         self._block_changed = False
 
         MaskedEntry.__init__(self)
-        
+
         self._valid = True
         self._def_error_msg = None
 
@@ -1024,7 +1019,7 @@ class ValidatableMaskedEntry(MaskedEntry):
 
     def do_get_property(self, prop):
         """Return the gproperty's value."""
-        
+
         if prop.name == 'data-type':
             return self.data_type
         elif prop.name == 'mandatory':
@@ -1034,18 +1029,18 @@ class ValidatableMaskedEntry(MaskedEntry):
 
     def do_set_property(self, prop, value):
         """Set the property of writable properties."""
-        
+
         if prop.name == 'data-type':
             if value is None:
                 self.data_type = value
                 return
-        
+
             # FIXME put the data type support back
             #if not issubclass(value, self.allowed_data_types):
                 #raise TypeError(
                     #"%s only accept %s types, not %r"
-                    #% (self, 
-                       #' or '.join([t.__name__ for t in self.allowed_data_types]), 
+                    #% (self,
+                       #' or '.join([t.__name__ for t in self.allowed_data_types]),
                        #value))
             self.data_type = value
         elif prop.name == 'mandatory':
@@ -1058,19 +1053,19 @@ class ValidatableMaskedEntry(MaskedEntry):
     def set_default_error_msg(self, text):
         """
         Set default message for validation error.
-        
+
         Default error message for an instance is useful when completion is
         used, because this case custom validation is not called.
-                
+
         :param text: can contain one and only one '%s', where the actual value
                      of the Entry will be inserted.
         :type text: str
         """
         if not isinstance(text, str):
             raise TypeError("text must be a string")
-            
+
         self._def_error_msg = text
-        
+
     def is_valid(self):
         """
         :returns: True if the widget is in validated state
@@ -1158,14 +1153,14 @@ class ValidatableMaskedEntry(MaskedEntry):
 
         generic_text = _("'%s' is not a valid value "
                          "for this field") % self.get_text()
-        
+
         # If there is no error text, let's try with the default or
         # fall back to a generic one
         if not text:
             text = self._def_error_msg
         if not text:
             text = generic_text
-            
+
         try:
             text.index('%s')
             text = text % self.get_text()
@@ -1243,26 +1238,32 @@ class ValidatableMaskedEntry(MaskedEntry):
 
 def main(args):
     from gramps.gen.datehandler import parser
-    
+
     def on_validate(widget, text):
         myDate = parser.parse(text)
         if not myDate.is_regular():
             # used on AgeOnDateGramplet
             return ValidationError(_("'%s' is not a valid date value"))
-        
+
     win = Gtk.Window()
     win.set_title('ValidatableMaskedEntry test window')
     win.set_position(Gtk.WindowPosition.CENTER)
+    #Set the mnemonic modifier on Macs to alt-ctrl so that it
+    #doesn't interfere with the extended keyboard, see
+    #https://gramps-project.org/bugs/view.php?id=6943
+    if is_quartz():
+        win.set_mnemonic_modifier(
+            Gdk.ModifierType.CONTROL_MASK | Gdk.ModifierType.MOD1_MASK)
     def cb(window, event):
         Gtk.main_quit()
     win.connect('delete-event', cb)
 
     vbox = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
     win.add(vbox)
-    
+
     label = Gtk.Label(label='Pre-filled entry validated against the given list:')
     vbox.pack_start(label, True, True, 0)
-    
+
     widget1 = ValidatableMaskedEntry(str)
     widget1.set_completion_mode(inline=True, popup=False)
     widget1.set_default_error_msg("'%s' is not a default Event")
@@ -1270,17 +1271,17 @@ def main(args):
     widget1.prefill(('Birth', 'Death', 'Conseption'))
     #widget1.set_exact_completion(True)
     vbox.pack_start(widget1, True, False, 0)
-    
+
     label = Gtk.Label(label='Mandatory masked entry validated against user function:')
     vbox.pack_start(label, True, True, 0)
-    
+
     #widget2 = ValidatableMaskedEntry(str, "#e0e0e0", error_icon=None)
     widget2 = ValidatableMaskedEntry()
     widget2.set_mask('00/00/0000')
     widget2.connect('validate', on_validate)
     widget2.mandatory = True
     vbox.pack_start(widget2, True, False, 0)
-    
+
     win.show_all()
     Gtk.main()
 
