@@ -1,6 +1,6 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
-# Copyright (C) 2009       Pander Musubi 
+# Copyright (C) 2009       Pander Musubi
 # Copyright (C) 2009       Douglas S. Blank
 #
 # This program is free software; you can redistribute it and/or modify
@@ -18,14 +18,23 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 #
-from __future__ import unicode_literals
 
+#-------------------------------------------------------------------------
+#
+# Python modules
+#
+#-------------------------------------------------------------------------
 from collections import defaultdict
-from gramps.gen.const import GRAMPS_LOCALE as glocale
-_ = glocale.translation.gettext
 
+#-------------------------------------------------------------------------
+#
+# Gramps modules
+#
+#-------------------------------------------------------------------------
 from gramps.gen.plug import Gramplet
 from gramps.gen.config import config
+from gramps.gen.const import GRAMPS_LOCALE as glocale
+_ = glocale.translation.gettext
 
 _YIELD_INTERVAL = 350
 
@@ -46,9 +55,9 @@ class GivenNameCloudGramplet(Gramplet):
         self.set_text(_("No Family Tree loaded."))
 
     def db_changed(self):
-        self.dbstate.db.connect('person-add', self.update)
-        self.dbstate.db.connect('person-delete', self.update)
-        self.dbstate.db.connect('person-update', self.update)
+        self.connect(self.dbstate.db, 'person-add', self.update)
+        self.connect(self.dbstate.db, 'person-delete', self.update)
+        self.connect(self.dbstate.db, 'person-update', self.update)
 
     def on_load(self):
         if len(self.gui.data) > 0:
@@ -68,12 +77,12 @@ class GivenNameCloudGramplet(Gramplet):
             allnames = [person.get_primary_name()] + person.get_alternate_names()
             allnames = set(name.get_first_name().strip() for name in allnames)
             for givenname in allnames:
-                anyNBSP = givenname.split('\u00A0')
-                if len(anyNBSP) > 1: # there was an NBSP, a non-breaking space
-                    first_two = anyNBSP[0] + '\u00A0' + anyNBSP[1].split()[0]
+                nbsp = givenname.split('\u00A0')
+                if len(nbsp) > 1: # there was an NBSP, a non-breaking space
+                    first_two = nbsp[0] + '\u00A0' + nbsp[1].split()[0]
                     givensubnames[first_two] += 1
                     representative_handle[first_two] = person.handle
-                    givenname = ' '.join(anyNBSP[1].split()[1:])
+                    givenname = ' '.join(nbsp[1].split()[1:])
                 for givensubname in givenname.split():
                     givensubnames[givensubname] += 1
                     representative_handle[givensubname] = person.handle
@@ -83,10 +92,11 @@ class GivenNameCloudGramplet(Gramplet):
 
         total_people = cnt
         givensubname_sort = []
-		
+
         total = cnt = 0
         for givensubname in givensubnames:
-            givensubname_sort.append( (givensubnames[givensubname], givensubname) )
+            givensubname_sort.append((givensubnames[givensubname],
+                                      givensubname))
             total += givensubnames[givensubname]
             cnt += 1
             if not cnt % _YIELD_INTERVAL:
@@ -98,8 +108,8 @@ class GivenNameCloudGramplet(Gramplet):
         cloud_values = []
 
         for count, givensubname in givensubname_sort:
-            cloud_names.append( (count, givensubname) )
-            cloud_values.append( count )
+            cloud_names.append((count, givensubname))
+            cloud_values.append(count)
 
         cloud_names.sort(key=lambda k: k[1])
         counts = sorted(set(cloud_values), reverse=True)
@@ -130,14 +140,14 @@ class GivenNameCloudGramplet(Gramplet):
                     text = givensubname
                 size = make_tag_size(count, counts)
                 self.link(text, 'Given', text, size,
-                          "%s, %.2f%% (%d)" % 
-                          (text, 
-                           (float(count)/total_people) * 100, 
+                          "%s, %.2f%% (%d)" %
+                          (text,
+                           (float(count)/total_people) * 100,
                            count))
                 self.append_text(" ")
                 showing += 1
 
-        self.append_text(("\n\n" + _("Total unique given names") + ": %d\n") % 
+        self.append_text(("\n\n" + _("Total unique given names") + ": %d\n") %
                          total_givensubnames)
         self.append_text((_("Total given names showing") + ": %d\n") % showing)
         self.append_text((_("Total people") + ": %d") % total_people, "begin")
