@@ -20,12 +20,15 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
+from gramps.gen.plug._pluginreg import register, STABLE, UNSTABLE, GRAMPLET
+from gramps.gen.const import GRAMPS_LOCALE as glocale
+_ = glocale.translation.gettext
 
-MODULE_VERSION="4.2" 
+MODULE_VERSION="5.0"
 
 #------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
 #------------------------------------------------------------------------
 
@@ -37,9 +40,9 @@ _ = glocale.translation.sgettext
 # Register Gramplet
 #
 #------------------------------------------------------------------------
-register(GRAMPLET, 
-         id="Age on Date", 
-         name=_("Age on Date"), 
+register(GRAMPLET,
+         id="Age on Date",
+         name=_("Age on Date"),
          description = _("Gramplet showing ages of living people on a specific date"),
          version="2.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -50,7 +53,7 @@ register(GRAMPLET,
          gramplet_title=_("Age on Date"),
          )
 
-register(GRAMPLET, 
+register(GRAMPLET,
          id = "Age Stats",
          name = _("Age Stats"),
          description = _("Gramplet showing graphs of various ages"),
@@ -66,9 +69,9 @@ register(GRAMPLET,
          gramps_target_version=MODULE_VERSION,
          )
 
-register(GRAMPLET, 
-         id="Calendar", 
-         name=_("Calendar"), 
+register(GRAMPLET,
+         id="Calendar",
+         name=_("Calendar"),
          description = _("Gramplet showing calendar and events on specific dates in history"),
          status = STABLE,
          fname="calendargramplet.py",
@@ -113,9 +116,9 @@ register(GRAMPLET,
          navtypes=["Person"],
          )
 
-register(GRAMPLET, 
-         id= "Fan Chart", 
-         name=_("Fan Chart"), 
+register(GRAMPLET,
+         id= "Fan Chart",
+         name=_("Fan Chart"),
          description = _("Gramplet showing active person's direct ancestors as a fanchart"),
          status = STABLE,
          fname="fanchartgramplet.py",
@@ -130,9 +133,9 @@ register(GRAMPLET,
          navtypes=["Person"],
          )
 
-register(GRAMPLET, 
-         id= "Descendant Fan Chart", 
-         name=_("Descendant Fan Chart"), 
+register(GRAMPLET,
+         id= "Descendant Fan Chart",
+         name=_("Descendant Fan Chart"),
          description = _("Gramplet showing active person's direct descendants as a fanchart"),
          status = STABLE,
          fname="fanchartdescgramplet.py",
@@ -147,9 +150,26 @@ register(GRAMPLET,
          navtypes=["Person"],
          )
 
-register(GRAMPLET, 
-         id="FAQ", 
-         name=_("FAQ"), 
+register(GRAMPLET,
+         id= "2-Way Fan Chart",
+         name=_("2-Way Fan Chart"),
+         description = _("Gramplet showing active person's direct ancestors and descendants as a fanchart"),
+         status = STABLE,
+         fname="fanchart2waygramplet.py",
+         height=300,
+         expand=True,
+         gramplet = 'FanChart2WayGramplet',
+         detached_height =300,
+         detached_width = 300,
+         gramplet_title=_("2-Way Fan"),
+         version="1.0.0",
+         gramps_target_version=MODULE_VERSION,
+         navtypes=["Person"],
+         )
+
+register(GRAMPLET,
+         id="FAQ",
+         name=_("FAQ"),
          description = _("Gramplet showing frequently asked questions"),
          status = STABLE,
          fname="faqgramplet.py",
@@ -160,9 +180,9 @@ register(GRAMPLET,
          gramps_target_version=MODULE_VERSION,
          )
 
-register(GRAMPLET, 
-         id= "Given Name Cloud", 
-         name=_("Given Name Cloud"), 
+register(GRAMPLET,
+         id= "Given Name Cloud",
+         name=_("Given Name Cloud"),
          description = _("Gramplet showing all given names as a text cloud"),
          status = STABLE,
          fname="givennamegramplet.py",
@@ -174,9 +194,9 @@ register(GRAMPLET,
          gramps_target_version=MODULE_VERSION,
          )
 
-register(GRAMPLET, 
-         id="Pedigree", 
-         name=_("Pedigree"), 
+register(GRAMPLET,
+         id="Pedigree",
+         name=_("Pedigree"),
          description = _("Gramplet showing active person's ancestors"),
          status = STABLE,
          fname="pedigreegramplet.py",
@@ -191,9 +211,9 @@ register(GRAMPLET,
          navtypes=["Person"],
          )
 
-register(GRAMPLET, 
-         id="Quick View", 
-         name=_("Quick View"), 
+register(GRAMPLET,
+         id="Quick View",
+         name=_("Quick View"),
          description = _("Gramplet showing an active item Quick View"),
          status = STABLE,
          fname="quickviewgramplet.py",
@@ -207,9 +227,9 @@ register(GRAMPLET,
          gramps_target_version=MODULE_VERSION,
          )
 
-register(GRAMPLET, 
-         id="Relatives", 
-         name=_("Relatives"), 
+register(GRAMPLET,
+         id="Relatives",
+         name=_("Relatives"),
          description = _("Gramplet showing active person's relatives"),
          status = STABLE,
          fname="relativegramplet.py",
@@ -223,9 +243,9 @@ register(GRAMPLET,
          navtypes=["Person"],
          )
 
-register(GRAMPLET, 
-         id="Session Log", 
-         name=_("Session Log"), 
+register(GRAMPLET,
+         id="Session Log",
+         name=_("Session Log"),
          description = _("Gramplet showing all activity for this session"),
          status = STABLE,
          fname="sessionloggramplet.py",
@@ -237,9 +257,9 @@ register(GRAMPLET,
          gramps_target_version=MODULE_VERSION,
          )
 
-register(GRAMPLET, 
-         id="Statistics", 
-         name=_("Statistics"), 
+register(GRAMPLET,
+         id="Statistics",
+         name=_("Statistics"),
          description = _("Gramplet showing summary data of the Family Tree"),
          status = STABLE,
          fname="statsgramplet.py",
@@ -251,9 +271,9 @@ register(GRAMPLET,
          gramps_target_version=MODULE_VERSION,
          )
 
-register(GRAMPLET, 
-         id= "Surname Cloud", 
-         name=_("Surname Cloud"), 
+register(GRAMPLET,
+         id= "Surname Cloud",
+         name=_("Surname Cloud"),
          description = _("Gramplet showing all surnames as a text cloud"),
          status = STABLE,
          fname="surnamecloudgramplet.py",
@@ -265,9 +285,9 @@ register(GRAMPLET,
          gramps_target_version=MODULE_VERSION,
          )
 
-register(GRAMPLET, 
-         id="To Do", 
-         name=_("gramplet|To Do"), 
+register(GRAMPLET,
+         id="To Do",
+         name=_("gramplet|To Do"),
          description = _("Gramplet for displaying a To Do list"),
          status = STABLE,
          fname="todogramplet.py",
@@ -280,9 +300,9 @@ register(GRAMPLET,
          navtypes=["Dashboard"],
          )
 
-register(GRAMPLET, 
-         id= "Top Surnames", 
-         name=_("Top Surnames"), 
+register(GRAMPLET,
+         id= "Top Surnames",
+         name=_("Top Surnames"),
          description = _("Gramplet showing most frequent surnames in this tree"),
          status = STABLE,
          fname="topsurnamesgramplet.py",
@@ -293,9 +313,9 @@ register(GRAMPLET,
          gramps_target_version=MODULE_VERSION,
          )
 
-register(GRAMPLET, 
-         id="Welcome", 
-         name=_("Welcome"), 
+register(GRAMPLET,
+         id="Welcome",
+         name=_("Welcome"),
          description = _("Gramplet showing a welcome message"),
          status = STABLE,
          fname="welcomegramplet.py",
@@ -307,9 +327,9 @@ register(GRAMPLET,
          gramps_target_version=MODULE_VERSION,
          )
 
-register(GRAMPLET, 
-         id = "What's Next", 
-         name =_("What's Next"), 
+register(GRAMPLET,
+         id = "What's Next",
+         name =_("What's Next"),
          description = _("Gramplet suggesting items to research"),
          status = STABLE,
          fname="whatsnext.py",
@@ -324,9 +344,9 @@ register(GRAMPLET,
 #------------------------------------------------------------------------
 # Bottombar
 #------------------------------------------------------------------------
-register(GRAMPLET, 
-         id="Person Details", 
-         name=_("Person Details"), 
+register(GRAMPLET,
+         id="Person Details",
+         name=_("Person Details"),
          description = _("Gramplet showing details of a person"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -338,9 +358,9 @@ register(GRAMPLET,
          navtypes=["Person"],
          )
 
-register(GRAMPLET, 
-         id="Repository Details", 
-         name=_("Repository Details"), 
+register(GRAMPLET,
+         id="Repository Details",
+         name=_("Repository Details"),
          description = _("Gramplet showing details of a repository"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -352,9 +372,9 @@ register(GRAMPLET,
          navtypes=["Repository"],
          )
 
-register(GRAMPLET, 
-         id="Place Details", 
-         name=_("Place Details"), 
+register(GRAMPLET,
+         id="Place Details",
+         name=_("Place Details"),
          description = _("Gramplet showing details of a place"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -366,9 +386,9 @@ register(GRAMPLET,
          navtypes=["Place"],
          )
 
-register(GRAMPLET, 
-         id="Media Preview", 
-         name=_("Media Preview"), 
+register(GRAMPLET,
+         id="Media Preview",
+         name=_("Media Preview"),
          description = _("Gramplet showing a preview of a media object"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -415,18 +435,24 @@ else:
             from gramps.gui.dialog import MessageHideDialog
             from gramps.gen.const import URL_WIKISTRING
             gexiv2_dict = { 'gramps_wiki_build_gexiv2_url' :
-                                URL_WIKISTRING + 
+                                URL_WIKISTRING +
                                     "GEPS_029:_GTK3-GObject_introspection"
                                     "_Conversion#GExiv2_for_Image_metadata" }
             title = _("GExiv2 module not loaded.")
             message = _("Image metadata functionality will not be available.\n"
                         "To build it for Gramps see "
                         "%(gramps_wiki_build_gexiv2_url)s" % gexiv2_dict )
-            MessageHideDialog(title, message, 'interface.ignore-gexiv2')
+            if uistate:
+                MessageHideDialog(title, message,
+                                  'interface.ignore-gexiv2',
+                                  parent=uistate.window)
+            else:
+                MessageHideDialog(title, message,
+                                  'interface.ignore-gexiv2')
 
-register(GRAMPLET, 
-         id="Person Residence", 
-         name=_("Person Residence"), 
+register(GRAMPLET,
+         id="Person Residence",
+         name=_("Person Residence"),
          description = _("Gramplet showing residence events for a person"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -438,9 +464,9 @@ register(GRAMPLET,
          navtypes=["Person"],
          )
 
-register(GRAMPLET, 
-         id="Person Events", 
-         name=_("Person Events"), 
+register(GRAMPLET,
+         id="Person Events",
+         name=_("Person Events"),
          description = _("Gramplet showing the events for a person"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -452,9 +478,9 @@ register(GRAMPLET,
          navtypes=["Person"],
          )
 
-register(GRAMPLET, 
-         id="Family Events", 
-         name=_("Family Events"), 
+register(GRAMPLET,
+         id="Family Events",
+         name=_("Family Events"),
          description = _("Gramplet showing the events for a family"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -466,9 +492,9 @@ register(GRAMPLET,
          navtypes=["Family"],
          )
 
-register(GRAMPLET, 
-         id="Person Gallery", 
-         name=_("Person Gallery"), 
+register(GRAMPLET,
+         id="Person Gallery",
+         name=_("Person Gallery"),
          description = _("Gramplet showing media objects for a person"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -480,9 +506,9 @@ register(GRAMPLET,
          navtypes=["Person"],
          )
 
-register(GRAMPLET, 
-         id="Family Gallery", 
-         name=_("Family Gallery"), 
+register(GRAMPLET,
+         id="Family Gallery",
+         name=_("Family Gallery"),
          description = _("Gramplet showing media objects for a family"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -494,9 +520,9 @@ register(GRAMPLET,
          navtypes=["Family"],
          )
 
-register(GRAMPLET, 
-         id="Event Gallery", 
-         name=_("Event Gallery"), 
+register(GRAMPLET,
+         id="Event Gallery",
+         name=_("Event Gallery"),
          description = _("Gramplet showing media objects for an event"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -508,9 +534,9 @@ register(GRAMPLET,
          navtypes=["Event"],
          )
 
-register(GRAMPLET, 
-         id="Place Gallery", 
-         name=_("Place Gallery"), 
+register(GRAMPLET,
+         id="Place Gallery",
+         name=_("Place Gallery"),
          description = _("Gramplet showing media objects for a place"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -522,9 +548,9 @@ register(GRAMPLET,
          navtypes=["Place"],
          )
 
-register(GRAMPLET, 
-         id="Source Gallery", 
-         name=_("Source Gallery"), 
+register(GRAMPLET,
+         id="Source Gallery",
+         name=_("Source Gallery"),
          description = _("Gramplet showing media objects for a source"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -536,9 +562,9 @@ register(GRAMPLET,
          navtypes=["Source"],
          )
 
-register(GRAMPLET, 
-         id="Citation Gallery", 
-         name=_("Citation Gallery"), 
+register(GRAMPLET,
+         id="Citation Gallery",
+         name=_("Citation Gallery"),
          description = _("Gramplet showing media objects for a citation"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -550,9 +576,9 @@ register(GRAMPLET,
          navtypes=["Citation"],
          )
 
-register(GRAMPLET, 
-         id="Person Attributes", 
-         name=_("Person Attributes"), 
+register(GRAMPLET,
+         id="Person Attributes",
+         name=_("Person Attributes"),
          description = _("Gramplet showing the attributes of a person"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -564,9 +590,9 @@ register(GRAMPLET,
          navtypes=["Person"],
          )
 
-register(GRAMPLET, 
-         id="Event Attributes", 
-         name=_("Event Attributes"), 
+register(GRAMPLET,
+         id="Event Attributes",
+         name=_("Event Attributes"),
          description = _("Gramplet showing the attributes of an event"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -578,9 +604,9 @@ register(GRAMPLET,
          navtypes=["Event"],
          )
 
-register(GRAMPLET, 
-         id="Family Attributes", 
-         name=_("Family Attributes"), 
+register(GRAMPLET,
+         id="Family Attributes",
+         name=_("Family Attributes"),
          description = _("Gramplet showing the attributes of a family"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -592,9 +618,9 @@ register(GRAMPLET,
          navtypes=["Family"],
          )
 
-register(GRAMPLET, 
-         id="Media Attributes", 
-         name=_("Media Attributes"), 
+register(GRAMPLET,
+         id="Media Attributes",
+         name=_("Media Attributes"),
          description = _("Gramplet showing the attributes of a media object"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -634,9 +660,9 @@ register(GRAMPLET,
          navtypes=["Citation"],
          )
 
-register(GRAMPLET, 
-         id="Person Notes", 
-         name=_("Person Notes"), 
+register(GRAMPLET,
+         id="Person Notes",
+         name=_("Person Notes"),
          description = _("Gramplet showing the notes for a person"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -648,9 +674,9 @@ register(GRAMPLET,
          navtypes=["Person"],
          )
 
-register(GRAMPLET, 
-         id="Event Notes", 
-         name=_("Event Notes"), 
+register(GRAMPLET,
+         id="Event Notes",
+         name=_("Event Notes"),
          description = _("Gramplet showing the notes for an event"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -662,9 +688,9 @@ register(GRAMPLET,
          navtypes=["Event"],
          )
 
-register(GRAMPLET, 
-         id="Family Notes", 
-         name=_("Family Notes"), 
+register(GRAMPLET,
+         id="Family Notes",
+         name=_("Family Notes"),
          description = _("Gramplet showing the notes for a family"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -676,9 +702,9 @@ register(GRAMPLET,
          navtypes=["Family"],
          )
 
-register(GRAMPLET, 
-         id="Place Notes", 
-         name=_("Place Notes"), 
+register(GRAMPLET,
+         id="Place Notes",
+         name=_("Place Notes"),
          description = _("Gramplet showing the notes for a place"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -690,9 +716,9 @@ register(GRAMPLET,
          navtypes=["Place"],
          )
 
-register(GRAMPLET, 
-         id="Source Notes", 
-         name=_("Source Notes"), 
+register(GRAMPLET,
+         id="Source Notes",
+         name=_("Source Notes"),
          description = _("Gramplet showing the notes for a source"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -704,9 +730,9 @@ register(GRAMPLET,
          navtypes=["Source"],
          )
 
-register(GRAMPLET, 
-         id="Citation Notes", 
-         name=_("Citation Notes"), 
+register(GRAMPLET,
+         id="Citation Notes",
+         name=_("Citation Notes"),
          description = _("Gramplet showing the notes for a citation"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -718,9 +744,9 @@ register(GRAMPLET,
          navtypes=["Citation"],
          )
 
-register(GRAMPLET, 
-         id="Repository Notes", 
-         name=_("Repository Notes"), 
+register(GRAMPLET,
+         id="Repository Notes",
+         name=_("Repository Notes"),
          description = _("Gramplet showing the notes for a repository"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -732,9 +758,9 @@ register(GRAMPLET,
          navtypes=["Repository"],
          )
 
-register(GRAMPLET, 
-         id="Media Notes", 
-         name=_("Media Notes"), 
+register(GRAMPLET,
+         id="Media Notes",
+         name=_("Media Notes"),
          description = _("Gramplet showing the notes for a media object"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -746,9 +772,9 @@ register(GRAMPLET,
          navtypes=["Media"],
          )
 
-register(GRAMPLET, 
-         id="Person Citations", 
-         name=_("Person Citations"), 
+register(GRAMPLET,
+         id="Person Citations",
+         name=_("Person Citations"),
          description = _("Gramplet showing the citations for a person"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -760,9 +786,9 @@ register(GRAMPLET,
          navtypes=["Person"],
          )
 
-register(GRAMPLET, 
-         id="Event Citations", 
-         name=_("Event Citations"), 
+register(GRAMPLET,
+         id="Event Citations",
+         name=_("Event Citations"),
          description = _("Gramplet showing the citations for an event"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -774,9 +800,9 @@ register(GRAMPLET,
          navtypes=["Event"],
          )
 
-register(GRAMPLET, 
-         id="Family Citations", 
-         name=_("Family Citations"), 
+register(GRAMPLET,
+         id="Family Citations",
+         name=_("Family Citations"),
          description = _("Gramplet showing the citations for a family"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -788,9 +814,9 @@ register(GRAMPLET,
          navtypes=["Family"],
          )
 
-register(GRAMPLET, 
-         id="Place Citations", 
-         name=_("Place Citations"), 
+register(GRAMPLET,
+         id="Place Citations",
+         name=_("Place Citations"),
          description = _("Gramplet showing the citations for a place"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -802,9 +828,9 @@ register(GRAMPLET,
          navtypes=["Place"],
          )
 
-register(GRAMPLET, 
-         id="Media Citations", 
-         name=_("Media Citations"), 
+register(GRAMPLET,
+         id="Media Citations",
+         name=_("Media Citations"),
          description = _("Gramplet showing the citations for a media object"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -816,9 +842,9 @@ register(GRAMPLET,
          navtypes=["Media"],
          )
 
-register(GRAMPLET, 
-         id="Person Children", 
-         name=_("Person Children"), 
+register(GRAMPLET,
+         id="Person Children",
+         name=_("Person Children"),
          description = _("Gramplet showing the children of a person"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -830,9 +856,9 @@ register(GRAMPLET,
          navtypes=["Person"],
          )
 
-register(GRAMPLET, 
-         id="Family Children", 
-         name=_("Family Children"), 
+register(GRAMPLET,
+         id="Family Children",
+         name=_("Family Children"),
          description = _("Gramplet showing the children of a family"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -970,9 +996,9 @@ register(GRAMPLET,
          navtypes=["Note"],
          )
 
-register(GRAMPLET, 
-         id="Person Filter", 
-         name=_("Person Filter"), 
+register(GRAMPLET,
+         id="Person Filter",
+         name=_("Person Filter"),
          description = _("Gramplet providing a person filter"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -984,9 +1010,9 @@ register(GRAMPLET,
          navtypes=["Person"],
          )
 
-register(GRAMPLET, 
-         id="Family Filter", 
-         name=_("Family Filter"), 
+register(GRAMPLET,
+         id="Family Filter",
+         name=_("Family Filter"),
          description = _("Gramplet providing a family filter"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -998,9 +1024,9 @@ register(GRAMPLET,
          navtypes=["Family"],
          )
 
-register(GRAMPLET, 
-         id="Event Filter", 
-         name=_("Event Filter"), 
+register(GRAMPLET,
+         id="Event Filter",
+         name=_("Event Filter"),
          description = _("Gramplet providing an event filter"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -1012,9 +1038,9 @@ register(GRAMPLET,
          navtypes=["Event"],
          )
 
-register(GRAMPLET, 
-         id="Source Filter", 
-         name=_("Source Filter"), 
+register(GRAMPLET,
+         id="Source Filter",
+         name=_("Source Filter"),
          description = _("Gramplet providing a source filter"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -1026,9 +1052,9 @@ register(GRAMPLET,
          navtypes=["Source"],
          )
 
-register(GRAMPLET, 
-         id="Citation Filter", 
-         name=_("Citation Filter"), 
+register(GRAMPLET,
+         id="Citation Filter",
+         name=_("Citation Filter"),
          description = _("Gramplet providing a citation filter"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -1040,9 +1066,9 @@ register(GRAMPLET,
          navtypes=["Citation"],
          )
 
-register(GRAMPLET, 
-         id="Place Filter", 
-         name=_("Place Filter"), 
+register(GRAMPLET,
+         id="Place Filter",
+         name=_("Place Filter"),
          description = _("Gramplet providing a place filter"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -1054,9 +1080,9 @@ register(GRAMPLET,
          navtypes=["Place"],
          )
 
-register(GRAMPLET, 
-         id="Media Filter", 
-         name=_("Media Filter"), 
+register(GRAMPLET,
+         id="Media Filter",
+         name=_("Media Filter"),
          description = _("Gramplet providing a media filter"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -1068,9 +1094,9 @@ register(GRAMPLET,
          navtypes=["Media"],
          )
 
-register(GRAMPLET, 
-         id="Repository Filter", 
-         name=_("Repository Filter"), 
+register(GRAMPLET,
+         id="Repository Filter",
+         name=_("Repository Filter"),
          description = _("Gramplet providing a repository filter"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -1082,9 +1108,9 @@ register(GRAMPLET,
          navtypes=["Repository"],
          )
 
-register(GRAMPLET, 
-         id="Note Filter", 
-         name=_("Note Filter"), 
+register(GRAMPLET,
+         id="Note Filter",
+         name=_("Note Filter"),
          description = _("Gramplet providing a note filter"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -1096,7 +1122,7 @@ register(GRAMPLET,
          navtypes=["Note"],
          )
 
-register(GRAMPLET, 
+register(GRAMPLET,
          id='Records Gramplet',
          name=_("Records"),
          description=_("Shows some interesting records about people and families"),
@@ -1112,9 +1138,9 @@ register(GRAMPLET,
          gramplet_title=_("Records")
          )
 
-register(GRAMPLET, 
-         id="Person To Do", 
-         name=_("Person To Do"), 
+register(GRAMPLET,
+         id="Person To Do",
+         name=_("Person To Do"),
          description = _("Gramplet showing the To Do notes for a person"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -1126,9 +1152,9 @@ register(GRAMPLET,
          navtypes=["Person"],
          )
 
-register(GRAMPLET, 
-         id="Event To Do", 
-         name=_("Event To Do"), 
+register(GRAMPLET,
+         id="Event To Do",
+         name=_("Event To Do"),
          description = _("Gramplet showing the To Do notes for an event"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -1140,9 +1166,9 @@ register(GRAMPLET,
          navtypes=["Event"],
          )
 
-register(GRAMPLET, 
-         id="Family To Do", 
-         name=_("Family To Do"), 
+register(GRAMPLET,
+         id="Family To Do",
+         name=_("Family To Do"),
          description = _("Gramplet showing the To Do notes for a family"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -1154,9 +1180,9 @@ register(GRAMPLET,
          navtypes=["Family"],
          )
 
-register(GRAMPLET, 
-         id="Place To Do", 
-         name=_("Place To Do"), 
+register(GRAMPLET,
+         id="Place To Do",
+         name=_("Place To Do"),
          description = _("Gramplet showing the To Do notes for a place"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -1168,9 +1194,9 @@ register(GRAMPLET,
          navtypes=["Place"],
          )
 
-register(GRAMPLET, 
-         id="Source To Do", 
-         name=_("Source To Do"), 
+register(GRAMPLET,
+         id="Source To Do",
+         name=_("Source To Do"),
          description = _("Gramplet showing the To Do notes for a source"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -1182,9 +1208,9 @@ register(GRAMPLET,
          navtypes=["Source"],
          )
 
-register(GRAMPLET, 
-         id="Citation To Do", 
-         name=_("Citation To Do"), 
+register(GRAMPLET,
+         id="Citation To Do",
+         name=_("Citation To Do"),
          description = _("Gramplet showing the To Do notes for a citation"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -1196,9 +1222,9 @@ register(GRAMPLET,
          navtypes=["Citation"],
          )
 
-register(GRAMPLET, 
-         id="Repository To Do", 
-         name=_("Repository To Do"), 
+register(GRAMPLET,
+         id="Repository To Do",
+         name=_("Repository To Do"),
          description = _("Gramplet showing the To Do notes for a repository"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -1210,9 +1236,9 @@ register(GRAMPLET,
          navtypes=["Repository"],
          )
 
-register(GRAMPLET, 
-         id="Media To Do", 
-         name=_("Media To Do"), 
+register(GRAMPLET,
+         id="Media To Do",
+         name=_("Media To Do"),
          description = _("Gramplet showing the To Do notes for a media object"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -1224,8 +1250,8 @@ register(GRAMPLET,
          navtypes=["Media"],
          )
 
-register(GRAMPLET, 
-         id="Python Evaluation", 
+register(GRAMPLET,
+         id="Python Evaluation",
          name="Python Evaluation",
          description = "Gramplet allowing the evaluation of python code",
          version="1.0.0",
@@ -1237,8 +1263,8 @@ register(GRAMPLET,
          gramplet_title="Python Evaluation",
          )
 
-register(GRAMPLET, 
-         id="Uncollected Objects", 
+register(GRAMPLET,
+         id="Uncollected Objects",
          name="Uncollected Objects",
          description = "Gramplet showing uncollected objects",
          version="1.0.0",
@@ -1264,8 +1290,8 @@ register(GRAMPLET,
          )
 
 register(GRAMPLET,
-         id="Place Locations",
-         name=_("Place Locations"),
+         id="Place Enclosed By",
+         name=_("Place Enclosed By"),
          description = _("Gramplet showing the places enclosed by the active place"),
          version="1.0.0",
          gramps_target_version=MODULE_VERSION,
@@ -1290,3 +1316,31 @@ register(GRAMPLET,
          gramplet_title=_("Encloses"),
          navtypes=["Place"],
          )
+
+register(GRAMPLET,
+         id="Geography coordinates for Person Events",
+         name=_("Geography coordinates for Person Events"),
+         description = _("Gramplet showing the events for a person"),
+         version="1.0.0",
+         gramps_target_version=MODULE_VERSION,
+         status = STABLE,
+         fname="coordinates.py",
+         height=200,
+         gramplet = 'GeoPersonEvents',
+         gramplet_title=_("Events Coordinates"),
+         navtypes=["Person"],
+         )
+
+register(GRAMPLET,
+         id="Geography coordinates for Family Events",
+         name=_("Geography coordinates for Family Events"),
+         description = _("Gramplet showing the events for all the family"),
+         version="1.0.0",
+         gramps_target_version=MODULE_VERSION,
+         status = STABLE,
+         fname="coordinates.py",
+         height=200,
+         gramplet = 'GeoFamilyEvents',
+         gramplet_title=_("Events Coordinates"),
+         navtypes=["Family"],
+         )
