@@ -63,6 +63,7 @@ from gramps.gen.lib.eventroletype import EventRoleType
 from gramps.gen.config import config
 from gramps.gen.display.place import displayer as place_displayer
 from gramps.gen.utils.libformatting import ImportInfo
+from gramps.gen.errors import GrampsImportError as Error
 
 #-------------------------------------------------------------------------
 #
@@ -450,6 +451,7 @@ class CSVParser:
             if new:
                 mar_ref = EventRef()
                 mar_ref.set_reference_handle(marriage.get_handle())
+                mar_ref.set_role(EventRoleType(EventRoleType.FAMILY))
                 family.add_event_ref(mar_ref)
                 self.db.commit_family(family, self.trans)
             # only add note to event:
