@@ -48,9 +48,10 @@ _LOG = logging.getLogger(".gui.personview")
 from gramps.gen.lib import Person, Surname
 from gramps.gen.db import DbTxn
 from gramps.gui.views.listview import ListView, TEXT, MARKUP, ICON
+from gramps.gui.actiongroup import ActionGroup
 from gramps.gen.utils.string import data_recover_msg
 from gramps.gen.display.name import displayer as name_displayer
-from gramps.gui.dialog import ErrorDialog, QuestionDialog
+from gramps.gui.dialog import ErrorDialog, MultiSelectDialog, QuestionDialog
 from gramps.gen.errors import WindowActiveError
 from gramps.gui.views.bookmarks import PersonBookmarks
 from gramps.gen.config import config
@@ -119,10 +120,10 @@ class BasePersonView(ListView):
                            COL_TAGS, COL_CHAN]),
         ('columns.size', [250, 75, 75, 100, 175, 100, 175, 100, 30, 30, 30, 30,
                           30, 100, 100])
-        )  
+        )
     ADD_MSG     = _("Add a new person")
     EDIT_MSG    = _("Edit the selected person")
-    DEL_MSG     = _("Remove the selected person")
+    DEL_MSG     = _("Delete the selected person")
     MERGE_MSG   = _("Merge the selected persons")
     FILTER_TYPE = "Person"
     QR_CATEGORY = CATEGORY_QR_PERSON
@@ -138,21 +139,26 @@ class BasePersonView(ListView):
             'person-rebuild' : self.object_build,
             'person-groupname-rebuild' : self.object_build,
             'no-database': self.no_database,
+            'family-update'  : self.related_update,
+            'family-add'     : self.related_update,
+            'event-update'   : self.related_update,
+            'place-update'   : self.related_update,
             }
- 
+
         ListView.__init__(
             self, title, pdata, dbstate, uistate,
             model, signal_map,
             PersonBookmarks, nav_group,
             multiple=True,
             filter_class=PersonSidebarFilter)
-            
+
         self.func_list.update({
             '<PRIMARY>J' : self.jump,
             '<PRIMARY>BackSpace' : self.key_delete,
             })
 
         uistate.connect('nameformat-changed', self.build_tree)
+        uistate.connect('placeformat-changed', self.build_tree)
 
         self.additional_uis.append(self.additional_ui())
 
@@ -167,7 +173,7 @@ class BasePersonView(ListView):
         Specify the drag type for a single selection
         """
         return DdTargets.PERSON_LINK
-        
+
     def exact_search(self):
         """
         Returns a tuple indicating columns requiring an exact search
@@ -221,7 +227,7 @@ class BasePersonView(ListView):
           <toolbar name="ToolBar">
             <placeholder name="CommonNavigation">
               <toolitem action="Back"/>
-              <toolitem action="Forward"/>  
+              <toolitem action="Forward"/>
               <toolitem action="HomePerson"/>
             </placeholder>
             <placeholder name="CommonEdit">
@@ -248,7 +254,7 @@ class BasePersonView(ListView):
 
     def get_handle_from_gramps_id(self, gid):
         """
-        Return the handle of the person having the given Gramps ID. 
+        Return the handle of the person having the given Gramps ID.
         """
         obj = self.dbstate.db.get_person_from_gramps_id(gid)
         if obj:
@@ -264,12 +270,12 @@ class BasePersonView(ListView):
         #the editor requires a surname
         person.primary_name.add_surname(Surname())
         person.primary_name.set_primary_surname(0)
-        
+
         try:
             EditPerson(self.dbstate, self.uistate, [], person)
         except WindowActiveError:
             pass
- 
+
     def edit(self, obj):
         """
         Edit an existing person in the database.
@@ -285,20 +291,45 @@ class BasePersonView(ListView):
         """
         Remove a person from the database.
         """
-        for sel in self.selected_handles():
-            person = self.dbstate.db.get_person_from_handle(sel)
-            self.active_person = person
-            name = name_displayer.display(person) 
+        handles = self.selected_handles()
+        if len(handles) == 1:
+            person = self._lookup_person(handles[0])
+            msg1 = self._message1_format(person)
+            msg2 = self._message2_format(person)
+            msg2 = "%s %s" % (msg2, data_recover_msg)
+            # This gets person to delete self.active_person:
+            QuestionDialog(msg1,
+                           msg2,
+                           _('_Delete Person'),
+                           self.delete_person_response,
+                           parent=self.uistate.window)
+        else:
+            # Ask to delete; option to cancel, delete rest
+            # This gets person to delete from parameter
+            MultiSelectDialog(self._message1_format,
+                              self._message2_format,
+                              handles,
+                              self._lookup_person,
+                              yes_func=self.delete_person_response,
+                              parent=self.uistate.window)
 
-            msg = _('Deleting the person will remove the person '
-                             'from the database.')
-            msg = "%s %s" % (msg, data_recover_msg)
-            QuestionDialog(_('Delete %s?') % name, 
-                                          msg, 
-                                          _('_Delete Person'), 
-                                          self.delete_person_response)
+    def _message1_format(self, person):
+        return _('Delete %s?') % (name_displayer.display(person) +
+                                  (" [%s]" % person.gramps_id))
 
-    def delete_person_response(self):
+    def _message2_format(self, person):
+        return _('Deleting the person will remove the person '
+                 'from the database.')
+
+    def _lookup_person(self, handle):
+        """
+        Get the next person from handle.
+        """
+        person = self.dbstate.db.get_person_from_handle(handle)
+        self.active_person = person
+        return person
+
+    def delete_person_response(self, person=None):
         """
         Deletes the person from the database.
         """
@@ -307,23 +338,29 @@ class BasePersonView(ListView):
 
         # create the transaction
         with DbTxn('', self.dbstate.db) as trans:
-        
+
             # create name to save
             person = self.active_person
             active_name = _("Delete Person (%s)") % name_displayer.display(person)
 
             # delete the person from the database
-            # Above will emit person-delete, which removes the person via 
+            # Above will emit person-delete, which removes the person via
             # callback to the model, so row delete is signaled
             self.dbstate.db.delete_person_from_database(person, trans)
             trans.set_description(active_name)
 
         self.uistate.set_busy_cursor(False)
 
+    def remove_object_from_handle(self, handle):
+        """
+        The remove_selected_objects method is not called in this view.
+        """
+        pass
+
     def define_actions(self):
         """
         Required define_actions function for PageView. Builds the action
-        group information required. We extend beyond the normal here, 
+        group information required. We extend beyond the normal here,
         since we want to have more than one action group for the PersonView.
         Most PageViews really won't care about this.
 
@@ -336,29 +373,29 @@ class BasePersonView(ListView):
 
         ListView.define_actions(self)
 
-        self.all_action = Gtk.ActionGroup(name=self.title + "/PersonAll")
-        self.edit_action = Gtk.ActionGroup(name=self.title + "/PersonEdit")
+        self.all_action = ActionGroup(name=self.title + "/PersonAll")
+        self.edit_action = ActionGroup(name=self.title + "/PersonEdit")
 
         self.all_action.add_actions([
                 ('FilterEdit', None, _('Person Filter Editor'), None, None,
                 self.filter_editor),
-                ('Edit', Gtk.STOCK_EDIT, _("action|_Edit..."),
-                "<PRIMARY>Return", self.EDIT_MSG, self.edit), 
-                ('QuickReport', None, _("Quick View"), None, None, None), 
-                ('WebConnect', None, _("Web Connection"), None, None, None), 
+                ('Edit', 'gtk-edit', _("action|_Edit..."),
+                "<PRIMARY>Return", self.EDIT_MSG, self.edit),
+                ('QuickReport', None, _("Quick View"), None, None, None),
+                ('WebConnect', None, _("Web Connection"), None, None, None),
                 ])
 
 
         self.edit_action.add_actions(
             [
-                ('Add', Gtk.STOCK_ADD, _("_Add..."), "<PRIMARY>Insert", 
-                 self.ADD_MSG, self.add), 
-                ('Remove', Gtk.STOCK_REMOVE, _("_Remove"), "<PRIMARY>Delete", 
+                ('Add', 'list-add', _("_Add..."), "<PRIMARY>Insert",
+                 self.ADD_MSG, self.add),
+                ('Remove', 'list-remove', _("_Delete"), "<PRIMARY>Delete",
                  self.DEL_MSG, self.remove),
                 ('Merge', 'gramps-merge', _('_Merge...'), None,
                  self.MERGE_MSG, self.merge),
                 ('ExportTab', None, _('Export View...'), None, None,
-                 self.export), 
+                 self.export),
                 ])
 
         self._add_action_group(self.edit_action)
@@ -372,7 +409,7 @@ class BasePersonView(ListView):
         self.all_action.set_visible(True)
         self.edit_action.set_visible(True)
         self.edit_action.set_sensitive(not self.dbstate.db.readonly)
-        
+
     def disable_action_group(self):
         """
         Turns off the visibility of the View's action group.
@@ -389,13 +426,13 @@ class BasePersonView(ListView):
         mlist = self.selected_handles()
 
         if len(mlist) != 2:
-            ErrorDialog(
-        _("Cannot merge people"), 
-        _("Exactly two people must be selected to perform a merge. "
-          "A second person can be selected by holding down the "
-          "control key while clicking on the desired person."))
+            ErrorDialog(_("Cannot merge people"),
+                        _("Exactly two people must be selected to perform "
+                        "a merge. A second person can be selected by "
+                        "holding down the control key while clicking on "
+                        "the desired person."), parent=self.uistate.window)
         else:
-            MergePerson(self.dbstate, self.uistate, mlist[0], mlist[1])
+            MergePerson(self.dbstate, self.uistate, [], mlist[0], mlist[1])
 
     def tag_updated(self, handle_list):
         """
@@ -416,7 +453,7 @@ class BasePersonView(ListView):
         person = self.dbstate.db.get_person_from_handle(person_handle)
         person.add_tag(tag_handle)
         self.dbstate.db.commit_person(person, transaction)
-        
+
     def get_default_gramplets(self):
         """
         Define the default gramplets for the sidebar and bottombar.
