@@ -79,6 +79,7 @@ class PlaceBaseView(ListView):
     COL_PRIV = 7
     COL_TAGS = 8
     COL_CHAN = 9
+    COL_SEARCH = 11
     # column definitions
     COLUMNS = [
         (_('Name'), TEXT, None),
@@ -98,7 +99,7 @@ class PlaceBaseView(ListView):
         ('columns.rank', [COL_NAME, COL_TITLE, COL_ID, COL_TYPE, COL_CODE,
                           COL_LAT, COL_LON, COL_PRIV, COL_TAGS, COL_CHAN]),
         ('columns.size', [250, 250, 75, 100, 100, 150, 150, 40, 100, 100])
-        )    
+        )
     ADD_MSG     = _("Add a new place")
     EDIT_MSG    = _("Edit the selected place")
     DEL_MSG     = _("Delete the selected place")
@@ -130,11 +131,25 @@ class PlaceBaseView(ListView):
             '<PRIMARY>BackSpace' : self.key_delete,
             })
         self.maptoolbtn = None
+
+        uistate.connect('placeformat-changed', self.build_tree)
+
         self.additional_uis.append(self.additional_ui())
 
     def navigation_type(self):
         return 'Place'
-    
+
+    def setup_filter(self):
+        """Build the default filters and add them to the filter menu.
+        This overrides the listview method because we use the hidden
+        COL_SEARCH that has alt names as well as primary name for name
+        searching"""
+        self.search_bar.setup_filter(
+            [(self.COLUMNS[pair[1]][0],
+              self.COL_SEARCH if pair[1] == self.COL_NAME else pair[1],
+              pair[1] in self.exact_search())
+                for pair in self.column_order() if pair[0]])
+
     def define_actions(self):
         ListView.define_actions(self)
         self._add_toolmenu_action('MapsList', _('Loading...'),
@@ -158,7 +173,7 @@ class PlaceBaseView(ListView):
         tb = self.uistate.viewmanager.uimanager.get_widget('/ToolBar')
         tb.remove(self.maptoolbtn)
         ListView.set_inactive(self)
-        
+
     def change_page(self):
         """
         Called by viewmanager at end of realization when arriving on the page
@@ -188,7 +203,7 @@ class PlaceBaseView(ListView):
             return
 
         self.mapslistlabel = []
-        if not self.mapservice in self.mapservicedata: 
+        if not self.mapservice in self.mapservicedata:
             #stored val no longer exists, use the first key instead
             self.set_mapservice(list(self.mapservicedata.keys())[0])
 
@@ -203,16 +218,6 @@ class PlaceBaseView(ListView):
         self.mapslistlabel.append(lbl)
         widget.set_label_widget(self.mapslistlabel[-1])
         widget.set_icon_name('go-jump')
-        if self.drag_info():
-            self.list.enable_model_drag_source(Gdk.ModifierType.BUTTON1_MASK,
-              [],
-              Gdk.DragAction.COPY)
-            tglist = Gtk.TargetList.new([])
-            tglist.add(self.drag_info().atom_drag_type, 
-                       self.drag_info().target_flags,
-                       self.drag_info().app_id)
-            tglist.add_text_targets (0)
-            self.list.drag_source_set_target_list(tglist)
 
     def __create_maps_menu_actions(self):
         """
@@ -220,13 +225,13 @@ class PlaceBaseView(ListView):
         from the menutoolbutton
         """
         menu = Gtk.Menu()
-        
+
         #select the map services to show
         self.mapservicedata = {}
         servlist = GuiPluginManager.get_instance().get_reg_mapservices()
         for i, pdata in enumerate(servlist):
             key = pdata.id.replace(' ', '-')
-            add_menuitem(menu, pdata.name, None, 
+            add_menuitem(menu, pdata.name, None,
                                make_callback(self.set_mapservice, key))
             self.mapservicedata[key] = pdata
 
@@ -243,7 +248,7 @@ class PlaceBaseView(ListView):
             label.show()
         config.set('interface.mapservice', mapkey)
         config.save()
-    
+
     def mapservice_label(self):
         """
         return the current label for the menutoolbutton
@@ -252,7 +257,7 @@ class PlaceBaseView(ListView):
 
     def gotomap(self, obj):
         """
-        Run the map service 
+        Run the map service
         """
         #First test if any map service is available
         if not len(self.mapservicedata):
@@ -260,7 +265,7 @@ class PlaceBaseView(ListView):
             msg2 = _("Check your installation.")
             ErrorDialog(msg, msg2, parent=self.uistate.window)
             return
-        
+
         place_handles = self.selected_handles()
         try:
             place_handle = self.selected_handles()[0]
@@ -271,18 +276,18 @@ class PlaceBaseView(ListView):
                      " selections.")
             ErrorDialog(msg, msg2, parent=self.uistate.window)
             return
-        
+
         #TODO: support for descriptions in some cases. For now, pass None
         #TODO: Later this might be 'Birth of William' ....
         places = [(x, None) for x in place_handles]
-        
+
         #run the mapservice:
         pmgr = GuiPluginManager.get_instance()
         serv = self.mapservicedata[self.mapservice]
         mod = pmgr.load_plugin(serv)
         if mod:
             servfunc = eval('mod.' +  serv.mapservice)
-            servfunc()(self.dbstate.db, places)
+            servfunc()(self.dbstate.db, places, self.uistate)
         else:
             print('Failed to load map plugin, see Plugin Manager')
 
@@ -325,8 +330,8 @@ class PlaceBaseView(ListView):
           </menubar>
           <toolbar name="ToolBar">
             <placeholder name="CommonNavigation">
-              <toolitem action="Back"/>  
-              <toolitem action="Forward"/>  
+              <toolitem action="Back"/>
+              <toolitem action="Forward"/>
             </placeholder>
             <placeholder name="CommonEdit">
               <toolitem action="Add"/>
@@ -365,7 +370,7 @@ class PlaceBaseView(ListView):
                          "First remove the places it contains.")
                 ErrorDialog(msg, msg2, parent=self.uistate.window)
                 return
-        self.remove_selected_objects()       
+        self.remove_selected_objects()
 
     def remove_object_from_handle(self, handle):
         person_list = [
@@ -375,11 +380,11 @@ class PlaceBaseView(ListView):
         family_list = [
             item[1] for item in
             self.dbstate.db.find_backlink_handles(handle,['Family'])]
-        
+
         event_list = [
             item[1] for item in
             self.dbstate.db.find_backlink_handles(handle,['Event'])]
-        
+
         object = self.dbstate.db.get_place_from_handle(handle)
         query = DeletePlaceQuery(self.dbstate, self.uistate, object,
                                  person_list, family_list, event_list)
@@ -400,7 +405,7 @@ class PlaceBaseView(ListView):
         Merge the selected places.
         """
         mlist = self.selected_handles()
-        
+
         if len(mlist) != 2:
             msg = _("Cannot merge places.")
             msg2 = _("Exactly two places must be selected to perform a merge. "
@@ -415,7 +420,7 @@ class PlaceBaseView(ListView):
                          "place hierarchy.")
                 ErrorDialog(msg, msg2, parent=self.uistate.window)
             else:
-                MergePlace(self.dbstate, self.uistate, mlist[0], mlist[1],
+                MergePlace(self.dbstate, self.uistate, [], mlist[0], mlist[1],
                            self.merged)
 
     def merged(self):
@@ -451,14 +456,15 @@ class PlaceBaseView(ListView):
         place = self.dbstate.db.get_place_from_handle(place_handle)
         place.add_tag(tag_handle)
         self.dbstate.db.commit_place(place, transaction)
-        
+
     def get_default_gramplets(self):
         """
         Define the default gramplets for the sidebar and bottombar.
         """
         return (("Place Filter",),
                 ("Place Details",
-                 "Place Locations",
+                 "Place Enclosed By",
+                 "Place Encloses",
                  "Place Gallery",
                  "Place Citations",
                  "Place Notes",
