@@ -41,7 +41,7 @@ Mary Smith was born on 3/28/1923.
 from gramps.gen.lib import EventType, PlaceType, Location
 from gramps.gen.utils.db import get_birth_or_fallback, get_death_or_fallback
 from gramps.gen.utils.location import get_main_location
-from gramps.gen.display.place import displayer as place_displayer
+from gramps.gen.display.place import displayer as _pd
 from gramps.gen.const import GRAMPS_LOCALE as glocale
 
 
@@ -50,7 +50,7 @@ from gramps.gen.const import GRAMPS_LOCALE as glocale
 # Local constants
 #
 #------------------------------------------------------------------------
-class TextTypes():
+class TextTypes:
     """Four enumerations that are used to for the four main parts of a string.
 
     and used for states.  Separator is not used in states.
@@ -66,7 +66,7 @@ TXT = TextTypes()
 # Formatting classes
 #
 #------------------------------------------------------------------------
-class GenericFormat(object):
+class GenericFormat:
     """A Generic parsing class.  Will be subclassed by specific format strings
     """
 
@@ -187,7 +187,7 @@ class NameFormat(GenericFormat):
                     name.get_suffix,           # s
                     name.get_surname,          # l
                     name.get_family_nick_name  # g
-                    ]
+                   ]
 
         return self.generic_format(name, code, upper, function)
 
@@ -297,11 +297,11 @@ class DateFormat(GenericFormat):
             return year(date.get_stop_year(), self.__count_chars("z", 4))
 
         def e_month():
-            return month(date.get_stop_month(), self.__count_chars("n", 4)) 
+            return month(date.get_stop_month(), self.__count_chars("n", 4))
 
         def eu_month():
-            return month(date.get_stop_month(), 
-                    self.__count_chars("N", 4)).upper()
+            return month(date.get_stop_month(),
+                         self.__count_chars("N", 4)).upper()
 
         def e_day():
             return day(date.get_stop_day(), self.__count_chars("e", 2))
@@ -309,14 +309,13 @@ class DateFormat(GenericFormat):
         def modifier():
             #ui_mods taken from date.py def lookup_modifier(self, modifier):
             # trans_text is a defined keyword (in po/update_po.py, po/genpot.sh)
-            # (in po/update_po.py, po/genpot.sh)
             trans_text = self._locale.translation.gettext
             ui_mods = ["", trans_text("before"), trans_text("after"),
                        trans_text("about"), "", "", ""]
             return ui_mods[date.get_modifier()]
 
 
-        code  = "ymMd" + "znNe" + "ot"
+        code = "ymMd" + "znNe" + "ot"
         upper = "OT"
         function = [s_year, s_month, su_month, s_day,
                     e_year, e_month, eu_month, e_day,
@@ -347,7 +346,7 @@ class PlaceFormat(GenericFormat):
         return None
 
     def _default_format(self, place):
-        return place_displayer.display(self.database, place)
+        return _pd.display(self.database, place)
 
     def parse_format(self, database, place):
         """ Parse the place """
@@ -382,7 +381,7 @@ class PlaceFormat(GenericFormat):
                     place.get_title,
                     place.get_longitude,
                     place.get_latitude
-                    ]
+                   ]
 
         return self.generic_format(place, code, upper, function)
 
@@ -454,7 +453,7 @@ class EventFormat(GenericFormat):
                     format_place,
                     event.get_gramps_id,
                     format_attrib
-                    ]
+                   ]
 
         return self.generic_format(event, code, upper, function)
 
@@ -471,7 +470,7 @@ class EventFormat(GenericFormat):
 #------------------------------------------------------------------------
 # gramps info Format strings
 #------------------------------------------------------------------------
-class GrampsFormat():
+class GrampsFormat:
     """ The Gramps Info Format class.
         This only polls information from system information.
     """
@@ -502,7 +501,7 @@ class GrampsFormat():
 
                 owner.get_phone(),
                 owner.get_email()
-                ]
+               ]
 
         where = code.find(self.string_in.this)
         if where != -1:
@@ -570,7 +569,7 @@ class GalleryFormat(GenericFormat):
                     format_date,
                     photo.get_gramps_id,
                     format_attrib
-                    ]
+                   ]
 
         return self.generic_format(photo, code, upper, function)
 
@@ -588,7 +587,7 @@ class GalleryFormat(GenericFormat):
 # ConsumableString - The Input string class
 #
 #------------------------------------------------------------------------
-class ConsumableString(object):
+class ConsumableString:
     """
     A simple string implementation with extras to help with parsing.
 
@@ -630,7 +629,7 @@ class ConsumableString(object):
     def __get_a_char_of_text(self):
         """ Removes one char of TEXT from the string and returns it. """
         if self.this == "\\":
-            if self.next == None:
+            if self.next is None:
                 rtrn = "\\"
             else:
                 rtrn = self.next
@@ -665,7 +664,7 @@ class ConsumableString(object):
 # VarString class  - The Output string class
 #
 #------------------------------------------------------------------------
-class VarString(object):
+class VarString:
     """
     The current state of the entire string (integer from TextTypes)
     A list to hold tuple object (integer from TextTypes, string)
@@ -673,7 +672,7 @@ class VarString(object):
     This will contain the string that will be displayed.  or string out.
     it is used for groups and format strings.
     """
-    def __init__(self, start_state = TXT.remove):
+    def __init__(self, start_state=TXT.remove):
         self.state = start_state  # overall state of the string.
         self._text = []  # list of tuples (TXT.?, string)
 
@@ -714,7 +713,7 @@ class VarString(object):
                 index = index + 1
                 break  # while self._text:
 
-            type_0_1  = (self._text[index][0], self._text[index+1][0])
+            type_0_1 = (self._text[index][0], self._text[index+1][0])
 
             #if   type_0_1 == (TXT.remove, TXT.remove):
             #    pass
@@ -759,7 +758,7 @@ class VarString(object):
 #------------------------------------------------------------------------
 # SeparatorParse
 #------------------------------------------------------------------------
-class SeparatorParse(object):
+class SeparatorParse:
     """ parse out a separator """
     def __init__(self, consumer_in):
         self._in = consumer_in
@@ -777,7 +776,7 @@ class SeparatorParse(object):
 #------------------------------------------------------------------------
 # AttributeParse
 #------------------------------------------------------------------------
-class AttributeParse(object):
+class AttributeParse:
     """  Parse attributes """
 
     def __init__(self, consumer_in):
@@ -811,7 +810,7 @@ class AttributeParse(object):
 #------------------------------------------------------------------------
 # VariableParse
 #------------------------------------------------------------------------
-class VariableParse(object):
+class VariableParse:
     """ Parse the individual variables """
 
     def __init__(self, friend, database, consumer_in, locale, name_displayer):
@@ -919,7 +918,7 @@ class VariableParse(object):
         media_list = person_or_marriage.get_media_list()
         for media_ref in media_list:
             media_handle = media_ref.get_reference_handle()
-            media = self.database.get_object_from_handle(media_handle)
+            media = self.database.get_media_from_handle(media_handle)
             mime_type = media.get_mime_type()
             if mime_type and mime_type.startswith("image"):
                 return media
@@ -1025,13 +1024,13 @@ class VariableParse(object):
             if self.empty_attribute(self.friend.person):
                 return
             return attrib_parse.parse_format(
-                                      self.friend.person.get_attribute_list())
+                self.friend.person.get_attribute_list())
         elif next_char == "u":
             #Marriage Atribute
             if self.empty_attribute(self.friend.family):
                 return
             return attrib_parse.parse_format(
-                                      self.friend.family.get_attribute_list())
+                self.friend.family.get_attribute_list())
 
         elif next_char == "e":
             #person event
@@ -1057,7 +1056,7 @@ class VariableParse(object):
 # SubstKeywords
 #
 #------------------------------------------------------------------------
-class SubstKeywords(object):
+class SubstKeywords:
     """Accepts a person/family with format lines and returns a new set of lines
     using variable substitution to make it.
 
@@ -1246,7 +1245,7 @@ if __name__ == '__main__':
 # You will need to put in your own path to the src directory
 #
 #-------------------------------------------------------------------------
-    # pylint: disable-msg=C0103
+    # pylint: disable=C0103
 
     def combinations(c, r):
         # combinations('ABCD', 2) --> AB AC AD BC BD CD
@@ -1271,7 +1270,7 @@ if __name__ == '__main__':
     def main_level_test(_in, testing_class, testing_what):
         """This is a mini def __main_level(self):
         """
-        main = LevelParse(_in)
+        main = _in
         sepa = SeparatorParse(_in)
         test = testing_class(_in)
 
@@ -1362,7 +1361,8 @@ if __name__ == '__main__':
     tmp = main_level_test(consume_str, DateFormat, date_to_test)
     print(tmp)
     answer.append(tmp)
-    print("Good" if answer == ["1970 a99b09c3d1970f70"
+    print("Good" if answer == [
+        "1970 a99b09c3d1970f70"
         ] else "!! bad !!")
 
     import sys
@@ -1386,7 +1386,8 @@ if __name__ == '__main__':
         #now can we put something in for the last name?
         name_to_test.set_family_nick_name("The Clubs" if 5 in y_or_n else "")
 
-    line_in = "{$(c)$(t)<1>{<2>$(f)}{<3>$(n){<0> <0>}<4>$(x)}$(s)<5>$(l)<6>$(g)<0>"
+    line_in = "{$(c)$(t)<1>{<2>$(f)}{<3>$(n){<0> "
+    line_in = line_in + "<0>}<4>$(x)}$(s)<5>$(l)<6>$(g)<0>"
     consume_str = ConsumableString(line_in)
 
     print()
@@ -1395,7 +1396,7 @@ if __name__ == '__main__':
     print("#None are known")
     tmp = main_level_test(consume_str, NameFormat, name_to_test)
     print(tmp)
-    print("Good" if tmp == None else "!! bad !!")
+    print("Good" if tmp is None else "!! bad !!")
 
 
     print()
@@ -1436,7 +1437,7 @@ if __name__ == '__main__':
     answer = main_level_test(consume_str, NameFormat, name_to_test)
     print(answer)
     print("Good" if answer == "BobDr.2Billy3Buck4BobIV6The Clubs"
-                 else "!! bad !!")
+          else "!! bad !!")
 
 
     print()
@@ -1510,7 +1511,8 @@ if __name__ == '__main__':
         #print tmp
         answer.append(len(tmp))
     print(answer)
-    print("Good" if answer == [38, 44, 44, 42, 46, 50, 49, 50, 40, 40, 38, 42,
+    print("Good" if answer == [
+        38, 44, 44, 42, 46, 50, 49, 50, 40, 40, 38, 42,
         46, 45, 46, 46, 44, 48, 52, 51, 52, 44, 48, 52, 51, 52, 46, 50, 49, 50,
         54, 53, 54, 57, 58, 57, 28, 28, 26, 30, 34, 33, 34, 34, 32, 36, 40, 39,
         40, 32, 36, 40, 39, 40, 34, 38, 37, 38, 42, 41, 42, 45, 46, 45, 30, 28,
