@@ -3,7 +3,7 @@
 #
 # Gramps - a GTK+/GNOME based genealogy program
 #
-# Copyright (C) 2011-2012       Serge Noiraud
+# Copyright (C) 2011-2016       Serge Noiraud
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -28,12 +28,9 @@
 from gramps.gen.const import GRAMPS_LOCALE as glocale
 _ = glocale.translation.sgettext
 import os
-import sys
 import re
-from gi.repository import GObject
 import time
 from gi.repository import GLib
-from math import pi
 
 #-------------------------------------------------------------------------
 #
@@ -41,27 +38,26 @@ from math import pi
 #
 #-------------------------------------------------------------------------
 from gi.repository import Gtk
-from gi.repository import GdkPixbuf
-import cairo
 
 #-------------------------------------------------------------------------
 #
 # Gramps Modules
 #
 #-------------------------------------------------------------------------
-from gramps.gen.lib import EventType, Place, PlaceType, PlaceRef, PlaceName
+from gramps.gen.lib import EventType, Place, PlaceRef, PlaceName
 from gramps.gen.display.name import displayer as _nd
 from gramps.gen.display.place import displayer as _pd
 from gramps.gui.views.navigationview import NavigationView
 from gramps.gen.utils.libformatting import FormattingHelper
 from gramps.gen.errors import WindowActiveError
-from gramps.gen.const import HOME_DIR, IMAGE_DIR
-from gramps.gui.managedwindow import ManagedWindow
+from gramps.gen.const import HOME_DIR
 from gramps.gen.config import config
 from gramps.gui.editors import EditPlace, EditEvent, EditFamily, EditPerson
 from gramps.gui.selectors.selectplace import SelectPlace
-from gramps.gen.constfunc import conv_to_unicode
+from gramps.gen.utils.file import media_path_full
 
+import gi
+gi.require_version('OsmGpsMap', '1.0')
 from gi.repository import OsmGpsMap as osmgpsmap
 from . import constants
 from .osmgps import OsmGps
@@ -93,6 +89,11 @@ GEOGRAPHY_PATH = os.path.join(HOME_DIR, "maps")
 PLACE_REGEXP = re.compile('<span background="green">(.*)</span>')
 PLACE_STRING = '<span background="green">%s</span>'
 
+# pylint: disable=unused-argument
+# pylint: disable=unused-variable
+# pylint: disable=no-member
+# pylint: disable=maybe-no-member
+
 def _get_sign(value):
     """
     return 1 if we have a negative number, 0 in other case
@@ -133,16 +134,17 @@ class GeoGraphyView(OsmGps, NavigationView):
         NavigationView.__init__(self, title, pdata, dbstate, uistate,
                                 bm_type, nav_group)
 
+        OsmGps.__init__(self, uistate)
         self.dbstate = dbstate
         self.dbstate.connect('database-changed', self.change_db)
+        self.dbstate.connect('no-database', self.clear_view)
         self.default_text = "Enter location here!"
         self.centerlon = config.get("geography.center-lon")
         self.centerlat = config.get("geography.center-lat")
         self.zoom = config.get("geography.zoom")
         self.lock = config.get("geography.lock")
-        if config.get('geography.path') == "" :
-            config.set('geography.path', GEOGRAPHY_PATH )
-        OsmGps.__init__(self)
+        if config.get('geography.path') == "":
+            config.set('geography.path', GEOGRAPHY_PATH)
 
         self.format_helper = FormattingHelper(self.dbstate)
         self.centerlat = self.centerlon = 0.0
@@ -154,39 +156,60 @@ class GeoGraphyView(OsmGps, NavigationView):
         self.select_fct = None
         self.geo_mainmap = None
         theme = Gtk.IconTheme.get_default()
-        self.geo_mainmap = theme.load_surface('gramps-geo-mainmap', 48, 1, 
+        self.geo_mainmap = theme.load_surface('gramps-geo-mainmap', 48, 1,
                                               None, 0)
         self.geo_altmap = theme.load_surface('gramps-geo-altmap', 48, 1,
                                              None, 0)
-        if ( config.get('geography.map_service') in
-            ( constants.OPENSTREETMAP,
-              constants.MAPS_FOR_FREE,
-              constants.OPENCYCLEMAP,
-              constants.OSM_PUBLIC_TRANSPORT,
+        if (config.get('geography.map_service') in
+            (constants.OPENSTREETMAP,
+             constants.MAPS_FOR_FREE,
+             constants.OPENCYCLEMAP,
+             constants.OSM_PUBLIC_TRANSPORT,
              )):
             default_image = self.geo_mainmap
         else:
             default_image = self.geo_altmap
         self.geo_othermap = {}
-        for ident in ( EventType.BIRTH,
-                    EventType.DEATH,
-                    EventType.MARRIAGE ):
+        for ident in (EventType.BIRTH,
+                      EventType.DEATH,
+                      EventType.MARRIAGE):
             icon = constants.ICONS.get(int(ident))
             self.geo_othermap[ident] = theme.load_surface(icon, 48, 1, None, 0)
+        self.maxyear = 0
+        self.minyear = 9999
+        self.maxlat = 0.0
+        self.minlat = 0.0
+        self.maxlon = 0.0
+        self.minlon = 0.0
+        self.longt = 0.0
+        self.latit = 0.0
+        self.itemoption = None
+        self.menu = None
+        self.mark = None
+        self.path_entry = None
+        self.changemap = None
+        self.clearmap = None
+        self.nbplaces = 0
 
     def add_bookmark(self, menu):
+        """
+        Add the place to the bookmark
+        """
         mlist = self.selected_handles()
         if mlist:
             self.bookmarks.add(mlist[0])
         else:
             from gramps.gui.dialog import WarningDialog
             WarningDialog(
-                _("Could Not Set a Bookmark"), 
+                _("Could Not Set a Bookmark"),
                 _("A bookmark could not be set because "
-                  "no one was selected."))
-        
+                  "no one was selected."),
+                parent=self.uistate.window)
 
     def add_bookmark_from_popup(self, menu, handle):
+        """
+        Add the place to the bookmark from the popup menu
+        """
         if handle:
             self.uistate.set_active(handle, self.navigation_type())
             self.bookmarks.add(handle)
@@ -194,9 +217,10 @@ class GeoGraphyView(OsmGps, NavigationView):
         else:
             from gramps.gui.dialog import WarningDialog
             WarningDialog(
-                _("Could Not Set a Bookmark"), 
+                _("Could Not Set a Bookmark"),
                 _("A bookmark could not be set because "
-                  "no one was selected."))
+                  "no one was selected."),
+                parent=self.uistate.window)
 
     def change_page(self):
         """
@@ -205,8 +229,9 @@ class GeoGraphyView(OsmGps, NavigationView):
         NavigationView.change_page(self)
         self.uistate.clear_filter_results()
         self.end_selection = None
-        self.osm.grab_focus()
-        self.set_crosshair(config.get("geography.show_cross"))
+        if self.osm:
+            self.osm.grab_focus()
+            self.set_crosshair(config.get("geography.show_cross"))
 
     def do_size_request(self, requisition):
         """
@@ -216,7 +241,7 @@ class GeoGraphyView(OsmGps, NavigationView):
         requisition.height = 300
 
     def do_get_preferred_width(self):
-        """ GTK3 uses width for height sizing model. This method will 
+        """ GTK3 uses width for height sizing model. This method will
             override the virtual method
         """
         req = Gtk.Requisition()
@@ -224,7 +249,7 @@ class GeoGraphyView(OsmGps, NavigationView):
         return req.width, req.width
 
     def do_get_preferred_height(self):
-        """ GTK3 uses width for height sizing model. This method will 
+        """ GTK3 uses width for height sizing model. This method will
             override the virtual method
         """
         req = Gtk.Requisition()
@@ -238,6 +263,13 @@ class GeoGraphyView(OsmGps, NavigationView):
         NavigationView.on_delete(self)
         self._config.save()
 
+    def clear_view(self):
+        self.place_list = []
+        self.remove_all_markers()
+        self.remove_all_gps()
+        self.remove_all_tracks()
+        self.message_layer.clear_messages()
+
     def change_db(self, dbse):
         """
         Callback associated with DbState. Whenever the database
@@ -249,8 +281,9 @@ class GeoGraphyView(OsmGps, NavigationView):
         if self.active:
             self.bookmarks.redraw()
         self.build_tree()
-        self.osm.grab_focus()
-        self.set_crosshair(config.get("geography.show_cross"))
+        if self.osm:
+            self.osm.grab_focus()
+            self.set_crosshair(config.get("geography.show_cross"))
 
     def can_configure(self):
         """
@@ -319,7 +352,7 @@ class GeoGraphyView(OsmGps, NavigationView):
         else:
             title = _('Add cross hair')
         add_item = Gtk.MenuItem(label=title)
-        add_item.connect("activate", self.config_crosshair, event, lat , lon)
+        add_item.connect("activate", self.config_crosshair, event, lat, lon)
         add_item.show()
         menu.append(add_item)
 
@@ -329,27 +362,27 @@ class GeoGraphyView(OsmGps, NavigationView):
             title = _('Lock zoom and position')
         add_item = Gtk.MenuItem(label=title)
         add_item.connect("activate", self.config_zoom_and_position,
-                         event, lat , lon)
+                         event, lat, lon)
         add_item.show()
         menu.append(add_item)
 
         add_item = Gtk.MenuItem(label=_("Add place"))
-        add_item.connect("activate", self.add_place, event, lat , lon)
+        add_item.connect("activate", self.add_place, event, lat, lon)
         add_item.show()
         menu.append(add_item)
 
         add_item = Gtk.MenuItem(label=_("Link place"))
-        add_item.connect("activate", self.link_place, event, lat , lon)
+        add_item.connect("activate", self.link_place, event, lat, lon)
         add_item.show()
         menu.append(add_item)
 
         add_item = Gtk.MenuItem(label=_("Add place from kml"))
-        add_item.connect("activate", self.add_place_from_kml, event, lat , lon)
+        add_item.connect("activate", self.add_place_from_kml, event, lat, lon)
         add_item.show()
         menu.append(add_item)
 
         add_item = Gtk.MenuItem(label=_("Center here"))
-        add_item.connect("activate", self.set_center, event, lat , lon)
+        add_item.connect("activate", self.set_center, event, lat, lon)
         add_item.show()
         menu.append(add_item)
 
@@ -360,7 +393,7 @@ class GeoGraphyView(OsmGps, NavigationView):
         add_item.show()
         menu.append(add_item)
 
-        map_name = constants.map_title[config.get("geography.map_service")]
+        map_name = constants.MAP_TITLE[config.get("geography.map_service")]
         title = _("Replace '%(map)s' by =>") % {
                    'map' : map_name
                   }
@@ -374,18 +407,30 @@ class GeoGraphyView(OsmGps, NavigationView):
         changemap.show()
         add_item.set_submenu(changemap)
         # show in the map menu all available providers
-        for map in constants.map_type:
-            changemapitem = Gtk.MenuItem(label=constants.map_title[map])
+        for my_map in constants.MAP_TYPE:
+            changemapitem = Gtk.MenuItem(label=constants.MAP_TITLE[my_map])
             changemapitem.show()
-            changemapitem.connect("activate", self.change_map, map)
+            changemapitem.connect("activate", self.change_map, my_map)
             changemap.append(changemapitem)
 
+        reload_text = _("Reload all visible tiles for '%(map)s'.") % {
+                   'map' : map_name
+                  }
+        self.reloadtiles = Gtk.MenuItem(label=reload_text)
+        reloadtiles = self.reloadtiles
+        reloadtiles.connect("activate", self.reload_visible_tiles)
+
+        reloadtiles.show()
+        menu.append(reloadtiles)
+
         clear_text = _("Clear the '%(map)s' tiles cache.") % {
                    'map' : map_name
                   }
         self.clearmap = Gtk.MenuItem(label=clear_text)
         clearmap = self.clearmap
-        clearmap.connect("activate", self.clear_map, constants.tiles_path[config.get("geography.map_service")])
+        clearmap.connect("activate", self.clear_map,
+                         constants.TILES_PATH[config.get(
+                                                      "geography.map_service")])
 
         clearmap.show()
         menu.append(clearmap)
@@ -394,16 +439,20 @@ class GeoGraphyView(OsmGps, NavigationView):
                    None, event.button, event.time)
         return 1
 
+    def reload_visible_tiles(self, menu):
+        """
+        We need to reload all visible tiles for the current map
+        """
+        self.reload_tiles()
 
     def clear_map(self, menu, the_map):
         """
         We need to clean the tiles cache for the current map
         """
         import shutil
-     
-        path = "%s%c%s" % ( config.get('geography.path'), os.sep, the_map )
-        shutil.rmtree(path)
-        pass
+
+        path = "%s%c%s" % (config.get('geography.path'), os.sep, the_map)
+        shutil.rmtree(path, ignore_errors=True)
 
     def add_specific_menu(self, menu, event, lat, lon):
         """
@@ -450,22 +499,21 @@ class GeoGraphyView(OsmGps, NavigationView):
                          14 : 0.0005, 15 : 0.0003, 16 : 0.0001,
                          17 : 0.0001, 18 : 0.0001
                          }.get(config.get("geography.zoom"), 5.0)
-            latp  = precision % lat
-            lonp  = precision % lon
+            latp = precision % lat
+            lonp = precision % lon
             mlatp = precision % float(mark[3])
             mlonp = precision % float(mark[4])
             latok = lonok = False
             _LOG.debug(" compare latitude : %s with %s (precision = %s)"
-                       " place='%s'" % (float(mark[3]), lat, precision,
-                                        mark[0]))
+                       " place='%s'", float(mark[3]), lat, precision, mark[0])
             _LOG.debug("compare longitude : %s with %s (precision = %s)"
-                       " zoom=%d" % (float(mark[4]), lon, precision,
-                                     config.get("geography.zoom")))
-            if (float(mlatp) >= (float(latp) - shift) ) and \
-               (float(mlatp) <= (float(latp) + shift) ):
+                       " zoom=%d", float(mark[4]), lon, precision,
+                                     config.get("geography.zoom"))
+            if (float(mlatp) >= (float(latp) - shift)) and \
+               (float(mlatp) <= (float(latp) + shift)):
                 latok = True
-            if (float(mlonp) >= (float(lonp) - shift) ) and \
-               (float(mlonp) <= (float(lonp) + shift) ):
+            if (float(mlonp) >= (float(lonp) - shift)) and \
+               (float(mlonp) <= (float(lonp) + shift)):
                 lonok = True
             if latok and lonok:
                 mark_selected.append(mark)
@@ -494,13 +542,14 @@ class GeoGraphyView(OsmGps, NavigationView):
         """
         self.osm.remove_layer(layer)
 
-    def add_marker(self, menu, event, lat, lon, event_type, differtype, count):
+    def add_marker(self, menu, event, lat, lon, event_type, differtype,
+                   count, color=None):
         """
         Add a new marker
         """
         mapservice = config.get('geography.map_service')
-        if ( mapservice in ( constants.OPENSTREETMAP,
-                             constants.OPENSTREETMAP_RENDERER )):
+        if (mapservice in (constants.OPENSTREETMAP,
+                           constants.OPENSTREETMAP_RENDERER)):
             default_image = self.geo_mainmap
         else:
             default_image = self.geo_altmap
@@ -509,7 +558,8 @@ class GeoGraphyView(OsmGps, NavigationView):
             value = self.geo_othermap.get(int(event_type), default_image)
         if differtype:                   # in case multiple evts
             value = default_image # we use default icon.
-        self.marker_layer.add_marker((float(lat), float(lon)), value, count)
+        self.marker_layer.add_marker((float(lat), float(lon)), value,
+                                     count, color=color)
 
     def remove_all_gps(self):
         """
@@ -538,13 +588,15 @@ class GeoGraphyView(OsmGps, NavigationView):
 
     def _append_to_places_list(self, place, evttype, name, lat,
                                longit, descr, year, icontype,
-                               gramps_id, place_id, event_id, family_id
+                               gramps_id, place_id, event_id, family_id,
+                               color=None
                               ):
         """
         Create a list of places with coordinates.
         """
         found = any(p[0] == place for p in self.places_found)
-        if not found and self.nbplaces < self._config.get("geography.max_places"):
+        if not found and (self.nbplaces <
+                          self._config.get("geography.max_places")):
             # We only show the first "geography.max_places".
             # over 3000 or 4000 places, the geography become unusable.
             # In this case, filter the places ...
@@ -552,7 +604,8 @@ class GeoGraphyView(OsmGps, NavigationView):
             self.places_found.append([place, lat, longit])
         self.place_list.append([place, name, evttype, lat,
                                 longit, descr, year, icontype,
-                                gramps_id, place_id, event_id, family_id
+                                gramps_id, place_id, event_id, family_id,
+                                color
                                ])
         self.nbmarkers += 1
         tfa = float(lat)
@@ -587,22 +640,24 @@ class GeoGraphyView(OsmGps, NavigationView):
         """
         Create all markers for the specified person.
         """
+        if self.marker_layer is None:
+            return
         self.remove_all_markers()
         self.remove_all_gps()
         self.remove_all_tracks()
-        if ( self.current_map is not None and
-             self.current_map != config.get("geography.map_service") ):
+        if (self.current_map is not None and
+            self.current_map != config.get("geography.map_service")):
             self.change_map(self.osm, config.get("geography.map_service"))
         last = ""
         current = ""
         differtype = False
-        savetype = None
+        #savetype = None
         lat = 0.0
         lon = 0.0
         icon = None
         count = 0
         self.uistate.set_busy_cursor(True)
-        _LOG.debug("%s" % time.strftime("start create_marker : "
+        _LOG.debug("%s", time.strftime("start create_marker : "
                    "%a %d %b %Y %H:%M:%S", time.gmtime()))
         for mark in self.sort:
             current = ([mark[3], mark[4]])
@@ -611,25 +666,29 @@ class GeoGraphyView(OsmGps, NavigationView):
                 lat = mark[3]
                 lon = mark[4]
                 icon = mark[7]
+                colour = mark[12]
                 differtype = False
                 count = 1
                 continue
             if last != current:
-                self.add_marker(None, None, lat, lon, icon, differtype, count)
+                self.add_marker(None, None, lat, lon, icon, differtype,
+                                count, color=colour)
                 differtype = False
                 count = 1
                 last = current
                 lat = mark[3]
                 lon = mark[4]
                 icon = mark[7]
+                colour = mark[12]
             else: # This marker already exists. add info.
                 count += 1
                 if icon != mark[7]:
                     differtype = True
-        if ( lat != 0.0 and lon != 0.0 ):
-            self.add_marker(None, None, lat, lon, icon, differtype, count)
+        if lat != 0.0 and lon != 0.0:
+            self.add_marker(None, None, lat, lon, icon, differtype,
+                            count, color=mark[12])
             self._set_center_and_zoom()
-        _LOG.debug("%s" % time.strftime(" stop create_marker : "
+        _LOG.debug("%s", time.strftime(" stop create_marker : "
                    "%a %d %b %Y %H:%M:%S", time.gmtime()))
         self.uistate.set_busy_cursor(False)
 
@@ -646,17 +705,17 @@ class GeoGraphyView(OsmGps, NavigationView):
         pt2 = bbox[1]
         s_bbox_lat2 = pt2.rlat + 10.0
         s_bbox_lon2 = pt2.rlon + 10.0
-        result = ( s_bbox_lat1 > s_lat > s_bbox_lat2 ) and \
-                 ( s_bbox_lon1 < s_lon < s_bbox_lon2 )
+        result = ((s_bbox_lat1 > s_lat > s_bbox_lat2) and
+                  (s_bbox_lon1 < s_lon < s_bbox_lon2))
         return result
 
     def _autozoom_in(self, lvl, p1lat, p1lon, p2lat, p2lon):
         """
         We zoom in until at least one marker missing.
         """
-        if ( ( self._visible_marker(p1lat, p1lon)
-                  and self._visible_marker(p2lat, p2lon) )
-                and lvl < 18 ):
+        if ((self._visible_marker(p1lat, p1lon)
+             and self._visible_marker(p2lat, p2lon))
+             and lvl < 18):
             lvl += 1
             self.osm.set_zoom(lvl)
             GLib.timeout_add(int(50), self._autozoom_in, lvl,
@@ -669,9 +728,9 @@ class GeoGraphyView(OsmGps, NavigationView):
         """
         We zoom out until all markers visible.
         """
-        if ( not ( self._visible_marker(p1lat, p1lon)
-                      and self._visible_marker(p2lat, p2lon) )
-                and lvl > 1 ):
+        if (not (self._visible_marker(p1lat, p1lon)
+                 and self._visible_marker(p2lat, p2lon))
+                 and lvl > 1):
             lvl -= 1
             self.osm.set_zoom(lvl)
             GLib.timeout_add(int(50), self._autozoom_out, lvl,
@@ -691,8 +750,8 @@ class GeoGraphyView(OsmGps, NavigationView):
         level_start = self.osm.props.zoom
         p1lat, p1lon = self.begin_selection.get_degrees()
         p2lat, p2lon = self.end_selection.get_degrees()
-        lat = p1lat + ( p2lat - p1lat ) / 2
-        lon = p1lon + ( p2lon - p1lon ) / 2
+        lat = p1lat + (p2lat - p1lat) / 2
+        lon = p1lon + (p2lon - p1lon) / 2
         # We center the map on the center of the region
         self.osm.set_center(lat, lon)
         self.save_center(lat, lon)
@@ -720,9 +779,9 @@ class GeoGraphyView(OsmGps, NavigationView):
         signmaxlon = _get_sign(self.maxlon)
         signmaxlat = _get_sign(self.maxlat)
         current = osmgpsmap.MapPoint.new_degrees(self.minlat, self.minlon)
-        self.end_selection = current 
+        self.end_selection = current
         current = osmgpsmap.MapPoint.new_degrees(self.maxlat, self.maxlon)
-        self.begin_selection = current 
+        self.begin_selection = current
         if signminlon == signmaxlon:
             maxlong = abs(abs(self.minlon) - abs(self.maxlon))
         else:
@@ -733,7 +792,7 @@ class GeoGraphyView(OsmGps, NavigationView):
             maxlat = abs(abs(self.minlat) + abs(self.maxlat))
         latit = longt = 0.0
         for mark in self.sort:
-            if ( signminlat == signmaxlat ):
+            if signminlat == signmaxlat:
                 if signminlat == 1:
                     latit = self.minlat+self.centerlat
                 else:
@@ -742,7 +801,7 @@ class GeoGraphyView(OsmGps, NavigationView):
                 latit = self.maxlat-self.centerlat
             else:
                 latit = self.minlat+self.centerlat
-            if ( signminlon == signmaxlon ):
+            if signminlon == signmaxlon:
                 if signminlon == 1:
                     longt = self.minlon+self.centerlon
                 else:
@@ -759,7 +818,7 @@ class GeoGraphyView(OsmGps, NavigationView):
         if config.get("geography.lock"):
             self.osm.set_center_and_zoom(config.get("geography.center-lat"),
                                          config.get("geography.center-lon"),
-                                         config.get("geography.zoom") )
+                                         config.get("geography.zoom"))
         else:
             self._autozoom()
             self.save_center(self.latit, self.longt)
@@ -780,13 +839,16 @@ class GeoGraphyView(OsmGps, NavigationView):
         fnam = mnam = _("Unknown")
         if family_list:
             for family in family_list:
+                father = mother = None
                 handle = family.get_father_handle()
-                father = dbstate.db.get_person_from_handle(handle)
+                if handle:
+                    father = dbstate.db.get_person_from_handle(handle)
                 handle = family.get_mother_handle()
-                mother = dbstate.db.get_person_from_handle(handle)
+                if handle:
+                    mother = dbstate.db.get_person_from_handle(handle)
                 fnam = _nd.display(father) if father else _("Unknown")
                 mnam = _nd.display(mother) if mother else _("Unknown")
-        return ( fnam, mnam )
+        return (fnam, mnam)
 
     #-------------------------------------------------------------------------
     #
@@ -801,10 +863,11 @@ class GeoGraphyView(OsmGps, NavigationView):
         if media_list:
             for media_ref in media_list:
                 object_handle = media_ref.get_reference_handle()
-                media_obj = self.dbstate.db.get_object_from_handle(object_handle)
+                media_obj = self.dbstate.db.get_media_from_handle(object_handle)
                 path = media_obj.get_path()
                 name, extension = os.path.splitext(path)
                 if extension == ".kml":
+                    path = media_path_full(self.dbstate.db, path)
                     if os.path.isfile(path):
                         self.kml_layer.add_kml(path)
 
@@ -817,6 +880,14 @@ class GeoGraphyView(OsmGps, NavigationView):
         """
         Print or save the view that is currently shown
         """
+        if Gtk.MAJOR_VERSION == 3 and Gtk.MINOR_VERSION < 11:
+            from gramps.gui.dialog import WarningDialog
+            WarningDialog(
+                _("You can't use the print functionality"),
+                _("Your Gtk version is too old."),
+                parent=self.uistate.window)
+            return
+
         req = self.osm.get_allocation()
         widthpx = req.width
         heightpx = req.height
@@ -881,7 +952,7 @@ class GeoGraphyView(OsmGps, NavigationView):
         """
         Edit the selected person at the marker position
         """
-        _LOG.debug("edit_person : %s" % mark[8])
+        _LOG.debug("edit_person : %s", mark[8])
         # need to add code here to edit the person.
         person = self.dbstate.db.get_person_from_gramps_id(mark[8])
         try:
@@ -893,7 +964,7 @@ class GeoGraphyView(OsmGps, NavigationView):
         """
         Edit the selected family at the marker position
         """
-        _LOG.debug("edit_family : %s" % mark[11])
+        _LOG.debug("edit_family : %s", mark[11])
         family = self.dbstate.db.get_family_from_gramps_id(mark[11])
         try:
             EditFamily(self.dbstate, self.uistate, [], family)
@@ -904,7 +975,7 @@ class GeoGraphyView(OsmGps, NavigationView):
         """
         Edit the selected event at the marker position
         """
-        _LOG.debug("edit_event : %s" % mark[10])
+        _LOG.debug("edit_event : %s", mark[10])
         event = self.dbstate.db.get_event_from_gramps_id(mark[10])
         try:
             EditEvent(self.dbstate, self.uistate, [], event)
@@ -930,20 +1001,21 @@ class GeoGraphyView(OsmGps, NavigationView):
 
         """
         # Ask for the kml file
-        filter = Gtk.FileFilter()
-        filter.add_pattern("*.kml")
+        filtering = Gtk.FileFilter()
+        filtering.add_pattern("*.kml")
         kml = Gtk.FileChooserDialog(
             _("Select a kml file used to add places"),
             action=Gtk.FileChooserAction.OPEN,
+            parent=self.uistate.window,
             buttons=(_('_Cancel'), Gtk.ResponseType.CANCEL,
                      _('_Apply'), Gtk.ResponseType.OK))
         mpath = HOME_DIR
         kml.set_current_folder(os.path.dirname(mpath))
-        kml.set_filter(filter)
+        kml.set_filter(filtering)
 
         status = kml.run()
         if status == Gtk.ResponseType.OK:
-            val = conv_to_unicode(kml.get_filename())
+            val = kml.get_filename()
             if val:
                 kmlfile = Kml(val)
                 points = kmlfile.add_points()
@@ -993,6 +1065,7 @@ class GeoGraphyView(OsmGps, NavigationView):
                     if gids == "":
                         gids = plce.gramps_id
                     else:
+                        # TODO for Arabic, should the next comma be translated?
                         gids = gids + ", " + plce.gramps_id
             if nb_places > 1:
                 from gramps.gui.dialog import WarningDialog
@@ -1007,7 +1080,8 @@ class GeoGraphyView(OsmGps, NavigationView):
                             'bold_start' : '<b>',
                             'bold_end'   : '</b>',
                             'title': '<b>' + place_title + '</b>',
-                            'gid': gids}
+                            'gid': gids},
+                       parent=self.uistate.window
                       )
             else:
                 self.mark = [None, None, None, None, None, None, None,
@@ -1032,9 +1106,19 @@ class GeoGraphyView(OsmGps, NavigationView):
         new_place.set_latitude(str(plat))
         new_place.set_longitude(str(plon))
         if parent:
-            placeref = PlaceRef()
-            placeref.ref = parent
-            new_place.add_placeref(placeref)
+            if isinstance(parent, Place):
+                placeref = PlaceRef()
+                placeref.ref = parent
+                new_place.add_placeref(placeref)
+            else:
+                found = None
+                for place in self.dbstate.db.iter_places():
+                    found = place
+                    if place.name.get_value() == parent:
+                        break
+                placeref = PlaceRef()
+                placeref.ref = found.get_handle()
+                new_place.add_placeref(placeref)
         try:
             EditPlace(self.dbstate, self.uistate, [], new_place)
             self.add_marker(None, None, plat, plon, None, True, 0)
@@ -1049,10 +1133,6 @@ class GeoGraphyView(OsmGps, NavigationView):
         place = self.dbstate.db.get_place_from_gramps_id(self.mark[9])
         place.set_latitude(str(plat))
         place.set_longitude(str(plon))
-        if parent:
-            placeref = PlaceRef()
-            placeref.ref = parent
-            place.add_placeref(placeref)
         try:
             EditPlace(self.dbstate, self.uistate, [], place)
         except WindowActiveError:
@@ -1100,7 +1180,6 @@ class GeoGraphyView(OsmGps, NavigationView):
         else:
             config.set("geography.lock", True)
         self.lock = config.get("geography.lock")
-        pass
 
     def config_crosshair(self, client, cnxn_id, entry, data):
         """
@@ -1111,7 +1190,6 @@ class GeoGraphyView(OsmGps, NavigationView):
         else:
             config.set("geography.show_cross", True)
         self.set_crosshair(config.get("geography.show_cross"))
-        pass
 
     def specific_options(self, configdialog):
         """
@@ -1157,24 +1235,32 @@ class GeoGraphyView(OsmGps, NavigationView):
                 _('The maximum number of places to show'),
                 4, 'geography.max_places',
                 (1000, 10000))
-        configdialog.add_checkbox(grid, 
-                _('Use keypad for shortcuts :\n' 
-                  'Either we choose the + and - from the keypad if we select this,\n'
+        configdialog.add_checkbox(grid,
+                _('Use keypad for shortcuts :\n'
+                  'Either we choose the + and - from the keypad if we '
+                  'select this,\n'
                   'or we use the characters from the keyboard.'),
                 5, 'geography.use-keypad',
                 extra_callback=self.update_shortcuts)
         return _('The map'), grid
 
     def set_tilepath(self, *obj):
+        """
+        Save the tile path in the config section.
+        """
         if self.path_entry.get_text().strip():
             config.set('geography.path', self.path_entry.get_text())
         else:
-            config.set('geography.path', GEOGRAPHY_PATH )
+            config.set('geography.path', GEOGRAPHY_PATH)
 
     def select_tilepath(self, *obj):
-        f = Gtk.FileChooserDialog(
+        """
+        Call a file chooser selection box to select the tile path.
+        """
+        selected_dir = Gtk.FileChooserDialog(
             _("Select tile cache directory for offline mode"),
             action=Gtk.FileChooserAction.SELECT_FOLDER,
+            parent=self.uistate.window,
             buttons=(_('_Cancel'),
                      Gtk.ResponseType.CANCEL,
                      _('_Apply'),
@@ -1182,12 +1268,11 @@ class GeoGraphyView(OsmGps, NavigationView):
         mpath = config.get('geography.path')
         if not mpath:
             mpath = HOME_DIR
-        f.set_current_folder(os.path.dirname(mpath))
+        selected_dir.set_current_folder(os.path.dirname(mpath))
 
-        status = f.run()
+        status = selected_dir.run()
         if status == Gtk.ResponseType.OK:
-            val = conv_to_unicode(f.get_filename())
+            val = selected_dir.get_filename()
             if val:
                 self.path_entry.set_text(val)
-        f.destroy()
-
+        selected_dir.destroy()
