@@ -17,7 +17,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 #
 
@@ -48,8 +48,8 @@ def get_ref(db, objclass, handle):
         ref = db.get_place_from_handle(handle)
     elif objclass == 'Note':
         ref = db.get_note_from_handle(handle)
-    elif objclass in ['MediaObject', 'Media']:
-        ref = db.get_object_from_handle(handle)
+    elif objclass == 'Media':
+        ref = db.get_media_from_handle(handle)
     else:
         ref = objclass
     return ref
@@ -87,7 +87,7 @@ run_family = lambda db, doc, obj: run(db, doc, obj, 'family', _("Family"))
 run_event  = lambda db, doc, obj: run(db, doc, obj, 'event', _("Event"))
 run_source = lambda db, doc, obj: run(db, doc, obj, 'source', _("Source"))
 run_citation = lambda db, doc, obj: run(db, doc, obj, 'citation', _("Citation"))
-run_source_or_citation = lambda db, doc, obj: run(db, doc, obj, 
+run_source_or_citation = lambda db, doc, obj: run(db, doc, obj,
                                 'source or citation', _("Source or Citation"))
 run_place  = lambda db, doc, obj: run(db, doc, obj, 'place', _("Place"))
 run_media  = lambda db, doc, obj: run(db, doc, obj, 'media', _("Media"))
