@@ -25,10 +25,10 @@
 """
 Russian-specific definitions of relationships
 """
-from __future__ import unicode_literals
+
 #-------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
 #-------------------------------------------------------------------------
 
@@ -48,249 +48,249 @@ _parents_level = [
   "прапрапрапрапрадедушки/прапрапрапрапрабабушки (8 поколение)",
   ]
 
-_male_cousin_level = [ 
-  "", 
-  "двоюродный", 
-  "троюродный", 
-  "четвероюродный",
-  "пятиюродный", 
-  "шестиюродный", 
-  "семиюродный", 
-  "восьмиюродный",
-  "девятиюродный", 
-  "десятиюродный", 
-  "одиннацатиюродный", 
-  "двенадцатиюродный", 
-  "тринадцатиюродный", 
-  "четырнадцатиюродный", 
-  "пятнадцатиюродный", 
-  "шестнадцатиюродный", 
-  "семнадцатиюродный", 
-  "восемнадцатиюродный", 
-  "девятнадцатиюродный", 
-  "двадцатиюродный", 
-  ]
-
-_female_cousin_level = [ 
-  "", 
-  "двоюродная", 
-  "троюродная", 
-  "четвероюродная",
-  "пятиюродная", 
-  "шестиюродная", 
-  "семиюродная", 
-  "восьмиюродная",
-  "девятиюродная", 
-  "десятиюродная", 
-  "одиннацатиюродная", 
-  "двенадцатиюродная", 
-  "тринадцатиюродная", 
-  "четырнадцатиюродная", 
-  "пятнадцатиюродная", 
-  "шестнадцатиюродная", 
-  "семнадцатиюродная", 
-  "восемнадцатиюродная", 
-  "девятнадцатиюродная", 
-  "двадцатиюродная", 
-  ]
-
-_cousin_level = [ 
+_male_cousin_level = [
   "",
-  "двоюродные", 
-  "троюродные", 
+  "двоюродный",
+  "троюродный",
+  "четвероюродный",
+  "пятиюродный",
+  "шестиюродный",
+  "семиюродный",
+  "восьмиюродный",
+  "девятиюродный",
+  "десятиюродный",
+  "одиннацатиюродный",
+  "двенадцатиюродный",
+  "тринадцатиюродный",
+  "четырнадцатиюродный",
+  "пятнадцатиюродный",
+  "шестнадцатиюродный",
+  "семнадцатиюродный",
+  "восемнадцатиюродный",
+  "девятнадцатиюродный",
+  "двадцатиюродный",
+  ]
+
+_female_cousin_level = [
+  "",
+  "двоюродная",
+  "троюродная",
+  "четвероюродная",
+  "пятиюродная",
+  "шестиюродная",
+  "семиюродная",
+  "восьмиюродная",
+  "девятиюродная",
+  "десятиюродная",
+  "одиннацатиюродная",
+  "двенадцатиюродная",
+  "тринадцатиюродная",
+  "четырнадцатиюродная",
+  "пятнадцатиюродная",
+  "шестнадцатиюродная",
+  "семнадцатиюродная",
+  "восемнадцатиюродная",
+  "девятнадцатиюродная",
+  "двадцатиюродная",
+  ]
+
+_cousin_level = [
+  "",
+  "двоюродные",
+  "троюродные",
   "четвероюродные",
-  "пятиюродные", 
-  "шестиюродные", 
-  "семиюродные", 
+  "пятиюродные",
+  "шестиюродные",
+  "семиюродные",
   "восьмиюродные",
-  "девятиюродные", 
+  "девятиюродные",
   "десятиюродные",
-  "одиннацатиюродные", 
+  "одиннацатиюродные",
   "двенадцатиюродные",
-  "тринадцатиюродные", 
-  "четырнадцатиюродные", 
-  "пятнадцатиюродные", 
-  "шестнадцатиюродные", 
-  "семнадцатиюродные", 
-  "восемнадцатиюродные", 
-  "девятнадцатиюродные", 
-  "двадцатиюродные", 
+  "тринадцатиюродные",
+  "четырнадцатиюродные",
+  "пятнадцатиюродные",
+  "шестнадцатиюродные",
+  "семнадцатиюродные",
+  "восемнадцатиюродные",
+  "девятнадцатиюродные",
+  "двадцатиюродные",
   ]
 
-_junior_male_removed_level = [ 
-  "брат", 
-  "племянник", 
-  "внучатый племянник", 
-  "правнучатый племянник", 
-  "праправнучатый племянник", 
-  "прапраправнучатый племянник", 
-  "прапрапраправнучатый племянник", 
+_junior_male_removed_level = [
+  "брат",
+  "племянник",
+  "внучатый племянник",
+  "правнучатый племянник",
+  "праправнучатый племянник",
+  "прапраправнучатый племянник",
+  "прапрапраправнучатый племянник",
   ]
 
-_junior_female_removed_level = [ 
-  "сестра", 
-  "племянница", 
-  "внучатая племянница", 
-  "правнучатая племянница", 
-  "праправнучатая племянница", 
-  "прапраправнучатая племянница", 
-  "прапрапраправнучатая племянница", 
+_junior_female_removed_level = [
+  "сестра",
+  "племянница",
+  "внучатая племянница",
+  "правнучатая племянница",
+  "праправнучатая племянница",
+  "прапраправнучатая племянница",
+  "прапрапраправнучатая племянница",
   ]
 
-_juniors_removed_level = [ 
-  "братья/сестры", 
-  "племянники", 
-  "внучатые племянники", 
-  "правнучатые племянники", 
-  "праправнучатые племянники", 
-  "прапраправнучатые племянники", 
-  "прапрапраправнучатые племянники", 
+_juniors_removed_level = [
+  "братья/сестры",
+  "племянники",
+  "внучатые племянники",
+  "правнучатые племянники",
+  "праправнучатые племянники",
+  "прапраправнучатые племянники",
+  "прапрапраправнучатые племянники",
   ]
 
-_senior_male_removed_level = [ 
-  "", 
-  "дядя", 
-  "дед", 
-  "прадед", 
-  "прапрадед", 
-  "прапрапрадед", 
-  "прапрапрапрадед", 
+_senior_male_removed_level = [
+  "",
+  "дядя",
+  "дед",
+  "прадед",
+  "прапрадед",
+  "прапрапрадед",
+  "прапрапрапрадед",
   ]
 
-_senior_female_removed_level = [ 
-  "", 
-  "тётя", 
-  "бабушка", 
-  "прабабушка", 
-  "прапрабабушка", 
-  "прапрапрабабушка", 
-  "прапрапрапрабабушка", 
+_senior_female_removed_level = [
+  "",
+  "тётя",
+  "бабушка",
+  "прабабушка",
+  "прапрабабушка",
+  "прапрапрабабушка",
+  "прапрапрапрабабушка",
   ]
 
-_seniors_removed_level = [ 
-  "", 
-  "дяди/тёти", 
-  "дедушки/бабушки", 
-  "прадеды/прабабушки", 
-  "прапрадеды/прапрабабушки", 
-  "прапрапрадеды/прапрапрабабушки", 
-  "прапрапрапрадеды/прапрапрапрабабушки", 
+_seniors_removed_level = [
+  "",
+  "дяди/тёти",
+  "дедушки/бабушки",
+  "прадеды/прабабушки",
+  "прапрадеды/прапрабабушки",
+  "прапрапрадеды/прапрапрабабушки",
+  "прапрапрапрадеды/прапрапрапрабабушки",
   ]
 
-_father_level = [ 
-  "", 
-  "отец", 
-  "дед", 
-  "прадед", 
-  "прапрадед", 
-  "прапрапрадед", 
-  "прапрапрапрадед", 
+_father_level = [
+  "",
+  "отец",
+  "дед",
+  "прадед",
+  "прапрадед",
+  "прапрапрадед",
+  "прапрапрапрадед",
   ]
 
-_mother_level = [ 
-   "", 
-   "мать", 
-   "бабушка", 
-   "прабабушка", 
-   "прапрабабушка", 
-   "прапрапрабабушка", 
-   "прапрапрапрабабушка", 
+_mother_level = [
+   "",
+   "мать",
+   "бабушка",
+   "прабабушка",
+   "прапрабабушка",
+   "прапрапрабабушка",
+   "прапрапрапрабабушка",
    ]
 
-_son_level = [ 
-  "", 
-  "сын", 
-  "внук", 
-  "правнук", 
-  "праправнук", 
-  "прапраправнук", 
-  "прапрапраправнук", 
+_son_level = [
+  "",
+  "сын",
+  "внук",
+  "правнук",
+  "праправнук",
+  "прапраправнук",
+  "прапрапраправнук",
   ]
 
-_daughter_level = [ 
-  "", 
-  "дочь", 
-  "внучка", 
-  "правнучка", 
-  "праправнучка", 
-  "прапраправнучка", 
-  "прапрапраправнучка", 
+_daughter_level = [
+  "",
+  "дочь",
+  "внучка",
+  "правнучка",
+  "праправнучка",
+  "прапраправнучка",
+  "прапрапраправнучка",
   ]
 
-_children_level = [ 
- "", 
- "дети", 
- "внуки", 
- "правнуки", 
- "праправнуки", 
- "прапраправнуки", 
- "прапрапраправнуки", 
+_children_level = [
+ "",
+ "дети",
+ "внуки",
+ "правнуки",
+ "праправнуки",
+ "прапраправнуки",
+ "прапрапраправнуки",
  "прапрапрапраправнуки",
  ]
 
-_sister_level = [ 
-  "", 
-  "сестра", 
-  "тётя", 
-  "двоюродная бабушка", 
-  "двоюродная прабабушка", 
-  "двоюродная прапрабабушка", 
-  "двоюродная прапрапрабабушка", 
-  "двоюродная прапрапрапрабабушка", 
+_sister_level = [
+  "",
+  "сестра",
+  "тётя",
+  "двоюродная бабушка",
+  "двоюродная прабабушка",
+  "двоюродная прапрабабушка",
+  "двоюродная прапрапрабабушка",
+  "двоюродная прапрапрапрабабушка",
   ]
 
-_brother_level = [ 
-  "", 
-  "брат", 
-  "дядя", 
-  "двоюродный дед", 
-  "двоюродный прадед", 
-  "двоюродный прапрадед", 
-  "двоюродный прапрапрадед", 
-  "двоюродный прапрапрапрадед", 
+_brother_level = [
+  "",
+  "брат",
+  "дядя",
+  "двоюродный дед",
+  "двоюродный прадед",
+  "двоюродный прапрадед",
+  "двоюродный прапрапрадед",
+  "двоюродный прапрапрапрадед",
   ]
 
-_siblings_level = [ 
-  "", 
-  "братья/сестры", 
-  "дядьки/тётки", 
-  "двоюродные дедушки/бабушки", 
-  "двоюродные прадедушки/прабабушки", 
-  "двоюродные прапрадедушки/прапрабабушки (5 поколение)", 
+_siblings_level = [
+  "",
+  "братья/сестры",
+  "дядьки/тётки",
+  "двоюродные дедушки/бабушки",
+  "двоюродные прадедушки/прабабушки",
+  "двоюродные прапрадедушки/прапрабабушки (5 поколение)",
   "двоюродные прапрапрадедушки/прапрапрабабушки (6 поколение)",
   "двоюродные прапрапрапрадедушки/прапрапрапрабабушки (7 поколение)",
   "двоюродные прапрапрапрапрадедушки/прапрапрапрапрабабушки (8 поколение)",
   ]
 
-_nephew_level = [ 
-  "", 
-  "племянник", 
-  "внучатый племянник", 
-  "правнучатый племянник", 
-  "праправнучатый племянник", 
-  "прапраправнучатый племянник", 
-  "прапрапраправнучатый племянник", 
+_nephew_level = [
+  "",
+  "племянник",
+  "внучатый племянник",
+  "правнучатый племянник",
+  "праправнучатый племянник",
+  "прапраправнучатый племянник",
+  "прапрапраправнучатый племянник",
   ]
 
-_niece_level = [ 
-  "", 
-  "племянница", 
-  "внучатая племянница", 
-  "правнучатая племянница", 
-  "праправнучатая племянница", 
-  "прапраправнучатая племянница", 
-  "прапрапраправнучатая племянница", 
+_niece_level = [
+  "",
+  "племянница",
+  "внучатая племянница",
+  "правнучатая племянница",
+  "праправнучатая племянница",
+  "прапраправнучатая племянница",
+  "прапрапраправнучатая племянница",
   ]
 
 _nephews_nieces_level = [
-  "", 
-  "братья/сестры", 
-  "племянники", 
-  "внучатые племянники", 
-  "правнучатые племянники", 
-  "праправнучатые племянники", 
-  "прапраправнучатые племянники", 
-  "прапрапраправнучатые племянники", 
+  "",
+  "братья/сестры",
+  "племянники",
+  "внучатые племянники",
+  "правнучатые племянники",
+  "праправнучатые племянники",
+  "прапраправнучатые племянники",
+  "прапрапраправнучатые племянники",
   ]
 
 #-------------------------------------------------------------------------
@@ -396,7 +396,7 @@ class RelationshipCalculator(gramps.gen.relationship.RelationshipCalculator):
 
     def get_single_relationship_string(self, Ga, Gb, gender_a, gender_b,
                                        reltocommon_a, reltocommon_b,
-                                       only_birth=True, 
+                                       only_birth=True,
                                        in_law_a=False, in_law_b=False):
 
         if Gb == 0:
@@ -463,28 +463,28 @@ class RelationshipCalculator(gramps.gen.relationship.RelationshipCalculator):
             else:
                 rel_str = "дальние племянники/племянницы"
         elif Ga > Gb:
-            # These are cousins in different generations with the second person 
-            # being in a higher generation from the common ancestor than the 
+            # These are cousins in different generations with the second person
+            # being in a higher generation from the common ancestor than the
             # first person.
             if Gb <= len(_seniors_removed_level) and (Ga-Gb) < len(_cousin_level):
-                rel_str = "%s %s" % ( _cousin_level[Gb-1], 
+                rel_str = "%s %s" % ( _cousin_level[Gb-1],
                                                   _seniors_removed_level[Ga-Gb] )
             else:
                 rel_str =  "(старшие) дальние родственники"
         else:
-            # These are cousins in different generations with the second person 
-            # being in a lower generation from the common ancestor than the 
+            # These are cousins in different generations with the second person
+            # being in a lower generation from the common ancestor than the
             # first person.
             if Ga <= len(_juniors_removed_level) and (Gb-Ga) < len(_cousin_level):
-                rel_str = "%s %s" % ( _cousin_level[Ga-1], 
+                rel_str = "%s %s" % ( _cousin_level[Ga-1],
                                                     _juniors_removed_level[Gb-Ga] )
             else:
                 rel_str =  "(младшие) дальние родственники"
-                
+
         if in_law_b == True:
             # TODO: Translate this!
             rel_str = "spouses of %s" % rel_str
-                
+
         return rel_str
 
 # TODO: def get_sibling_relationship_string for Russian step and inlaw relations
@@ -497,7 +497,7 @@ if __name__ == "__main__":
     # python src/plugins/rel/rel_ru.py
     # (Above not needed here)
 
-    """TRANSLATORS, copy this if statement at the bottom of your 
+    """TRANSLATORS, copy this if statement at the bottom of your
         rel_xx.py module, and test your work with:
         python src/plugins/rel/rel_xx.py
     """
