@@ -31,8 +31,6 @@
 # standard python modules
 #
 #------------------------------------------------------------------------
-from __future__ import print_function
-
 import os
 
 #------------------------------------------------------------------------
@@ -46,12 +44,12 @@ from gi.repository import GdkPixbuf
 
 #------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
 #------------------------------------------------------------------------
 from gramps.gen.const import URL_MANUAL_PAGE, ICON, SPLASH
 from gramps.gui.display import display_help
-from gramps.gen.lib import MediaObject
+from gramps.gen.lib import Media
 from gramps.gen.db import DbTxn
 from gramps.gen.updatecallback import UpdateCallback
 from gramps.gui.plug import tool
@@ -59,7 +57,7 @@ from gramps.gen.utils.file import media_path_full, relative_path, media_path
 from gramps.gen.const import GRAMPS_LOCALE as glocale
 _ = glocale.translation.sgettext
 from gramps.gen.mime import get_type, is_image_type
-from gramps.gen.constfunc import cuni
+from gramps.gui.managedwindow import ManagedWindow
 
 #-------------------------------------------------------------------------
 #
@@ -67,54 +65,66 @@ from gramps.gen.constfunc import cuni
 #
 #-------------------------------------------------------------------------
 WIKI_HELP_PAGE = '%s_-_Tools' % URL_MANUAL_PAGE
-WIKI_HELP_SEC = _('manual|Media_Manager...')
+WIKI_HELP_SEC = _('manual|Media_Manager')
 
 #-------------------------------------------------------------------------
 #
 # This is an Assistant implementation to guide the user
 #
 #-------------------------------------------------------------------------
-class MediaMan(tool.Tool):
+class MediaMan(ManagedWindow, tool.Tool):
 
     def __init__(self, dbstate, user, options_class, name, callback=None):
         uistate = user.uistate
 
         tool.Tool.__init__(self, dbstate, options_class, name)
-        self.uistate = uistate
+        ManagedWindow.__init__(self, uistate, [], self.__class__)
         self.callback = uistate.pulse_progressbar
 
         self.batch_ops = []
         self.build_batch_ops()
 
         self.assistant = Gtk.Assistant()
+        self.set_window(self.assistant, None, _('Media Manager'))
+        self.setup_configs('interface.mediaman', 780, 600)
 
-        self.assistant.set_title(_('Gramps Media Manager'))
-        self.assistant.connect('close', self.close)
-        self.assistant.connect('cancel', self.close)
+        help_btn = Gtk.Button.new_with_label(_('Help'))
+        help_btn.connect('clicked', self.on_help_clicked)
+        self.assistant.add_action_widget(help_btn)
+
+        self.assistant.connect('close', self.do_close)
+        self.assistant.connect('cancel', self.do_close)
         self.assistant.connect('apply', self.run)
         self.assistant.connect('prepare', self.prepare)
 
         intro = IntroductionPage()
         self.add_page(intro, Gtk.AssistantPageType.INTRO, _('Introduction'))
         self.selection = SelectionPage(self.batch_ops)
-        self.add_page(self.selection, Gtk.AssistantPageType.CONTENT, 
+        self.add_page(self.selection, Gtk.AssistantPageType.CONTENT,
                       _('Selection'))
         self.settings = SettingsPage(self.batch_ops, self.assistant)
         self.add_page(self.settings, Gtk.AssistantPageType.CONTENT)
         self.confirmation = ConfirmationPage(self.batch_ops)
-        self.add_page(self.confirmation, Gtk.AssistantPageType.CONFIRM, 
+        self.add_page(self.confirmation, Gtk.AssistantPageType.CONFIRM,
                       _('Final confirmation'))
         self.conclusion = ConclusionPage(self.assistant)
         self.add_page(self.conclusion, Gtk.AssistantPageType.SUMMARY)
-        
-        self.assistant.show()
+
+        self.show()
         self.assistant.set_forward_page_func(self.forward_page, None)
 
-    def close(self, assistant):
+    def build_menu_names(self, obj):
+        """Override :class:`.ManagedWindow` method."""
+        return (_('Media Manager'), None)
+
+    def do_close(self, assistant):
         """
         Close the assistant.
         """
+        position = self.window.get_position() # crock
         self.assistant.hide()
+        self.window.move(position[0], position[1])
+        self.close()
 
     def forward_page(self, page, data):
         """
@@ -176,7 +186,7 @@ class MediaMan(tool.Tool):
         success = self.batch_ops[index].run_tool()
         self.conclusion.set_result(success)
         self.post_run()
-        
+
     def pre_run(self):
         """
         Code to run prior to the batch op.
@@ -196,14 +206,14 @@ class MediaMan(tool.Tool):
 # Assistant pages
 #
 #------------------------------------------------------------------------
-class IntroductionPage(Gtk.VBox):
+class IntroductionPage(Gtk.Box):
     """
     A page containing introductory text.
     """
     def __init__(self):
-        GObject.GObject.__init__(self)
+        Gtk.Box.__init__(self, orientation=Gtk.Orientation.VERTICAL)
 
-        # Using set_page_side_image causes window sizing problems, so put the 
+        # Using set_page_side_image causes window sizing problems, so put the
         # image in the main page instead.
         image = Gtk.Image()
         image.set_from_file(SPLASH)
@@ -211,8 +221,7 @@ class IntroductionPage(Gtk.VBox):
         label = Gtk.Label(label=self.__get_intro_text())
         label.set_line_wrap(True)
         label.set_use_markup(True)
-        if (Gtk.get_major_version(), Gtk.get_minor_version()) >= (3, 10):
-            label.set_max_width_chars(60)
+        label.set_max_width_chars(60)
 
         self.pack_start(image, False, False, 0)
         self.pack_start(label, False, False, 5)
@@ -228,7 +237,8 @@ class IntroductionPage(Gtk.VBox):
                  "The Gramps media object is a collection of data about "
                  "the media object file: its filename and/or path, its "
                  "description, its ID, notes, source references, etc. "
-                 "These data <b>do not include the file itself</b>.\n\n"
+                 "These data "
+                 "%(bold_start)sdo not include the file itself%(bold_end)s.\n\n"
                  "The files containing image, sound, video, etc, exist "
                  "separately on your hard drive. These files are "
                  "not managed by Gramps and are not included in the Gramps "
@@ -238,23 +248,25 @@ class IntroductionPage(Gtk.VBox):
                  "your Gramps database. If you want to move or rename "
                  "the files then you need to do it on your own, outside of "
                  "Gramps. Then you can adjust the paths using this tool so "
-                 "that the media objects store the correct file locations.")
+                 "that the media objects store the correct file locations."
+                ) % { 'bold_start' : '<b>' ,
+                      'bold_end'   : '</b>' }
 
-class SelectionPage(Gtk.VBox):
+class SelectionPage(Gtk.Box):
     """
     A page with the radio buttons for every available batch op.
     """
     def __init__(self, batch_ops):
-        GObject.GObject.__init__(self)
-        
+        Gtk.Box.__init__(self, orientation=Gtk.Orientation.VERTICAL)
+
         self.batch_op_buttons = []
 
         self.set_spacing(12)
 
-        table = Gtk.Table(n_rows=2 * len(batch_ops), n_columns=2)
-        table.set_row_spacings(6)
-        table.set_col_spacings(6)
-        
+        grid = Gtk.Grid()
+        grid.set_row_spacing(6)
+        grid.set_column_spacing(6)
+
         button = None
         for index in range(len(batch_ops)):
             title = batch_ops[index].title
@@ -263,28 +275,28 @@ class SelectionPage(Gtk.VBox):
             button = Gtk.RadioButton.new_with_mnemonic_from_widget(button, title)
             button.set_tooltip_text(description)
             self.batch_op_buttons.append(button)
-            table.attach(button, 0, 2, 2 * index, 2 * index + 1, yoptions=0)
-        
-        self.add(table)
+            grid.attach(button, 0, 2 * index, 2, 1)
+
+        self.add(grid)
 
     def get_index(self):
         """
-        Query the selection radiobuttons and return the index number 
-        of the selected batch op. 
+        Query the selection radiobuttons and return the index number
+        of the selected batch op.
         """
         for index in range(len(self.batch_op_buttons)):
             button = self.batch_op_buttons[index]
             if button.get_active():
                 return index
-        else:
-            return 0
 
-class SettingsPage(Gtk.VBox):
+        return 0
+
+class SettingsPage(Gtk.Box):
     """
     An extra page with the settings specific for the chosen batch-op.
     """
     def __init__(self, batch_ops, assistant):
-        GObject.GObject.__init__(self)
+        Gtk.Box.__init__(self, orientation=Gtk.Orientation.VERTICAL)
         self.assistant = assistant
         self.batch_ops = batch_ops
 
@@ -304,13 +316,13 @@ class SettingsPage(Gtk.VBox):
             self.assistant.set_page_title(self, '')
             return False
 
-class ConfirmationPage(Gtk.VBox):
+class ConfirmationPage(Gtk.Box):
     """
-    A page to display the summary of the proposed action, as well as the 
+    A page to display the summary of the proposed action, as well as the
     list of affected paths.
     """
     def __init__(self, batch_ops):
-        GObject.GObject.__init__(self)
+        Gtk.Box.__init__(self, orientation=Gtk.Orientation.VERTICAL)
 
         self.batch_ops = batch_ops
 
@@ -318,9 +330,9 @@ class ConfirmationPage(Gtk.VBox):
         self.set_border_width(12)
 
         self.confirm = Gtk.Label()
+        self.confirm.set_halign(Gtk.Align.START)
         self.confirm.set_line_wrap(True)
         self.confirm.set_use_markup(True)
-        self.confirm.set_alignment(0, 0.5)
         self.pack_start(self.confirm, False, True, 0)
 
         scrolled_window = Gtk.ScrolledWindow()
@@ -336,8 +348,8 @@ class ConfirmationPage(Gtk.VBox):
         scrolled_window.add(tree)
         self.pack_start(scrolled_window, True, True, 0)
 
-        label3 = Gtk.Label(_('Press Apply to proceed, Cancel to abort, '
-                             'or Back to revisit your options.'))
+        label3 = Gtk.Label(label=_('Press Apply to proceed, Cancel to abort, '
+                                   'or Back to revisit your options.'))
         self.pack_start(label3, False, True, 0)
 
     def prepare(self, index):
@@ -353,13 +365,13 @@ class ConfirmationPage(Gtk.VBox):
         for path in path_list:
             self.path_model.append(row=[path])
 
-class ConclusionPage(Gtk.VBox):
+class ConclusionPage(Gtk.Box):
     """
-    A page to display the summary of the proposed action, as well as the 
+    A page to display the summary of the proposed action, as well as the
     list of affected paths.
     """
     def __init__(self, assistant):
-        GObject.GObject.__init__(self)
+        Gtk.Box.__init__(self, orientation=Gtk.Orientation.VERTICAL)
 
         self.assistant = assistant
 
@@ -371,7 +383,7 @@ class ConclusionPage(Gtk.VBox):
 
         self.pack_start(image, False, False, 0)
         self.pack_start(self.label, False, False, 5)
-        
+
     def set_result(self, success):
         if success:
             conclusion_title =  _('Operation successfully finished')
@@ -482,54 +494,56 @@ class PathChange(BatchOp):
     def build_config(self):
         title = _("Replace substring settings")
 
-        box = Gtk.VBox()
+        box = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
         box.set_spacing(12)
 
-        table = Gtk.Table(n_rows=2, n_columns=2)
-        table.set_row_spacings(6)
-        table.set_col_spacings(6)
+        grid = Gtk.Grid()
+        grid.set_row_spacing(6)
+        grid.set_column_spacing(6)
 
         self.from_entry = Gtk.Entry()
-        table.attach(self.from_entry, 1, 2, 0, 1, yoptions=0)
-        
+        self.from_entry.set_hexpand(True)
+        grid.attach(self.from_entry, 1, 0, 1, 1)
+
         from_label = Gtk.Label(label=_('_Replace:'))
+        from_label.set_halign(Gtk.Align.START)
         from_label.set_use_underline(True)
-        from_label.set_alignment(0, 0.5)
         from_label.set_mnemonic_widget(self.from_entry)
-        table.attach(from_label, 0, 1, 0, 1, xoptions=0, yoptions=0)
+        grid.attach(from_label, 0, 0, 1, 1)
 
         self.to_entry = Gtk.Entry()
-        table.attach(self.to_entry, 1, 2, 1, 2, yoptions=0)
+        self.to_entry.set_hexpand(True)
+        grid.attach(self.to_entry, 1, 1, 1, 1)
 
         to_label = Gtk.Label(label=_('_With:'))
+        to_label.set_halign(Gtk.Align.START)
         to_label.set_use_underline(True)
-        to_label.set_alignment(0, 0.5)
         to_label.set_mnemonic_widget(self.to_entry)
-        table.attach(to_label, 0, 1, 1, 2, xoptions=0, yoptions=0)
+        grid.attach(to_label, 0, 1, 1, 1)
 
-        box.add(table)
+        box.add(grid)
 
         return (title, box)
 
     def build_confirm_text(self):
-        from_text = cuni(self.from_entry.get_text())
-        to_text = cuni(self.to_entry.get_text())
+        from_text = str(self.from_entry.get_text())
+        to_text = str(self.to_entry.get_text())
         text = _(
             'The following action is to be performed:\n\n'
             'Operation:\t%(title)s\n'
             'Replace:\t\t%(src_fname)s\n'
             'With:\t\t%(dest_fname)s') % {
-            'title' : self.title.replace('_',''), 
-            'src_fname' : from_text, 
+            'title' : self.title.replace('_',''),
+            'src_fname' : from_text,
             'dest_fname' : to_text }
         return text
-        
+
     def _prepare(self):
-        from_text = cuni(self.from_entry.get_text())
-        self.set_total(self.db.get_number_of_media_objects())
+        from_text = str(self.from_entry.get_text())
+        self.set_total(self.db.get_number_of_media())
         with self.db.get_media_cursor() as cursor:
             for handle, data in cursor:
-                obj = MediaObject()
+                obj = Media()
                 obj.unserialize(data)
                 if obj.get_path().find(from_text) != -1:
                     self.handle_list.append(handle)
@@ -542,13 +556,13 @@ class PathChange(BatchOp):
         if not self.prepared:
             self.prepare()
         self.set_total(len(self.handle_list))
-        from_text = cuni(self.from_entry.get_text())
-        to_text = cuni(self.to_entry.get_text())
+        from_text = str(self.from_entry.get_text())
+        to_text = str(self.to_entry.get_text())
         for handle in self.handle_list:
-            obj = self.db.get_object_from_handle(handle)
+            obj = self.db.get_media_from_handle(handle)
             new_path = obj.get_path().replace(from_text, to_text)
             obj.set_path(new_path)
-            self.db.commit_media_object(obj, self.trans)
+            self.db.commit_media(obj, self.trans)
             self.update()
         return True
 
@@ -563,10 +577,10 @@ class Convert2Abs(BatchOp):
                     "that is not set, it prepends user's directory.")
 
     def _prepare(self):
-        self.set_total(self.db.get_number_of_media_objects())
+        self.set_total(self.db.get_number_of_media())
         with self.db.get_media_cursor() as cursor:
             for handle, data in cursor:
-                obj = MediaObject()
+                obj = Media()
                 obj.unserialize(data)
                 if not os.path.isabs(obj.path):
                     self.handle_list.append(handle)
@@ -579,10 +593,10 @@ class Convert2Abs(BatchOp):
             self.prepare()
         self.set_total(len(self.handle_list))
         for handle in self.handle_list:
-            obj = self.db.get_object_from_handle(handle)
+            obj = self.db.get_media_from_handle(handle)
             new_path = media_path_full(self.db, obj.path)
             obj.set_path(new_path)
-            self.db.commit_media_object(obj, self.trans)
+            self.db.commit_media(obj, self.trans)
             self.update()
         return True
 
@@ -599,10 +613,10 @@ class Convert2Rel(BatchOp):
                     "a base path that can change to your needs.")
 
     def _prepare(self):
-        self.set_total(self.db.get_number_of_media_objects())
+        self.set_total(self.db.get_number_of_media())
         with self.db.get_media_cursor() as cursor:
             for handle, data in cursor:
-                obj = MediaObject()
+                obj = Media()
                 obj.unserialize(data)
                 if os.path.isabs(obj.path):
                     self.handle_list.append(handle)
@@ -616,10 +630,10 @@ class Convert2Rel(BatchOp):
         self.set_total(len(self.handle_list))
         base_dir = media_path(self.db)
         for handle in self.handle_list:
-            obj = self.db.get_object_from_handle(handle)
+            obj = self.db.get_media_from_handle(handle)
             new_path = relative_path(obj.path, base_dir)
             obj.set_path(new_path)
-            self.db.commit_media_object(obj, self.trans)
+            self.db.commit_media(obj, self.trans)
             self.update()
         return True
 
@@ -638,10 +652,10 @@ class ImagesNotIncluded(BatchOp):
         objects in the database.
         """
         self.dir_list = set()
-        self.set_total(self.db.get_number_of_media_objects())
+        self.set_total(self.db.get_number_of_media())
         with self.db.get_media_cursor() as cursor:
             for handle, data in cursor:
-                obj = MediaObject()
+                obj = Media()
                 obj.unserialize(data)
                 self.handle_list.append(handle)
                 full_path = media_path_full(self.db, obj.path)
@@ -680,18 +694,18 @@ class ImagesNotIncluded(BatchOp):
                         self.path_list.append(media_full_path)
                         mime_type = get_type(media_full_path)
                         if is_image_type(mime_type):
-                            obj = MediaObject()
+                            obj = Media()
                             obj.set_path(media_full_path)
                             obj.set_mime_type(mime_type)
                             (root, ext) = os.path.splitext(filename)
                             obj.set_description(root)
-                            self.db.add_object(obj, self.trans)
+                            self.db.add_media(obj, self.trans)
             self.update()
         return True
 
 #------------------------------------------------------------------------
 #
-# 
+#
 #
 #------------------------------------------------------------------------
 class MediaManOptions(tool.ToolOptions):
