@@ -33,15 +33,16 @@ from gi.repository import GObject
 
 #------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
 #------------------------------------------------------------------------
 from gramps.gen.const import GRAMPS_LOCALE as glocale
 _ = glocale.translation.sgettext
 ngettext = glocale.translation.ngettext # else "nearby" comments are ignored
 from gramps.gen.const import URL_MANUAL_PAGE
+from gramps.gen.errors import WindowActiveError
 from gramps.gui.plug import tool
-from gramps.gen.plug.report import utils as ReportUtils
+from gramps.gen.plug.report import utils
 from gramps.gui.editors import EditPerson, EditFamily
 from gramps.gui.managedwindow import ManagedWindow
 from gramps.gui.utils import ProgressMeter
@@ -81,9 +82,9 @@ class NotRelated(tool.ActivePersonTool, ManagedWindow) :
         self.dbstate = dbstate
         self.uistate = uistate
         self.db = dbstate.db
-        
+
         topDialog = Glade()
-        
+
         topDialog.connect_signals({
             "destroy_passed_object" : self.close,
             "on_help_clicked"       : self.on_help_clicked,
@@ -93,6 +94,7 @@ class NotRelated(tool.ActivePersonTool, ManagedWindow) :
         window = topDialog.toplevel
         title = topDialog.get_object("title")
         self.set_window(window, title, self.title)
+        self.setup_configs('interface.notrelated', 450, 400)
 
         self.tagcombo = topDialog.get_object("tagcombo")
         tagmodel = Gtk.ListStore(str)
@@ -107,8 +109,8 @@ class NotRelated(tool.ActivePersonTool, ManagedWindow) :
         self.tagapply.connect('clicked', self.applyTagClicked)
 
         # start the progress indicator
-        self.progress = ProgressMeter(self.title,_('Starting'),
-                                      parent=self.window)
+        self.progress = ProgressMeter(self.title, _('Starting'),
+                                      parent=self.uistate.window)
 
         # setup the columns
         self.model = Gtk.TreeStore(
@@ -228,8 +230,8 @@ class NotRelated(tool.ActivePersonTool, ManagedWindow) :
                     pass
 
     def on_help_clicked(self, obj):
-        """Display the relevant portion of GRAMPS manual"""
-        display_help(WIKI_HELP_PAGE , WIKI_HELP_SEC)    
+        """Display the relevant portion of Gramps manual"""
+        display_help(WIKI_HELP_PAGE , WIKI_HELP_SEC)
 
 
     def applyTagClicked(self, button) :
@@ -252,24 +254,24 @@ class NotRelated(tool.ActivePersonTool, ManagedWindow) :
 
             # if more than 1 person is selected, use a progress indicator
             if rows > 1:
-                progress = ProgressMeter(self.title,_('Starting'),
+                progress = ProgressMeter(self.title, _('Starting'),
                                          parent=self.window)
                 progress.set_pass(
                     # translators: leave all/any {...} untranslated
                     #TRANS: no singular form needed, as rows is always > 1
                     ngettext("Setting tag for {number_of} person",
-                             "Setting tag for {number_of} people", 
+                             "Setting tag for {number_of} people",
                              rows).format(number_of=rows),
                     rows)
 
-    
+
             # iterate through all of the selected rows
             (model, paths) = self.treeSelection.get_selected_rows()
 
             for path in paths:
                 if progress:
                     progress.step()
-    
+
                 # for the current row, get the GID and the person from the database
                 iter        = self.model.get_iter(path)
                 personGid   = self.model.get_value(iter, 1)
@@ -332,7 +334,7 @@ class NotRelated(tool.ActivePersonTool, ManagedWindow) :
             # step 1 -- spouses
             for familyHandle in person.get_family_handle_list():
                 family = self.db.get_family_from_handle(familyHandle)
-                spouseHandle = ReportUtils.find_spouse(person, family)
+                spouseHandle = utils.find_spouse(person, family)
                 if spouseHandle and \
                   spouseHandle not in self.handlesOfPeopleAlreadyProcessed:
                     self.handlesOfPeopleToBeProcessed.add(spouseHandle)
@@ -475,13 +477,14 @@ class NotRelated(tool.ActivePersonTool, ManagedWindow) :
 
     def get_tag_list(self, person):
         """
-        Return a sorted list of tag names for the given person. 
+        Return a sorted list of tag names for the given person.
         """
         tags = []
         for handle in person.get_tag_list():
             tag = self.db.get_tag_from_handle(handle)
             tags.append(tag.get_name())
         tags.sort(key=glocale.sort_key)
+        # TODO for Arabic, should the next line's comma be translated?
         return ', '.join(tags)
 
 #------------------------------------------------------------------------
