@@ -27,9 +27,6 @@ Relationship View
 # Python modules
 #
 #-------------------------------------------------------------------------
-from gramps.gen.const import GRAMPS_LOCALE as glocale
-_ = glocale.translation.sgettext
-ngettext = glocale.translation.ngettext # else "nearby" comments are ignored
 from html import escape
 import pickle
 
@@ -55,7 +52,10 @@ from gi.repository import Pango
 # Gramps Modules
 #
 #-------------------------------------------------------------------------
-from gramps.gen.lib import (ChildRef, EventRoleType, EventType, Family, 
+from gramps.gen.const import GRAMPS_LOCALE as glocale
+_ = glocale.translation.sgettext
+ngettext = glocale.translation.ngettext # else "nearby" comments are ignored
+from gramps.gen.lib import (ChildRef, EventRoleType, EventType, Family,
                             FamilyRelType, Name, Person, Surname)
 from gramps.gen.lib.date import Today
 from gramps.gen.db import DbTxn
@@ -69,7 +69,7 @@ from gramps.gen.utils.file import media_path_full
 from gramps.gen.utils.alive import probably_alive
 from gramps.gui.utils import open_file_with_default_application
 from gramps.gen.datehandler import displayer, get_date
-from gramps.gui.thumbnails import get_thumbnail_image
+from gramps.gen.utils.thumbnails import get_thumbnail_image
 from gramps.gen.config import config
 from gramps.gui import widgets
 from gramps.gui.widgets.reorderfam import Reorder
@@ -77,14 +77,14 @@ from gramps.gui.selectors import SelectorFactory
 from gramps.gen.errors import WindowActiveError
 from gramps.gui.views.bookmarks import PersonBookmarks
 from gramps.gen.const import CUSTOM_FILTERS
-from gramps.gen.utils.db import (get_birth_or_fallback, get_death_or_fallback, 
+from gramps.gen.utils.db import (get_birth_or_fallback, get_death_or_fallback,
                           preset_name)
 from gramps.gui.ddtargets import DdTargets
 
 _GenderCode = {
-    Person.MALE    : '\u2642', 
-    Person.FEMALE  : '\u2640', 
-    Person.UNKNOWN : '\u2650', 
+    Person.MALE    : '\u2642',
+    Person.FEMALE  : '\u2640',
+    Person.UNKNOWN : '\u2650',
     }
 
 _NAME_START   = 0
@@ -94,7 +94,7 @@ _DATA_START   = _LABEL_STOP
 _DATA_STOP    = _DATA_START+1
 _BTN_START    = _DATA_STOP
 _BTN_STOP     = _BTN_START+2
-_PLABEL_START = 1 
+_PLABEL_START = 1
 _PLABEL_STOP  = _PLABEL_START+1
 _PDATA_START  = _PLABEL_STOP
 _PDATA_STOP   = _PDATA_START+2
@@ -120,7 +120,7 @@ _RIGHT_BUTTON = 3
 
 class RelationshipView(NavigationView):
     """
-    View showing a textual representation of the relationships of the 
+    View showing a textual representation of the relationships of the
     active person
     """
     #settings in the config file
@@ -134,9 +134,9 @@ class RelationshipView(NavigationView):
 
     def __init__(self, pdata, dbstate, uistate, nav_group=0):
         NavigationView.__init__(self, _('Relationships'),
-                                      pdata, dbstate, uistate, 
+                                      pdata, dbstate, uistate,
                                       PersonBookmarks,
-                                      nav_group)        
+                                      nav_group)
 
         self.func_list.update({
             '<PRIMARY>J' : self.jump,
@@ -144,6 +144,7 @@ class RelationshipView(NavigationView):
 
         dbstate.connect('database-changed', self.change_db)
         uistate.connect('nameformat-changed', self.build_tree)
+        uistate.connect('placeformat-changed', self.build_tree)
         self.redrawing = False
 
         self.child = None
@@ -160,6 +161,16 @@ class RelationshipView(NavigationView):
         self.theme = self._config.get('preferences.relation-display-theme')
         self.toolbar_visible = config.get('interface.toolbar-on')
 
+    def get_handle_from_gramps_id(self, gid):
+        """
+        returns the handle of the specified object
+        """
+        obj = self.dbstate.db.get_person_from_gramps_id(gid)
+        if obj:
+            return obj.get_handle()
+        else:
+            return None
+
     def _connect_db_signals(self):
         """
         implement from base class DbGUIElement
@@ -182,7 +193,7 @@ class RelationshipView(NavigationView):
 
     def can_configure(self):
         """
-        See :class:`~gui.views.pageview.PageView 
+        See :class:`~gui.views.pageview.PageView
         :return: bool
         """
         return True
@@ -275,7 +286,7 @@ class RelationshipView(NavigationView):
     def change_page(self):
         NavigationView.change_page(self)
         self.uistate.clear_filter_results()
-            
+
     def get_stock(self):
         """
         Return the name of the stock icon to use for the display.
@@ -283,7 +294,7 @@ class RelationshipView(NavigationView):
         GNOME as a stock icon.
         """
         return 'gramps-relation'
-    
+
     def get_viewtype_stock(self):
         """Type of view in category
         """
@@ -291,8 +302,8 @@ class RelationshipView(NavigationView):
 
     def build_widget(self):
         """
-        Build the widget that contains the view, see 
-        :class:`~gui.views.pageview.PageView 
+        Build the widget that contains the view, see
+        :class:`~gui.views.pageview.PageView
         """
         container = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
         container.set_border_width(12)
@@ -309,7 +320,7 @@ class RelationshipView(NavigationView):
         self.scroll.set_policy(Gtk.PolicyType.AUTOMATIC,
                                Gtk.PolicyType.AUTOMATIC)
         self.scroll.show()
-        
+
         vp = Gtk.Viewport()
         vp.set_shadow_type(Gtk.ShadowType.NONE)
         vp.add(self.vbox)
@@ -359,8 +370,8 @@ class RelationshipView(NavigationView):
           </menubar>
           <toolbar name="ToolBar">
             <placeholder name="CommonNavigation">
-              <toolitem action="Back"/>  
-              <toolitem action="Forward"/>  
+              <toolitem action="Back"/>
+              <toolitem action="Forward"/>
               <toolitem action="HomePerson"/>
             </placeholder>
             <placeholder name="CommonEdit">
@@ -398,20 +409,20 @@ class RelationshipView(NavigationView):
                 _("Add a new family with person as parent"), self.add_spouse),
             ('AddParents', 'gramps-parents-add', _('Add'), None ,
                 _("Add a new set of parents"), self.add_parents),
-            ('AddParentsMenu', 'gramps-parents-add', _('Add New Parents...'), 
+            ('AddParentsMenu', 'gramps-parents-add', _('Add New Parents...'),
                 None, _("Add a new set of parents"), self.add_parents),
-            ('ShareFamily', 'gramps-parents-open', _('Share'), 
-                None , _("Add person as child to an existing family"), 
+            ('ShareFamily', 'gramps-parents-open', _('Share'),
+                None , _("Add person as child to an existing family"),
                 self.select_parents),
-            ('ShareFamilyMenu', 'gramps-parents-open', 
-                _('Add Existing Parents...'), None , 
-                _("Add person as child to an existing family"), 
+            ('ShareFamilyMenu', 'gramps-parents-open',
+                _('Add Existing Parents...'), None ,
+                _("Add person as child to an existing family"),
                 self.select_parents),
             ])
-            
-        self._add_action('FilterEdit',  None, _('Person Filter Editor'), 
+
+        self._add_action('FilterEdit',  None, _('Person Filter Editor'),
                         callback=self.filter_editor)
-                        
+
         self._add_action_group(self.order_action)
         self._add_action_group(self.family_action)
 
@@ -420,7 +431,7 @@ class RelationshipView(NavigationView):
 
     def filter_editor(self, obj):
         try:
-            FilterEditor('Person', CUSTOM_FILTERS, 
+            FilterEditor('Person', CUSTOM_FILTERS,
                          self.dbstate, self.uistate)
         except WindowActiveError:
             return
@@ -454,7 +465,7 @@ class RelationshipView(NavigationView):
             self.change_person(active_person)
         else:
             self.change_person(None)
-        
+
     def change_person(self, obj):
         self.change_active(obj)
         try:
@@ -464,7 +475,8 @@ class RelationshipView(NavigationView):
             exc = traceback.format_exc()
             _LOG.error(str(msg) +"\n" + exc)
             from gramps.gui.dialog import RunDatabaseRepair
-            RunDatabaseRepair(str(msg))
+            RunDatabaseRepair(str(msg),
+                              parent=self.uistate.window)
             self.redrawing = False
             return True
 
@@ -488,7 +500,9 @@ class RelationshipView(NavigationView):
         for old_child in self.header.get_children():
             self.header.remove(old_child)
 
-        person = self.dbstate.db.get_person_from_handle(obj)
+        person = None
+        if obj:
+            person = self.dbstate.db.get_person_from_handle(obj)
         if not person:
             self.family_action.set_sensitive(False)
             self.order_action.set_sensitive(False)
@@ -513,11 +527,11 @@ class RelationshipView(NavigationView):
                 if family_handle:
                     self.write_parents(family_handle, person)
         else:
-            self.write_label("%s:" % _('Parents'), None, True, person)
+            self.write_label(_("%s:") % _('Parents'), None, True, person)
             self.row += 1
-                
+
         family_handle_list = person.get_family_handle_list()
-        
+
         if not self.reorder_sensitive:
             self.reorder_sensitive = len(family_handle_list)> 1
 
@@ -553,9 +567,9 @@ class RelationshipView(NavigationView):
         label = widgets.DualMarkupLabel(text, _GenderCode[person.gender],
                                         halign=Gtk.Align.END)
         if self._config.get('preferences.releditbtn'):
-            button = widgets.IconButton(self.edit_button_press, 
+            button = widgets.IconButton(self.edit_button_press,
                                         person.handle)
-            button.set_tooltip_text(_('Edit %s') % name)
+            button.set_tooltip_text(_('Edit Person (%s)') % name)
         else:
             button = None
         eventbox = Gtk.EventBox()
@@ -573,9 +587,9 @@ class RelationshipView(NavigationView):
         subgrid.set_row_spacing(0)
         eventbox.add(subgrid)
         self._set_draggable_person(eventbox, person.get_handle())
-        # GRAMPS ID
+        # Gramps ID
 
-        subgrid.attach(widgets.BasicLabel("%s:" % _('ID')), 1, 0, 1, 1)
+        subgrid.attach(widgets.BasicLabel(_("%s:") % _('ID')), 1, 0, 1, 1)
         label = widgets.BasicLabel(person.gramps_id)
         label.set_hexpand(True)
         subgrid.attach(label, 2, 0, 1, 1)
@@ -587,8 +601,10 @@ class RelationshipView(NavigationView):
         else:
             birth_title = _("Birth")
 
-        subgrid.attach(widgets.BasicLabel("%s:" % birth_title), 1, 1, 1, 1)
-        subgrid.attach(widgets.BasicLabel(self.format_event(birth)), 2, 1, 1, 1)
+        subgrid.attach(widgets.BasicLabel(_("%s:") % birth_title), 1, 1, 1, 1)
+        birthwidget = widgets.BasicLabel(self.format_event(birth))
+        birthwidget.set_selectable(True)
+        subgrid.attach(birthwidget, 2, 1, 1, 1)
 
         death = get_death_or_fallback(self.dbstate.db, person)
         if death:
@@ -604,32 +620,36 @@ class RelationshipView(NavigationView):
                     death_date = death.get_date_object()
                     if (death_date and death_date.get_valid()):
                         age = death_date - birth_date
-                        subgrid.attach(widgets.BasicLabel("%s:" % death_title),
+                        subgrid.attach(widgets.BasicLabel(_("%s:") % death_title),
                                       1, 2, 1, 1)
-                        subgrid.attach(widgets.BasicLabel("%s (%s)" % 
+                        deathwidget = widgets.BasicLabel("%s (%s)" %
                                                          (self.format_event(death), age),
-                                                         Pango.EllipsizeMode.END),
+                                                         Pango.EllipsizeMode.END)
+                        deathwidget.set_selectable(True)
+                        subgrid.attach(deathwidget,
                                       2, 2, 1, 1)
                         showed_death = True
                 if not showed_death:
                     age = Today() - birth_date
                     if probably_alive(person, self.dbstate.db):
-                        subgrid.attach(widgets.BasicLabel("%s:" % _("Alive")),
+                        subgrid.attach(widgets.BasicLabel(_("%s:") % _("Alive")),
                                       1, 2, 1, 1)
                         subgrid.attach(widgets.BasicLabel("(%s)" % age, Pango.EllipsizeMode.END),
                                       2, 2, 1, 1)
                     else:
-                        subgrid.attach(widgets.BasicLabel("%s:" % _("Death")),
+                        subgrid.attach(widgets.BasicLabel(_("%s:") % _("Death")),
                                       1, 2, 1, 1)
-                        subgrid.attach(widgets.BasicLabel("%s (%s)" % (_("unknown"), age), 
+                        subgrid.attach(widgets.BasicLabel("%s (%s)" % (_("unknown"), age),
                                                          Pango.EllipsizeMode.END),
                                       2, 2, 1, 1)
                     showed_death = True
 
         if not showed_death:
-            subgrid.attach(widgets.BasicLabel("%s:" % death_title),
+            subgrid.attach(widgets.BasicLabel(_("%s:") % death_title),
                           1, 2, 1, 1)
-            subgrid.attach(widgets.BasicLabel(self.format_event(death)),
+            deathwidget = widgets.BasicLabel(self.format_event(death))
+            deathwidget.set_selectable(True)
+            subgrid.attach(deathwidget,
                           2, 2, 1, 1)
 
         mbox = Gtk.Box()
@@ -638,10 +658,10 @@ class RelationshipView(NavigationView):
         # image
         image_list = person.get_media_list()
         if image_list:
-            mobj = self.dbstate.db.get_object_from_handle(image_list[0].ref)
+            mobj = self.dbstate.db.get_media_from_handle(image_list[0].ref)
             if mobj and mobj.get_mime_type()[0:5] == "image":
                 pixbuf = get_thumbnail_image(
-                                media_path_full(self.dbstate.db, 
+                                media_path_full(self.dbstate.db,
                                                 mobj.get_path()),
                                 rectangle=image_list[0].get_rectangle())
                 image = Gtk.Image()
@@ -659,7 +679,7 @@ class RelationshipView(NavigationView):
         Open this picture in the default picture viewer.
         """
         photo_path = media_path_full(self.dbstate.db, photo.get_path())
-        open_file_with_default_application(photo_path)
+        open_file_with_default_application(photo_path, self.uistate)
 
     def write_person_event(self, ename, event):
         if event:
@@ -671,8 +691,8 @@ class RelationshipView(NavigationView):
                 pname = None
 
             value = {
-                'date' : displayer.display(dobj), 
-                'place' : pname, 
+                'date' : displayer.display(dobj),
+                'place' : pname,
                 }
         else:
             pname = None
@@ -680,7 +700,7 @@ class RelationshipView(NavigationView):
 
         if dobj:
             if pname:
-                self.write_person_data(ename, 
+                self.write_person_data(ename,
                                        _('%(date)s in %(place)s') % value)
             else:
                 self.write_person_data(ename, '%(date)s' % value)
@@ -699,8 +719,8 @@ class RelationshipView(NavigationView):
                 pname = None
 
             value = {
-                'date' : displayer.display(dobj), 
-                'place' : pname, 
+                'date' : displayer.display(dobj),
+                'place' : pname,
                 }
         else:
             pname = None
@@ -743,7 +763,7 @@ class RelationshipView(NavigationView):
                                                     self.expand_collapse_press,
                                                     (person, family.handle))
         else :
-            arrow = Gtk.Arrow(arrow_type=Gtk.ArrowType.RIGHT, 
+            arrow = Gtk.Arrow(arrow_type=Gtk.ArrowType.RIGHT,
                                         shadow_type=Gtk.ShadowType.OUT)
         hbox.pack_start(arrow, False, True, 0)
         hbox.pack_start(label, True, True, 0)
@@ -790,10 +810,10 @@ class RelationshipView(NavigationView):
                 call_fcn = self.add_family
                 del_fcn = self.delete_family
 
-            if not self.toolbar_visible and not self.dbstate.db.readonly:
-                # Show edit-Buttons if toolbar is not visible
+            if not self.dbstate.db.readonly:
+                # Show edit-Buttons only if db is not readonly
                 if self.reorder_sensitive:
-                    add = widgets.IconButton(self.reorder_button_press, None, 
+                    add = widgets.IconButton(self.reorder_button_press, None,
                                              'view-sort-ascending')
                     add.set_tooltip_text(ord_msg)
                     hbox.pack_start(add, False, True, 0)
@@ -809,12 +829,12 @@ class RelationshipView(NavigationView):
                     hbox.pack_start(add, False, True, 0)
 
             if family:
-                edit = widgets.IconButton(self.edit_family, family.handle, 
+                edit = widgets.IconButton(self.edit_family, family.handle,
                                           'gtk-edit')
                 edit.set_tooltip_text(edit_msg)
                 hbox.pack_start(edit, False, True, 0)
                 if not self.dbstate.db.readonly:
-                    delete = widgets.IconButton(del_fcn, family.handle, 
+                    delete = widgets.IconButton(del_fcn, family.handle,
                                                 'list-remove')
                     delete.set_tooltip_text(del_msg)
                     hbox.pack_start(delete, False, True, 0)
@@ -826,7 +846,7 @@ class RelationshipView(NavigationView):
             self.child.attach(eventbox, _BTN_START, self.row,
                               _BTN_STOP-_BTN_START, 1)
         self.row += 1
-        
+
 ######################################################################
 
     def write_parents(self, family_handle, person = None):
@@ -835,7 +855,7 @@ class RelationshipView(NavigationView):
             return
         if person and self.check_collapsed(person.handle, family_handle):
             # don't show rest
-            self.write_label("%s:" % _('Parents'), family, True, person)
+            self.write_label(_("%s:") % _('Parents'), family, True, person)
             self.row -= 1 # back up one row for summary names
             active = self.get_active()
             child_list = [ref.ref for ref in family.get_child_ref_list()
@@ -869,7 +889,7 @@ class RelationshipView(NavigationView):
                                _PDATA_STOP-_PDATA_START, 1)
             self.row += 1 # now advance it
         else:
-            self.write_label("%s:" % _('Parents'), family, True, person)
+            self.write_label(_("%s:") % _('Parents'), family, True, person)
             self.write_person(_('Father'), family.get_father_handle())
             self.write_person(_('Mother'), family.get_mother_handle())
 
@@ -922,12 +942,12 @@ class RelationshipView(NavigationView):
                     self.row += 1 # now advance it
                 else:
                     hbox = Gtk.Box()
-                    addchild = widgets.IconButton(self.add_child_to_fam, 
-                                                  family.handle, 
+                    addchild = widgets.IconButton(self.add_child_to_fam,
+                                                  family.handle,
                                                   'list-add')
                     addchild.set_tooltip_text(_('Add new child to family'))
-                    selchild = widgets.IconButton(self.sel_child_to_fam, 
-                                                  family.handle, 
+                    selchild = widgets.IconButton(self.sel_child_to_fam,
+                                                  family.handle,
                                                   'gtk-index')
                     selchild.set_tooltip_text(_('Add existing child to family'))
                     hbox.pack_start(addchild, False, True, 0)
@@ -961,12 +981,12 @@ class RelationshipView(NavigationView):
             initial_name = False
             if handle:
                 name = self.get_name(handle, True)
-                link_label = widgets.LinkLabel(name, self._button_press, 
+                link_label = widgets.LinkLabel(name, self._button_press,
                                                handle, theme=self.theme)
                 if self._config.get('preferences.releditbtn'):
-                    button = widgets.IconButton(self.edit_button_press, 
+                    button = widgets.IconButton(self.edit_button_press,
                                                 handle)
-                    button.set_tooltip_text(_('Edit %s') % name[0])
+                    button.set_tooltip_text(_('Edit Person (%s)') % name[0])
                 else:
                     button = None
                 hbox.pack_start(widgets.LinkBox(link_label, button),
@@ -1017,11 +1037,11 @@ class RelationshipView(NavigationView):
                 emph = True
             else:
                 emph = False
-            link_label = widgets.LinkLabel(name, self._button_press, 
+            link_label = widgets.LinkLabel(name, self._button_press,
                                            handle, emph, theme=self.theme)
             if self._config.get('preferences.releditbtn'):
                 button = widgets.IconButton(self.edit_button_press, handle)
-                button.set_tooltip_text(_('Edit %s') % name[0])
+                button.set_tooltip_text(_('Edit Person (%s)') % name[0])
             else:
                 button = None
             vbox.pack_start(widgets.LinkBox(link_label, button), True, True, 0)
@@ -1031,14 +1051,14 @@ class RelationshipView(NavigationView):
             link_label.set_halign(Gtk.Align.START)
             link_label.show()
             vbox.pack_start(link_label, True, True, 0)
-            
-        if self.show_details:
+
+        if self.show_details and handle:
             value = self.info_string(handle)
             if value:
                 vbox.pack_start(widgets.MarkupLabel(value), True, True, 0)
 
         eventbox.add(vbox)
-        
+
         self.child.attach(eventbox, _PDATA_START, self.row,
                           _PDATA_STOP-_PDATA_START, 1)
         self.row += 1
@@ -1113,7 +1133,7 @@ class RelationshipView(NavigationView):
             original_vbox.pack_start(frame, True, True, 0)
         else:
             original_vbox.pack_start(ev, True, True, 0)
-        
+
         parent = has_children(self.dbstate.db,
                               self.dbstate.db.get_person_from_handle(handle))
 
@@ -1140,7 +1160,7 @@ class RelationshipView(NavigationView):
         if child_should_be_linked and self._config.get(
             'preferences.releditbtn'):
             button = widgets.IconButton(self.edit_button_press, handle)
-            button.set_tooltip_text(_('Edit %s') % name[0])
+            button.set_tooltip_text(_('Edit Person (%s)') % name[0])
         else:
             button = None
 
@@ -1162,8 +1182,10 @@ class RelationshipView(NavigationView):
                 vbox.add(l)
 
     def write_data(self, box, title, start_col=_SDATA_START,
-                   stop_col=_SDATA_STOP):
-        box.add(widgets.BasicLabel(title))
+                   stop_col=_SDATA_STOP, selectable=False):
+        label=widgets.BasicLabel(title)
+        label.set_selectable(selectable)
+        box.add(label)
 
     def info_string(self, handle):
         person = self.dbstate.db.get_person_from_handle(handle)
@@ -1198,7 +1220,7 @@ class RelationshipView(NavigationView):
             value = _("%(birthabbrev)s %(birthdate)s, %(deathabbrev)s %(deathdate)s") % {
                 'birthabbrev': birth.type.get_abbreviation(),
                 'deathabbrev': death.type.get_abbreviation(),
-                'birthdate' : bdate, 
+                'birthdate' : bdate,
                 'deathdate' : ddate
                 }
         elif bdate:
@@ -1235,22 +1257,20 @@ class RelationshipView(NavigationView):
         if button_activated(event, _LEFT_BUTTON):
             self.change_active(handle)
         elif button_activated(event, _RIGHT_BUTTON):
-            self.myMenu = Gtk.Menu()
-            self.myMenu.append(self.build_menu_item(handle))
-            self.myMenu.popup(None, None, None, None, event.button, event.time)
+            self.my_menu = Gtk.Menu()
+            self.my_menu.set_reserve_toggle_size(False)
+            self.my_menu.append(self.build_menu_item(handle))
+            self.my_menu.popup(None, None, None, None, event.button, event.time)
 
     def build_menu_item(self, handle):
         person = self.dbstate.db.get_person_from_handle(handle)
         name = name_displayer.display(person)
 
-        item = Gtk.ImageMenuItem(None)
-        image = Gtk.Image.new_from_icon_name('gtk-edit', Gtk.IconSize.MENU)
-        image.show()
-        label = Gtk.Label(label=_("Edit %s") % name)
+        item = Gtk.MenuItem()
+        label = Gtk.Label(label=_("Edit Person (%s)") % name)
         label.show()
         label.set_halign(Gtk.Align.START)
 
-        item.set_image(image)
         item.add(label)
 
         item.connect('activate', self.edit_menu, handle)
@@ -1274,13 +1294,13 @@ class RelationshipView(NavigationView):
             handle = event_ref.ref
             event = self.dbstate.db.get_event_from_handle(handle)
             if (event and event.get_type().is_relationship_event() and
-                (event_ref.get_role() == EventRoleType.FAMILY or 
+                (event_ref.get_role() == EventRoleType.FAMILY or
                  event_ref.get_role() == EventRoleType.PRIMARY)):
                 self.write_event_ref(vbox, event.get_type().string, event)
                 value = True
         return value
 
-    def write_event_ref(self, vbox, ename, event, start_col=_SDATA_START, 
+    def write_event_ref(self, vbox, ename, event, start_col=_SDATA_START,
                         stop_col=_SDATA_STOP):
         if event:
             dobj = event.get_date_object()
@@ -1291,9 +1311,9 @@ class RelationshipView(NavigationView):
                 pname = None
 
             value = {
-                'date' : displayer.display(dobj), 
-                'place' : pname, 
-                'event_type' : ename, 
+                'date' : displayer.display(dobj),
+                'place' : pname,
+                'event_type' : ename,
                 }
         else:
             pname = None
@@ -1304,10 +1324,10 @@ class RelationshipView(NavigationView):
             if pname:
                 self.write_data(
                     vbox, _('%(event_type)s: %(date)s in %(place)s') %
-                    value, start_col, stop_col)
+                    value, start_col, stop_col, True)
             else:
                 self.write_data(
-                    vbox, _('%(event_type)s: %(date)s') % value, 
+                    vbox, _('%(event_type)s: %(date)s') % value,
                     start_col, stop_col)
         elif pname:
             self.write_data(
@@ -1326,7 +1346,7 @@ class RelationshipView(NavigationView):
                 _('Please run the Check and Repair Database tool'),
                 parent=self.uistate.window)
             return
-        
+
         father_handle = family.get_father_handle()
         mother_handle = family.get_mother_handle()
         if self.get_active() == father_handle:
@@ -1337,7 +1357,7 @@ class RelationshipView(NavigationView):
         # collapse button
         if self.check_collapsed(person.handle, family_handle):
             # show "> Family: ..." and nothing else
-            self.write_label("%s:" % _('Family'), family, False, person)
+            self.write_label(_("%s:") % _('Family'), family, False, person)
             self.row -= 1 # back up
             child_list = family.get_child_ref_list()
             if child_list:
@@ -1359,7 +1379,7 @@ class RelationshipView(NavigationView):
             self.row += 1 # now advance it
         else:
             # show "V Family: ..." and the rest
-            self.write_label("%s:" % _('Family'), family, False, person)
+            self.write_label(_("%s:") % _('Family'), family, False, person)
             if (handle or
                     family.get_relationship() != FamilyRelType.UNKNOWN):
                 box = self.write_person(_('Spouse'), handle)
@@ -1404,14 +1424,14 @@ class RelationshipView(NavigationView):
                 self.row += 1 # now advance it
             else:
                 hbox = Gtk.Box()
-                addchild = widgets.IconButton(self.add_child_to_fam, 
-                                              family.handle, 
+                addchild = widgets.IconButton(self.add_child_to_fam,
+                                              family.handle,
                                               'list-add')
                 addchild.set_tooltip_text(_('Add new child to family'))
-                selchild = widgets.IconButton(self.sel_child_to_fam, 
-                                              family.handle, 
+                selchild = widgets.IconButton(self.sel_child_to_fam,
+                                              family.handle,
                                               'gtk-index')
-                selchild.set_tooltip_text(_('Add existing child to family'))                                  
+                selchild.set_tooltip_text(_('Add existing child to family'))
                 hbox.pack_start(addchild, False, True, 0)
                 hbox.pack_start(selchild, False, True, 0)
                 self.child.attach(hbox, _CLABEL_START, self.row,
@@ -1434,7 +1454,7 @@ class RelationshipView(NavigationView):
     def edit_button_press(self, obj, event, handle):
         if button_activated(event, _LEFT_BUTTON):
             self.edit_person(obj, handle)
-        
+
     def edit_person(self, obj, handle):
         person = self.dbstate.db.get_person_from_handle(handle)
         try:
@@ -1456,12 +1476,12 @@ class RelationshipView(NavigationView):
             person = self.dbstate.db.get_person_from_handle(self.get_active())
             if not person:
                 return
-            
+
             if person.gender == Person.MALE:
                 family.set_father_handle(person.handle)
             else:
                 family.set_mother_handle(person.handle)
-                
+
             try:
                 EditFamily(self.dbstate, self.uistate, [], family)
             except WindowActiveError:
@@ -1473,12 +1493,12 @@ class RelationshipView(NavigationView):
 
         if not person:
             return
-            
+
         if person.gender == Person.MALE:
             family.set_father_handle(person.handle)
         else:
             family.set_mother_handle(person.handle)
-                
+
         try:
             EditFamily(self.dbstate, self.uistate, [], family)
         except WindowActiveError:
@@ -1497,13 +1517,14 @@ class RelationshipView(NavigationView):
             name.add_surname(Surname())
             name.set_primary_surname(0)
             family = self.dbstate.db.get_family_from_handle(handle)
-            father = self.dbstate.db.get_person_from_handle(
-                                        family.get_father_handle())
-            if father:
-                preset_name(father, name)
+            father_h = family.get_father_handle()
+            if father_h:
+                father = self.dbstate.db.get_person_from_handle(father_h)
+                if father:
+                    preset_name(father, name)
             person.set_primary_name(name)
             try:
-                EditPerson(self.dbstate, self.uistate, [], person, 
+                EditPerson(self.dbstate, self.uistate, [], person,
                            callback=callback)
             except WindowActiveError:
                 pass
@@ -1513,7 +1534,7 @@ class RelationshipView(NavigationView):
         ref.ref = person.get_handle()
         family = self.dbstate.db.get_family_from_handle(family_handle)
         family.add_child_ref(ref)
-        
+
         with DbTxn(_("Add Child to Family"), self.dbstate.db) as trans:
             #add parentref to child
             person.add_parent_family_handle(family_handle)
@@ -1534,7 +1555,7 @@ class RelationshipView(NavigationView):
             sel = SelectPerson(self.dbstate, self.uistate, [],
                                _("Select Child"), skip=skip_list)
             person = sel.run()
-            
+
             if person:
                 self.callback_add_child(person, handle)
 
@@ -1545,7 +1566,7 @@ class RelationshipView(NavigationView):
             phandle = self.get_active()
             person = self.dbstate.db.get_person_from_handle(phandle)
             skip = set(person.get_family_handle_list())
-            
+
             dialog = SelectFamily(self.dbstate, self.uistate, skip=skip)
             family = dialog.run()
 
@@ -1561,13 +1582,13 @@ class RelationshipView(NavigationView):
         person = self.dbstate.db.get_person_from_handle(phandle)
         skip = set(person.get_family_handle_list()+
                    person.get_parent_family_handle_list())
-            
+
         dialog = SelectFamily(self.dbstate, self.uistate, skip=skip)
         family = dialog.run()
 
         if family:
             child = self.dbstate.db.get_person_from_handle(self.get_active())
-            
+
             self.dbstate.db.add_child_to_family(family, child)
 
     def add_parents(self, obj):
@@ -1580,12 +1601,12 @@ class RelationshipView(NavigationView):
         ref = ChildRef()
         ref.ref = person.handle
         family.add_child_ref(ref)
-        
+
         try:
             EditFamily(self.dbstate, self.uistate, [], family)
         except WindowActiveError:
             pass
-            
+
     def add_parent_family(self, obj, event, handle):
         if button_activated(event, _LEFT_BUTTON):
             family = Family()
@@ -1594,7 +1615,7 @@ class RelationshipView(NavigationView):
             ref = ChildRef()
             ref.ref = person.handle
             family.add_child_ref(ref)
-                
+
             try:
                 EditFamily(self.dbstate, self.uistate, [], family)
             except WindowActiveError:
@@ -1614,7 +1635,7 @@ class RelationshipView(NavigationView):
     def reorder_button_press(self, obj, event, handle):
         if button_activated(event, _LEFT_BUTTON):
             self.reorder(obj)
-            
+
     def reorder(self, obj, dumm1=None, dummy2=None):
         if self.get_active():
             try:
@@ -1650,11 +1671,11 @@ class RelationshipView(NavigationView):
         grid.set_column_spacing(6)
         grid.set_row_spacing(6)
 
-        configdialog.add_checkbox(grid, 
-                _('Use shading'), 
+        configdialog.add_checkbox(grid,
+                _('Use shading'),
                 0, 'preferences.relation-shade')
-        configdialog.add_checkbox(grid, 
-                _('Display edit buttons'), 
+        configdialog.add_checkbox(grid,
+                _('Display edit buttons'),
                 1, 'preferences.releditbtn')
         checkbox = Gtk.CheckButton(label=_('View links as website links'))
         theme = self._config.get('preferences.relation-display-theme')
@@ -1672,11 +1693,11 @@ class RelationshipView(NavigationView):
         grid.set_border_width(12)
         grid.set_column_spacing(6)
         grid.set_row_spacing(6)
-        configdialog.add_checkbox(grid, 
-                _('Show Details'), 
+        configdialog.add_checkbox(grid,
+                _('Show Details'),
                 0, 'preferences.family-details')
-        configdialog.add_checkbox(grid, 
-                _('Show Siblings'), 
+        configdialog.add_checkbox(grid,
+                _('Show Siblings'),
                 1, 'preferences.family-siblings')
 
         return _('Content'), grid
@@ -1687,18 +1708,18 @@ class RelationshipView(NavigationView):
         """
         if obj.get_active():
             self.theme = 'WEBPAGE'
-            self._config.set('preferences.relation-display-theme', 
+            self._config.set('preferences.relation-display-theme',
                               'WEBPAGE')
         else:
             self.theme = 'CLASSIC'
-            self._config.set('preferences.relation-display-theme', 
+            self._config.set('preferences.relation-display-theme',
                               'CLASSIC')
 
     def _get_configure_page_funcs(self):
         """
-        Return a list of functions that create gtk elements to use in the 
+        Return a list of functions that create gtk elements to use in the
         notebook pages of the Configure dialog
-        
+
         :return: list of functions
         """
         return [self.content_panel, self.config_panel]
@@ -1714,6 +1735,8 @@ def has_children(db,p):
     """
     for family_handle in p.get_family_handle_list():
         family = db.get_family_from_handle(family_handle)
+        if not family:
+            continue
         childlist = family.get_child_ref_list()
         if childlist and len(childlist) > 0:
             return True
