@@ -25,7 +25,7 @@
 """
 update_po.py for Gramps translations.
 
-Examples: 
+Examples:
    python update_po.py -t
 
       Tests if 'gettext' and 'python' are well configured.
@@ -37,11 +37,11 @@ Examples:
    python update_po.py -p
 
       Generates a new template/catalog (gramps.pot).
-      
+
    python update_po.py -m de.po
 
       Merges 'de.po' file with 'gramps.pot'.
-      
+
    python update_po.py -k de.po
 
       Checks 'de.po' file, tests to compile and generates a textual resume.
@@ -55,7 +55,7 @@ from argparse import ArgumentParser
 
 # Windows OS
 
-if sys.platform == 'win32':          
+if sys.platform == 'win32':
     # GetText Win 32 obtained from http://gnuwin32.sourceforge.net/packages/gettext.htm
     # ....\gettext\bin\msgmerge.exe needs to be on the path
     msgmergeCmd = os.path.join('C:', 'Program Files(x86)', 'gettext', 'bin', 'msgmerge.exe')
@@ -96,67 +96,64 @@ def tests():
         print ("\n====='msgmerge'=(merge our translation)================\n")
         os.system('''%(program)s -V''' % {'program': msgmergeCmd})
     except:
-        print ('Please, install %(program)s for updating your translation' 
+        print ('Please, install %(program)s for updating your translation'
                     % {'program': msgmergeCmd})
-        
+
     try:
         print ("\n==='msgfmt'=(format our translation for installation)==\n")
         os.system('''%(program)s -V''' % {'program': msgfmtCmd})
     except:
-        print ('Please, install %(program)s for checking your translation' 
+        print ('Please, install %(program)s for checking your translation'
                     % {'program': msgfmtCmd})
-        
+
     try:
         print ("\n===='msgattrib'==(list groups of messages)=============\n")
         os.system('''%(program)s -V''' % {'program': msgattribCmd})
     except:
-        print ('Please, install %(program)s for listing groups of messages' 
+        print ('Please, install %(program)s for listing groups of messages'
                     % {'program': msgattribCmd})
-        
-    
+
     try:
         print("\n===='xgettext' =(generate a new template)==============\n")
         os.system('''%(program)s -V''' % {'program': xgettextCmd})
     except:
-        print ('Please, install %(program)s for generating a new template' 
+        print ('Please, install %(program)s for generating a new template'
                     % {'program': xgettextCmd})
-    
+
     try:
         print("\n=================='python'=============================\n")
         os.system('''%(program)s -V''' % {'program': pythonCmd})
     except:
         print ('Please, install python')
-        
 
 def TipsParse(filename, mark):
     """
     Experimental alternative to 'intltool-extract' for 'tips.xml'.
     """
-
     from xml.etree import ElementTree
-    
+
     tree = ElementTree.parse(filename)
     root = tree.getroot()
-        
+
     '''
     <?xml version="1.0" encoding="UTF-8"?>
       <tips>
         <_tip number="1">
           <b>Working with Dates</b>
             <br/>
-        A range of dates can be given by using the format &quot;between 
-        January 4, 2000 and March 20, 2003&quot;. You can also indicate 
-        the level of confidence in a date and even choose between seven 
+        A range of dates can be given by using the format &quot;between
+        January 4, 2000 and March 20, 2003&quot;. You can also indicate
+        the level of confidence in a date and even choose between seven
         different calendars. Try the button next to the date field in the
         Events Editor.
         </_tip>
-        
-    char *s = N_("<b>Working with Dates</b><br/>A range of dates can be 
+
+    char *s = N_("<b>Working with Dates</b><br/>A range of dates can be
     given by using the format &quot;between January 4, 2000 and March 20,
-    2003&quot;. You can also indicate the level of confidence in a date 
-    and even choose between seven different calendars. Try the button 
+    2003&quot;. You can also indicate the level of confidence in a date
+    and even choose between seven different calendars. Try the button
     next to the date field in the Events Editor.");
-    
+
     gramps.pot:
     msgid ""
     "<b>Working with Dates</b><br/>A range of dates can be given by using the "
@@ -165,34 +162,32 @@ def TipsParse(filename, mark):
     "different calendars. Try the button next to the date field in the Events "
     "Editor."
     '''
-    
-    tips = open('../data/tips.xml.in.h', 'w')
-    marklist = root.iter(mark)
-    for key in marklist:
-        tip = ElementTree.tostring(key, encoding="UTF-8", method="xml")
-        if sys.version_info[0] < 3:
-            tip = tip.replace("<?xml version='1.0' encoding='UTF-8'?>", "")
-            tip = tip.replace('\n<_tip number="%(number)s">' % key.attrib, "")
-        else: # python3 support
-            tip = tip.decode("utf-8")
-            tip = tip.replace('<_tip number="%(number)s">' % key.attrib, "")
-        tip = tip.replace("<br />", "<br/>")
-        #tip = tip.replace("\n</_tip>\n", "</_tip>\n") # special case tip 7
-        #tip = tip.replace("\n<b>", "<b>") # special case tip 18
-        tip = tip.replace("</_tip>\n\n", "")
-        tip = tip.replace('"', '&quot;')
-        tips.write('char *s = N_("%s");\n' % tip)
-    tips.close()
+
+    with open('../data/tips.xml.in.h', 'w') as tips:
+        marklist = root.iter(mark)
+        for key in marklist:
+            tip = ElementTree.tostring(key, encoding="UTF-8", method="xml")
+            if sys.version_info[0] < 3:
+                tip = tip.replace("<?xml version='1.0' encoding='UTF-8'?>", "")
+                tip = tip.replace('\n<_tip number="%(number)s">' % key.attrib, "")
+            else: # python3 support
+                tip = tip.decode("utf-8")
+                tip = tip.replace('<_tip number="%(number)s">' % key.attrib, "")
+            tip = tip.replace("<br />", "<br/>")
+            #tip = tip.replace("\n</_tip>\n", "</_tip>\n") # special case tip 7
+            #tip = tip.replace("\n<b>", "<b>") # special case tip 18
+            tip = tip.replace("</_tip>\n\n", "")
+            tip = tip.replace('"', '&quot;')
+            tips.write('char *s = N_("%s");\n' % tip)
     print ('Wrote ../data/tips.xml.in.h')
     root.clear()
-    
+
 def HolidaysParse(filename, mark):
     """
     Experimental alternative to 'intltool-extract' for 'holidays.xml'.
     """
-
     from xml.etree import ElementTree
-    
+
     tree = ElementTree.parse(filename)
     root = tree.getroot()
     ellist = root.iter()
@@ -204,27 +199,25 @@ def HolidaysParse(filename, mark):
           ..
         <country _name="Jewish Holidays">
           <date _name="Yom Kippur" value="> passover(y)" offset="172"/>
-          
+
     char *s = N_("Bulgaria");
     char *s = N_("Jewish Holidays");
     char *s = N_("Yom Kippur");
-    
+
     gramps.pot:
     msgid "Bulgaria"
     msgid "Jewish Holidays"
     msgid "Yom Kippur"
     '''
-    
-    holidays = open('../gramps/plugins/lib/holidays.xml.in.h', 'w')
-    for key in ellist:
-        if key.attrib.get(mark):
-            line = key.attrib
-            string = line.items
-            # mapping via the line dict (_name is the key)
-            name = 'char *s = N_("%(_name)s");\n' % line
-            holidays.write(name)
-    holidays.close()
-    print ('Wrote ../gramps/plugins/lib/holidays.xml.in.h')
+    with open('../data/holidays.xml.in.h', 'w') as holidays:
+        for key in ellist:
+            if key.attrib.get(mark):
+                line = key.attrib
+                string = line.items
+                # mapping via the line dict (_name is the key)
+                name = 'char *s = N_("%(_name)s");\n' % line
+                holidays.write(name)
+    print ('Wrote ../data/holidays.xml.in.h')
     root.clear()
 
 
@@ -232,12 +225,11 @@ def XmlParse(filename, mark):
     """
     Experimental alternative to 'intltool-extract' for 'file.xml.in'.
     """
-    
     from xml.etree import ElementTree
-    
+
     tree = ElementTree.parse(filename)
     root = tree.getroot()
-    
+
     '''
     <?xml version="1.0" encoding="UTF-8"?>
 
@@ -252,10 +244,10 @@ def XmlParse(filename, mark):
           <glob pattern="*.gedcom"/>
           <glob pattern="*.GED"/>
           <glob pattern="*.GEDCOM"/>
-    
+
     msgid "Gramps database"
     msgid "GEDCOM"
-    
+
     <description>
     <_p> Gramps is a free software project and community.
     We strive to produce a genealogy program that is both intuitive for hobbyists
@@ -263,71 +255,64 @@ def XmlParse(filename, mark):
     </p>
     </description>
     '''
-    
-    head = open(filename + '.h', 'w')
-    
-    for key in root.iter():
-        if key.tag == '{http://www.freedesktop.org/standards/shared-mime-info}%s' % mark:
-            comment = 'char *s = N_("%s");\n' % key.text
-            head.write(comment)
-        if key.tag == mark: #appdata
-            comment = 'char *s = N_("%s");\n' % key.text
-            head.write(comment)
 
-    if root.tag == 'application':
+    with open(filename + '.h', 'w') as head:
         for key in root.iter():
-            if key.tag == mark:
+            if key.tag == '{http://www.freedesktop.org/standards/shared-mime-info}%s' % mark:
                 comment = 'char *s = N_("%s");\n' % key.text
                 head.write(comment)
-    
-    head.close()
+            if key.tag == mark: #appdata
+                comment = 'char *s = N_("%s");\n' % key.text
+                head.write(comment)
+
+        if root.tag == 'application':
+            for key in root.iter():
+                if key.tag == mark:
+                    comment = 'char *s = N_("%s");\n' % key.text
+                    head.write(comment)
+
     print ('Wrote %s' % filename)
     root.clear()
 
-        
 def DesktopParse(filename):
     """
     Experimental alternative to 'intltool-extract' for 'gramps.desktop'.
     """
-    
+
     '''
     [Desktop Entry]
     _Name=Gramps
     _GenericName=Genealogy System
     _X-GNOME-FullName=Gramps Genealogy System
-    _Comment=Manage genealogical information, 
+    _Comment=Manage genealogical information,
              perform genealogical research and analysis
-             
+
     msgid "Gramps"
     msgid "Genealogy System"
     msgid "Gramps Genealogy System"
     msgid ""
-          "Manage genealogical information, 
+          "Manage genealogical information,
            perform genealogical research and analysis"
     '''
-    
-    desktop = open('../data/gramps.desktop.in.h', 'w')
-    
-    f = open(filename)
-    lines = [file.strip() for file in f]
-    f.close()
-    
-    for line in lines:
-        if line[0] == '_':
-            for i in range(len(line)):
-                if line[i] == '=':
-                    val = 'char *s = N_("%s");\n' % line[i+1:len(line)]
-                    desktop.write(val)
-                    
-    desktop.close()
+    with open('../data/gramps.desktop.in.h', 'w') as desktop:
+
+        with open(filename) as f:
+            lines = [file.strip() for file in f]
+
+        for line in lines:
+            if line[0] == '_':
+                for i in range(len(line)):
+                    if line[i] == '=':
+                        val = 'char *s = N_("%s");\n' % line[i+1:len(line)]
+                        desktop.write(val)
+
     print ('Wrote ../data/gramps.desktop.in.h')
-                    
 
 def KeyParse(filename, mark):
     """
     Experimental alternative to 'intltool-extract' for 'gramps.keys'.
     """
-    
+
     '''
     application/x-gramps-xml:
     _description=Gramps XML database
@@ -343,48 +328,44 @@ def KeyParse(filename, mark):
     application/x-gedcom:
     _description=GEDCOM
     default_action_type=application
-    
+
     msgid "Gramps XML database"
     msgid "GEDCOM"
     '''
-    
-    key = open('../data/gramps.keys.in.h', 'w')
-    
-    f = open(filename)
-    lines = [file for file in f]
-    f.close()
-    
-    temp = []
-       
-    for line in lines:
-        for i in range(len(line)):
-            if line[i:i+12] == mark:
-                temp.append(line.strip())
-                
-    for t in temp:
-        for i in range(len(t)):
-            if t[i] == '=':
-                val = 'char *s = N_("%s");\n' % t[i+1:len(t)]
-                key.write(val)
-    
-    key.close()
+    with open('../data/gramps.keys.in.h', 'w') as key:
+
+        with open(filename) as f:
+            lines = [file for file in f]
+
+        temp = []
+
+        for line in lines:
+            for i in range(len(line)):
+                if line[i:i+12] == mark:
+                    temp.append(line.strip())
+
+        for t in temp:
+            for i in range(len(t)):
+                if t[i] == '=':
+                    val = 'char *s = N_("%s");\n' % t[i+1:len(t)]
+                    key.write(val)
+
     print ('Wrote ../data/gramps.keys.in.h')
-    
 
 def main():
     """
     The utility for handling translation stuff.
     What is need by Gramps, nothing more.
     """
-       
-    parser = ArgumentParser( 
+
+    parser = ArgumentParser(
                          description='This program generates a new template and '
-                                      'also provides some common features.', 
+                                      'also provides some common features.',
                          )
     parser.add_argument("-t", "--test",
             action="store_true", dest="test",  default=True,
             help="test if 'python' and 'gettext' are properly installed")
-                        
+
     parser.add_argument("-x", "--xml",
             action="store_true", dest="xml",  default=False,
             help="extract messages from xml based file formats")
@@ -394,93 +375,91 @@ def main():
     parser.add_argument("-c", "--clean",
             action="store_true", dest="clean",  default=False,
             help="remove created files")
-    parser.add_argument("-p", "--pot", 
+    parser.add_argument("-p", "--pot",
             action="store_true", dest="catalog",  default=False,
             help="create a new catalog")
-                    
+
     update = parser.add_argument_group('Update', 'Maintenance around translations')
-    
+
     # need at least one argument (sv.po, de.po, etc ...)
 
-    # lang.po files maintenance                          
+    # lang.po files maintenance
     update.add_argument("-m", dest="merge",
             choices=LANG,
             help="merge lang.po files with last catalog")
-              
+
     update.add_argument("-k", dest="check",
             choices=LANG,
             help="check lang.po files")
-        
-     # testing stage
+
+    # testing stage
     trans = parser.add_argument_group('Translation', 'Display content of translations file')
-       
+
     # need one argument (eg, de.po)
-    
-    trans.add_argument("-u", dest="untranslated", 
+
+    trans.add_argument("-u", dest="untranslated",
             choices=[file for file in os.listdir('.') if file.endswith('.po')],
             help="list untranslated messages")
     trans.add_argument("-f", dest="fuzzy",
             choices=[file for file in os.listdir('.') if file.endswith('.po')],
             help="list fuzzy messages")
-    
-    
+
     args = parser.parse_args()
     namespace, extra = parser.parse_known_args()
 
     if args.test:
         tests()
-       
+
     if args.xml:
         extract_xml()
-        
+
     if args.glade:
         create_filesfile()
         extract_glade()
         if os.path.isfile('tmpfiles'):
             os.unlink('tmpfiles')
-        
+
     if args.catalog:
         retrieve()
-        
+
     if args.clean:
         clean()
-        
+
     if args.merge:
         #retrieve() windows os?
         if sys.argv[2:] == ['all']:
             sys.argv[2:] = LANG
         merge(sys.argv[2:])
-        
+
     if args.check:
         #retrieve() windows os?
         if sys.argv[2:] == ['all']:
             sys.argv[2:] = LANG
         check(sys.argv[2:])
-        
+
     if args.untranslated:
         untranslated(sys.argv[2:])
-        
+
     if args.fuzzy:
         fuzzy(sys.argv[2:])
 
 def create_filesfile():
     """
     Create a file with all files that we should translate.
-    These are all python files not in POTFILES.skip added with those in 
+    These are all python files not in POTFILES.skip added with those in
     POTFILES.in
     """
     dir = os.getcwd()
     topdir = os.path.normpath(os.path.join(dir, '..', 'gramps'))
     lentopdir = len(topdir)
-    f = open('POTFILES.in')
-    infiles = dict(['../' + file.strip(), None] for file in f if file.strip() 
-                                                        and not file[0]=='#')
-    f.close()
-    f = open('POTFILES.skip')
-    notinfiles = dict(['../' + file.strip(), None] for file in f if file 
-                                                        and not file[0]=='#')
-    f.close()
-    
+    with open('POTFILES.in') as f:
+        infiles = dict(['../' + file.strip(), None] for file in f if file.strip()
+                                                            and not file[0]=='#')
+
+    with open('POTFILES.skip') as f:
+        notinfiles = dict(['../' + file.strip(), None] for file in f if file
+                                                            and not file[0]=='#')
+
     for (dirpath, dirnames, filenames) in os.walk(topdir):
             root, subdir = os.path.split(dirpath)
             if subdir.startswith("."):
@@ -495,7 +474,7 @@ def create_filesfile():
             # if the directory does not exist or is a link, do nothing
             if not os.path.isdir(dirpath) or os.path.islink(dirpath):
                 continue
-            
+
             for filename in os.listdir(dirpath):
                 name = os.path.split(filename)[1]
                 if name.endswith('.py') or name.endswith('.glade'):
@@ -504,11 +483,10 @@ def create_filesfile():
                     if full_filename[lentopdir:] in notinfiles:
                         infiles['../gramps' + full_filename[lentopdir:]] = None
     #now we write out all the files in form ../gramps/filename
-    f = open('tmpfiles', 'w')
-    for file in sorted(infiles.keys()):
-        f.write(file)
-        f.write('\n')
-    f.close()
+    with open('tmpfiles', 'w') as f:
+        for file in sorted(infiles.keys()):
+            f.write(file)
+            f.write('\n')
 
 def listing(name, extensionlist):
     """
@@ -516,26 +494,22 @@ def listing(name, extensionlist):
     Parsing from a textual file (gramps) is faster and easy for maintenance.
     Like POTFILES.in and POTFILES.skip
     """
-    
-    f = open('tmpfiles')
-    files = [file.strip() for file in f if file and not file[0]=='#']
-    f.close()
-    
-    temp = open(name, 'w')
-    
-    for entry in files:
-        for ext in extensionlist:
-            if entry.endswith(ext):
-                temp.write(entry)
-                temp.write('\n')
-                break
-    
-    temp.close()
-    
+
+    with open('tmpfiles') as f:
+        files = [file.strip() for file in f if file and not file[0]=='#']
+
+    with open(name, 'w') as temp:
+        for entry in files:
+            for ext in extensionlist:
+                if entry.endswith(ext):
+                    temp.write(entry)
+                    temp.write('\n')
+                    break
+
 def headers():
     """
     Look at existing C file format headers.
-    Generated by 'intltool-extract' but want to get rid of this 
+    Generated by 'intltool-extract' but want to get rid of this
     dependency (perl, just a set of tools).
     """
     headers = []
@@ -543,8 +517,8 @@ def headers():
     # in.h; extract_xml
     if os.path.isfile('''../data/tips.xml.in.h'''):
         headers.append('''../data/tips.xml.in.h''')
-    if os.path.isfile('''../gramps/plugins/lib/holidays.xml.in.h'''):
-        headers.append('''../gramps/plugins/lib/holidays.xml.in.h''')
+    if os.path.isfile('''../data/holidays.xml.in.h'''):
+        headers.append('''../data/holidays.xml.in.h''')
     if os.path.isfile('''../data/gramps.xml.in.h'''):
         headers.append('''../data/gramps.xml.in.h''')
     if os.path.isfile('''../data/gramps.desktop.in.h'''):
@@ -555,7 +529,7 @@ def headers():
         headers.append('''../data/gramps.appdata.xml.in.h''')
     if os.path.isfile('''gtklist.h'''):
         headers.append('''gtklist.h''')
-    
+
     return headers
 
 def extract_xml():
@@ -563,21 +537,20 @@ def extract_xml():
     Extract translation strings from XML based, keys, mime and desktop
     files. Own XML files parsing and custom translation marks.
     """
-  
-    HolidaysParse('../gramps/plugins/lib/holidays.xml.in', '_name')
+    HolidaysParse('../data/holidays.xml.in', '_name')
     TipsParse('../data/tips.xml.in', '_tip')
     XmlParse('../data/gramps.xml.in', '_comment')
     XmlParse('../data/gramps.appdata.xml.in', '_p')
     DesktopParse('../data/gramps.desktop.in')
     KeyParse('../data/gramps.keys.in', '_description')
-    
+
 def create_template():
     """
     Create a new file for template, if it does not exist.
     """
-    template = open('gramps.pot', 'w')
-    template.close()
-    
+    with open('gramps.pot', 'w') as template:
+        pass
+
 def extract_glade():
     """
     Extract messages from a temp file with all .glade
@@ -597,9 +570,9 @@ def extract_gtkbuilder():
     https://savannah.gnu.org/bugs/index.php?29216
     See bug reports #6595, #5621
     """
-    
+
     from xml.etree import ElementTree
-    
+
     '''
     <?xml version="1.0" encoding="UTF-8"?>
     <interface>
@@ -622,26 +595,24 @@ def extract_gtkbuilder():
       </row>
     </data>
   </object>
-    
+
     msgid "All rules must apply"
     msgid "At least one rule must apply"
     msgid "Exactly one rule must apply"
     '''
-    
+
     files = ['../gramps/plugins/importer/importgedcom.glade', '../gramps/gui/glade/rule.glade']
-    temp = open('gtklist.h', 'w')
-    
-    for filename in files:
-        tree = ElementTree.parse(filename)
-        root = tree.getroot()
-        for line in root.iter():
-            att = line.attrib
-            if att == {'id': '0', 'translatable': 'yes'}:
-                col = 'char *s = N_("%s");\n' % line.text
-                temp.write(col)
-        root.clear()
-    
-    temp.close()
+    with open('gtklist.h', 'w') as temp:
+        for filename in files:
+            tree = ElementTree.parse(filename)
+            root = tree.getroot()
+            for line in root.iter():
+                att = line.attrib
+                if att == {'id': '0', 'translatable': 'yes'}:
+                    col = 'char *s = N_("%s");\n' % line.text
+                    temp.write(col)
+            root.clear()
+
     print ('Wrote gtklist.h')
 
 def retrieve():
@@ -649,29 +620,29 @@ def retrieve():
     Extract messages from all files used by Gramps (python, glade, xml)
     """
     extract_xml()
-    
+
     extract_gtkbuilder()
-    
+
     create_template()
-        
+
     create_filesfile()
     listing('python.txt', ['.py', '.py.in'])
-    
+
     # additional keywords must always be kept in sync with those in genpot.sh
     os.system('''%(xgettext)s -F -c -j --directory=./ -d gramps '''
               '''-L Python -o gramps.pot --files-from=python.txt '''
-              '''--keyword=_ --keyword=ngettext '''
+              '''--debug --keyword=_ --keyword=ngettext '''
               '''--keyword=_T_ --keyword=trans_text '''
               '''--keyword=sgettext --from-code=UTF-8''' % {'xgettext': xgettextCmd}
              )
-    
+
     extract_glade()
-    
+
     # C format header (.h extension)
     for h in headers():
         print ('xgettext for %s' % h)
         os.system('''%(xgettext)s -F --add-comments -j -o gramps.pot '''
-                  '''--keyword=N_ --from-code=UTF-8 %(head)s''' 
+                  '''--keyword=N_ --from-code=UTF-8 %(head)s'''
                   % {'xgettext': xgettextCmd, 'head': h}
                   )
     clean()
@@ -701,20 +672,18 @@ def merge(args):
     """
     Merge messages with 'gramps.pot'
     """
-    
     for arg in args:
         if arg == 'all':
-            continue  
+            continue
         print ('Merge %(lang)s with current template' % {'lang': arg})
-        os.system('''%(msgmerge)s %(lang)s gramps.pot -o updated_%(lang)s''' \
+        os.system('''%(msgmerge)s -U %(lang)s gramps.pot''' \
                     % {'msgmerge': msgmergeCmd, 'lang': arg})
-        print ("Updated file: 'updated_%(lang)s'." % {'lang': arg})
+        print ("Updated file: '%(lang)s'." % {'lang': arg})
 
 def check(args):
     """
     Check the translation file
     """
-    
     for arg in args:
         if arg == 'all':
             continue
@@ -722,22 +691,20 @@ def check(args):
                     % {'lang.po': arg, 'txt': arg[:-3]})
         os.system('''%(python)s ./check_po -s %(lang.po)s > %(lang)s.txt''' \
                     % {'python': pythonCmd, 'lang.po': arg, 'lang': arg[:-3]})
-        os.system('''%(msgfmt)s -c -v %(lang.po)s''' 
+        os.system('''%(msgfmt)s -c -v %(lang.po)s'''
                     % {'msgfmt': msgfmtCmd, 'lang.po': arg})
 
 def untranslated(arg):
     """
     List untranslated messages
     """
-        
     os.system('''%(msgattrib)s --untranslated %(lang.po)s''' % {'msgattrib': msgattribCmd, 'lang.po': arg[0]})
 
 def fuzzy(arg):
     """
     List fuzzy messages
     """
-   
     os.system('''%(msgattrib)s --only-fuzzy --no-obsolete %(lang.po)s''' % {'msgattrib': msgattribCmd, 'lang.po': arg[0]})
 
 if __name__ == "__main__":
-	main()
+    main()
